@@ -125,6 +125,8 @@ Fl_Group *grpTABS = (Fl_Group *)0;
 
 Fl_Group *hidden_tabs = (Fl_Group *)0;
 
+Fl_Group *tabs = (Fl_Group *)0;
+
 Fl_Tabs *tabsGeneric=(Fl_Tabs *)0;
 
 Fl_Group *tab_yaesu_bands = (Fl_Group *)0;
@@ -386,6 +388,9 @@ Fl_Group *g_extras = (Fl_Group *)0;
 
 static const char *mtr_scales[] = {
 "5 watt",
+"10 watt",
+"15 watt",
+"20 watt",
 "25 watt",
 "50 watt",
 "100 watt",
@@ -571,11 +576,9 @@ static void cb_mnu_power_meter_scale(Fl_Menu_ *, void *) {
 	select_power_meter_scales();
 }
 
-extern bool useB;
-
 static void cb_btnA(Fl_Light_Button*, void*) {
 	if (Fl::event_button() == FL_RIGHT_MOUSE) {
-		if (!useB) {
+		if (selrig->inuse == onA) {
 			addFreq();
 			btnA->value(1);
 			btnB->value(0);
@@ -584,7 +587,7 @@ static void cb_btnA(Fl_Light_Button*, void*) {
 			btnB->value(1);
 		}
 	} else {
-		if (useB) {
+		if (selrig->inuse == onB) {
 			cb_selectA();
 		} else {
 			if (FreqDispA->is_reversed_colors()) {
@@ -615,7 +618,7 @@ static void cb_btn_KX3_swapAB(Fl_Button*, void*) {
 
 static void cb_btnB(Fl_Light_Button*, void*) {
 	if (Fl::event_button() == FL_RIGHT_MOUSE) {
-		if (useB) {
+		if (selrig->inuse == onB) {
 			addFreq();
 			btnB->value(1);
 			btnA->value(0);
@@ -624,7 +627,7 @@ static void cb_btnB(Fl_Light_Button*, void*) {
 			btnA->value(1);
 		}
 	} else {
-		if (!useB) {
+		if (selrig->inuse == onA) {
 			cb_selectB();
 		} else { 
 			if (FreqDispB->is_reversed_colors()) {
@@ -705,7 +708,8 @@ static void cb_btnSplit(Fl_Light_Button* o, void*) {
 }
 
 extern void doPTT(int);
-static void cb_btnPTT(Fl_Light_Button *b, void*) {
+static void cb_btnPTT(Fl_Light_Button *b, void*)
+{
 	doPTT(b->value());
 }
 
@@ -781,9 +785,8 @@ static void cb_sldrVOLUME(Fl_Wheel_Value_Slider*, void*) {
 }
 
 static void cb_btn_band_select(Fl_Button *, void *d) {
-	long lband = reinterpret_cast<long>(d);
-	int band = lband;
-	cbBandSelect(band);
+	size_t band = reinterpret_cast<size_t>(d);
+	cbBandSelect( (int)band);
 }
 
 static void cb_btnSpot(Fl_Light_Button* o, void*) {
@@ -931,7 +934,7 @@ static void cb_btn_xcvr_synch_now( Fl_Button *o, void *) {
 //}
 
 static void cb_btnUser( Fl_Button * o, void *d) {
-	long val = reinterpret_cast<long>(d);
+	size_t val = reinterpret_cast<size_t>(d);
 	if (((Fl::event_state() & FL_SHIFT) == FL_SHIFT) ||
 		(Fl::event_button() == FL_RIGHT_MOUSE)) {
 		switch (val) {
@@ -1220,6 +1223,10 @@ static void cb_tt550_Nsamples(Fl_Simple_Counter *, void *) {
 	progStatus.tt550_Nsamples =  tt550_Nsamples->value();
 }
 
+static void cb_tabsGeneric(Fl_Widget *, void *) {
+	progStatus.visible_tab = (tabsGeneric->value())->label();
+}
+
 Fl_Menu_Item *getMenuItem(const char *caption, Fl_Menu_Item* menu = 0)
 {
 	if (menu == 0) {
