@@ -1,3 +1,4 @@
+
 // ---------------------------------------------------------------------
 // cwio.cxx  --  morse code modem
 //
@@ -43,11 +44,11 @@
 #include "tod_clock.h"
 #include "cwio.h"
 #include "cwioUI.h"
+#include "support.h"
+#include "status.h"
 
 //#define CWIO_DEBUG
 
-using namespace std;
-
 Cserial *cwio_serial = 0;
 Cmorse  *morse = 0;
 
@@ -59,6 +60,10 @@ pthread_mutex_t cwio_text_mutex = PTHREAD_MUTEX_INITIALIZER;
 int cwio_process = NONE;
 bool cwio_thread_running = false;
 
+static std::string new_text;
+static std::string cwio_text;
+
+
 // return current tick time in seconds
 double cw_now()
 {
@@ -107,6 +112,35 @@ int cw_sleep (double sleep_time)
 	return 0;
 }
 
+void cwio_key(bool state)
+{
+	Cserial *port = cwio_serial;
+
+	switch (progStatus.cwioSHARED) {
+		case 1: port = RigSerial; break;
+		case 2: port = AuxSerial; break;
+		case 3: port = SepSerial; break;
+		default: port = cwio_serial;
+	}
+
+	if (!port)
+		return;
+
+	if (!port->IsOpen())
+		return;
+
+	if (progStatus.cwioPTT)
+		doPTT(state);
+
+	if (progStatus.cwioKEYLINE == 2) {
+			port->setDTR(progStatus.cwioINVERTED ? !state : state);
+	} else if (progStatus.cwioKEYLINE == 1) {
+		port->setRTS(progStatus.cwioINVERTED ? !state : state);
+	}
+
+	return;
+}
+
 void send_cwkey(char c)
 {
 #ifdef CWIO_DEBUG
@@ -117,6 +151,7 @@ void send_cwkey(char c)
 	static double tc = 0;
 	static double tch = 0;
 	static double twd = 0;
+	static double xcvr_corr = 0;
 	Cserial *port = cwio_serial;
 
 	switch (progStatus.cwioSHARED) {
@@ -142,6 +177,10 @@ void send_cwkey(char c)
 		twd = twd - 4 * progStatus.cwio_comp;
 	}
 
+	xcvr_corr = progStatus.cwio_keycorr * 1e-3;
+	if (xcvr_corr < -tc / 2) xcvr_corr = - tc / 2;
+	else if (xcvr_corr > tc / 2) xcvr_corr = tc / 2;
+
 	if (c == ' ' || c == 0x0a) {
 		cw_sleep(twd);
 		goto exit_send_cwkey;
@@ -158,7 +197,7 @@ void send_cwkey(char c)
 			port->setRTS(progStatus.cwioINVERTED ? 0 : 1);
 		}
 		if (code[n] == '.')
-			cw_sleep(tc);
+			cw_sleep(tc + xcvr_corr);
 		else
 			cw_sleep(tch);
 
@@ -170,7 +209,7 @@ void send_cwkey(char c)
 		if (n == code.length() -1)
 			cw_sleep(tch);
 		else
-			cw_sleep(tc);
+			cw_sleep(tc - xcvr_corr);
 	}
 
 exit_send_cwkey:
@@ -223,7 +262,7 @@ void close_cwkey()
 	}
 }
 
-static string snd;
+static std::string snd;
 
 void update_txt_to_send(void *)
 {
@@ -405,9 +444,7 @@ void stop_cwio_thread()
 
 }
 
-static string new_text;
-
-void add_cwio(string txt)
+void add_cwio(std::string txt)
 {
 	if (!cwio_thread_running) return;
 
@@ -433,6 +470,12 @@ void send_text(bool state)
 	}
 }
 
+void cwio_new_text(std::string txt)
+{
+	cwio_text.append(txt);
+	send_text(true);
+}
+
 void cwio_clear_text()
 {
 	txt_to_send->value("");
