@@ -27,6 +27,7 @@
 #include "fskioUI.h"
 #include "serial.h"
 #include "support.h"
+#include "status.h"
 #include "util.h"
 
 #ifdef __WIN32__
@@ -367,8 +368,8 @@ if (!ftiming) {
 			send_baudot(chr_out & 0x1F);
 		}
 	} else
-//		MilliSleep(10);
-		sleep(BITLEN);
+		MilliSleep(BITLEN*1000L);
+//		sleep(BITLEN);
 	return 0;
 }
 
@@ -419,7 +420,7 @@ int  FSK_start_thread() {
 	try {
 		fsk_instance = new FSK;
 	} catch (const char *error) {
-		cerr << error << '\n';
+		std::cerr << error << '\n';
 		debug::stop();
 		return 1;
 	}
@@ -429,9 +430,9 @@ int  FSK_start_thread() {
 void FSK_stop_thread() {
 }
 
-static string FSK_new_text;
+static std::string FSK_new_text;
 
-void FSK_add(string txt)
+void FSK_add(std::string txt)
 {
 	guard_lock lck(&fskio_text_mutex);
 	FSK_new_text = FSK_txt_to_send->value();
