@@ -27,6 +27,9 @@
 //#include "smeter.xbm"
 
 #include "images/P5.xbm"
+#include "images/P10.xbm"
+#include "images/P15.xbm"
+#include "images/P20.xbm"
 #include "images/P25.xbm"
 #include "images/P50.xbm"
 #include "images/P100.xbm"
@@ -40,6 +43,9 @@
 #include "images/alc.xbm"
 
 Fl_Bitmap image_p5(P5_bits, P5_width, P5_height);
+Fl_Bitmap image_p10(P10_bits, P10_width, P10_height);
+Fl_Bitmap image_p15(P15_bits, P15_width, P15_height);
+Fl_Bitmap image_p20(P20_bits, P20_width, P20_height);
 Fl_Bitmap image_p25(P25_bits, P25_width, P25_height);
 Fl_Bitmap image_p50(P50_bits, P50_width, P50_height);
 Fl_Bitmap image_p100(P100_bits, P100_width, P100_height);
