@@ -84,8 +84,6 @@
 #include "tentec/TT566.h"
 #include "tentec/TT588.h"
 #include "tentec/TT599.h"
-#include "xiegu/Xiegu-5105.h"
-#include "xiegu/Xiegu-G90.h"
 #include "yaesu/FT100D.h"
 #include "yaesu/FT450.h"
 #include "yaesu/FT450D.h"
@@ -109,6 +107,7 @@
 #include "yaesu/FT991A.h"
 #include "yaesu/FT1000.h"
 #include "yaesu/FT1000MP.h"
+#include "yaesu/FT1000MP_A.h"
 #include "yaesu/FT2000.h"
 #include "yaesu/FTdx10.h"
 #include "yaesu/FTdx101D.h"
@@ -116,6 +115,9 @@
 #include "yaesu/FTdx3000.h"
 #include "yaesu/FTdx9000.h"
 #include "yaesu/FT5000.h"
+#include "xiegu/Xiegu-5105.h"
+#include "xiegu/Xiegu-G90.h"
+#include "xiegu/X6100.h"
 
 extern rigbase			rig_null;		// 0
 extern RIG_FDMDUO		rig_FDMDUO;		// 1
@@ -143,75 +145,77 @@ extern RIG_FT991		rig_FT991;		// 22
 extern RIG_FT991A		rig_FT991A;		// 23
 extern RIG_FT1000		rig_FT1000;		// 24
 extern RIG_FT1000MP     rig_FT1000MP;	// 25
-extern RIG_FT2000		rig_FT2000;		// 26
-extern RIG_FTdx10		rig_FTdx10;		// 27
-extern RIG_FTdx101D		rig_FTdx101D;	// 28
-extern RIG_FTdx101MP	rig_FTdx101MP;	// 29
-extern RIG_FTdx1200		rig_FTdx1200;	// 30
-extern RIG_FTdx3000		rig_FTdx3000;	// 31
-extern RIG_FT5000		rig_FT5000;		// 32
-extern RIG_FTdx9000		rig_FTdx9000;	// 33
-extern RIG_IC703		rig_IC703;		// 34
-extern RIG_IC705		rig_IC705;		// 35
-extern RIG_IC706MKIIG	rig_IC706MKIIG;	// 36
-extern RIG_IC718		rig_IC718;		// 37
-extern RIG_IC728		rig_IC728;		// 38
-extern RIG_IC735		rig_IC735;		// 39
-extern RIG_IC746		rig_IC746;		// 40
-extern RIG_IC746PRO     rig_IC746PRO;	// 41
-extern RIG_IC756		rig_IC756;		// 42
-extern RIG_IC756PRO     rig_IC756PRO;	// 43
-extern RIG_IC756PRO2	rig_IC756PRO2;	// 44
-extern RIG_IC756PRO3	rig_IC756PRO3;	// 45
-extern RIG_IC7000		rig_IC7000;		// 46
-extern RIG_IC7100		rig_IC7100;		// 47
-extern RIG_IC7200		rig_IC7200;		// 48
-extern RIG_IC7300		rig_IC7300;		// 49
-extern RIG_IC7410		rig_IC7410;		// 50
-extern RIG_IC7600		rig_IC7600;		// 51
-extern RIG_IC7610		rig_IC7610;		// 52
-extern RIG_IC7700		rig_IC7700;		// 53
-extern RIG_IC7800		rig_IC7800;		// 54
-extern RIG_IC7851		rig_IC7851;		// 55
-extern RIG_IC9100		rig_IC9100;		// 56
-extern RIG_IC9700		rig_IC9700;		// 57
-extern RIG_IC910H		rig_IC910H;		// 58
-extern RIG_ICF8101		rig_ICF8101;	// 59
-extern RIG_K2			rig_K2;			// 60
-extern RIG_K3			rig_K3;			// 61
-extern RIG_KX3			rig_KX3;		// 62
-extern RIG_PCR1000		rig_PCR1000;	// 63
-extern RIG_RAY152		rig_RAY152;		// 64
-extern RIG_TMD710		rig_TMD710;		// 65
-extern RIG_TS440		rig_TS440;		// 66
-extern RIG_TS140		rig_TS140;		// 67
-extern RIG_TS450S		rig_TS450S;		// 68
-extern RIG_TS480HX		rig_TS480HX;	// 69
-extern RIG_TS480SAT	    rig_TS480SAT;	// 70
-extern RIG_TS570		rig_TS570;		// 71
-extern RIG_TS590S		rig_TS590S;		// 72
-extern RIG_TS590SG		rig_TS590SG;	// 73
-extern RIG_TS790		rig_TS790;		// 74
-extern RIG_TS850		rig_TS850;		// 75
-extern RIG_TS870S		rig_TS870S;		// 76
-extern RIG_TS890S		rig_TS890S;		// 77
-extern RIG_TS940S		rig_TS940S;		// 78
-extern RIG_TS950		rig_TS950;		// 79
-extern RIG_TS990		rig_TS990;		// 80
-extern RIG_TS2000		rig_TS2000;		// 81
-extern RIG_TT516		rig_TT516;		// 82
-extern RIG_TT535		rig_TT535;		// 83
-extern RIG_TT538		rig_TT538;		// 84
-extern RIG_TT550		rig_TT550;		// 85
-extern RIG_TT563		rig_TT563;		// 86
-extern RIG_TT566		rig_TT566;		// 87
-extern RIG_TT588		rig_TT588;		// 88
-extern RIG_TT599		rig_TT599;		// 89
-extern RIG_AOR5K		rig_AOR5K;		// 90
-extern RIG_XI5105		rig_XI5105;		// 91
-extern RIG_Xiegu_G90	rig_XIG90;		// 92
-extern RIG_PowerSDR		rig_PowerSDR;	// 93
-extern RIG_FLEX1500		rig_FLEX1500;	// 94
-extern RIG_TX500		rig_TX500;		// 95
+extern RIG_FT1000MP_A	Rig_FT1000MP_A;	// 26
+extern RIG_FT2000		rig_FT2000;		// 27
+extern RIG_FTdx10		rig_FTdx10;		// 28
+extern RIG_FTdx101D		rig_FTdx101D;	// 29
+extern RIG_FTdx101MP	rig_FTdx101MP;	// 20
+extern RIG_FTdx1200		rig_FTdx1200;	// 31
+extern RIG_FTdx3000		rig_FTdx3000;	// 32
+extern RIG_FT5000		rig_FT5000;		// 33
+extern RIG_FTdx9000		rig_FTdx9000;	// 34
+extern RIG_IC703		rig_IC703;		// 35
+extern RIG_IC705		rig_IC705;		// 36
+extern RIG_IC706MKIIG	rig_IC706MKIIG;	// 37
+extern RIG_IC718		rig_IC718;		// 38
+extern RIG_IC728		rig_IC728;		// 39
+extern RIG_IC735		rig_IC735;		// 30
+extern RIG_IC746		rig_IC746;		// 41
+extern RIG_IC746PRO     rig_IC746PRO;	// 42
+extern RIG_IC756		rig_IC756;		// 43
+extern RIG_IC756PRO     rig_IC756PRO;	// 44
+extern RIG_IC756PRO2	rig_IC756PRO2;	// 45
+extern RIG_IC756PRO3	rig_IC756PRO3;	// 46
+extern RIG_IC7000		rig_IC7000;		// 47
+extern RIG_IC7100		rig_IC7100;		// 48
+extern RIG_IC7200		rig_IC7200;		// 49
+extern RIG_IC7300		rig_IC7300;		// 40
+extern RIG_IC7410		rig_IC7410;		// 51
+extern RIG_IC7600		rig_IC7600;		// 52
+extern RIG_IC7610		rig_IC7610;		// 53
+extern RIG_IC7700		rig_IC7700;		// 54
+extern RIG_IC7800		rig_IC7800;		// 55
+extern RIG_IC7851		rig_IC7851;		// 56
+extern RIG_IC9100		rig_IC9100;		// 57
+extern RIG_IC9700		rig_IC9700;		// 58
+extern RIG_IC910H		rig_IC910H;		// 59
+extern RIG_ICF8101		rig_ICF8101;	// 50
+extern RIG_K2			rig_K2;			// 61
+extern RIG_K3			rig_K3;			// 62
+extern RIG_KX3			rig_KX3;		// 63
+extern RIG_PCR1000		rig_PCR1000;	// 64
+extern RIG_RAY152		rig_RAY152;		// 65
+extern RIG_TMD710		rig_TMD710;		// 66
+extern RIG_TS440		rig_TS440;		// 67
+extern RIG_TS140		rig_TS140;		// 68
+extern RIG_TS450S		rig_TS450S;		// 69
+extern RIG_TS480HX		rig_TS480HX;	// 60
+extern RIG_TS480SAT	    rig_TS480SAT;	// 71
+extern RIG_TS570		rig_TS570;		// 72
+extern RIG_TS590S		rig_TS590S;		// 73
+extern RIG_TS590SG		rig_TS590SG;	// 74
+extern RIG_TS790		rig_TS790;		// 75
+extern RIG_TS850		rig_TS850;		// 76
+extern RIG_TS870S		rig_TS870S;		// 77
+extern RIG_TS890S		rig_TS890S;		// 78
+extern RIG_TS940S		rig_TS940S;		// 79
+extern RIG_TS950		rig_TS950;		// 70
+extern RIG_TS990		rig_TS990;		// 81
+extern RIG_TS2000		rig_TS2000;		// 82
+extern RIG_TT516		rig_TT516;		// 83
+extern RIG_TT535		rig_TT535;		// 84
+extern RIG_TT538		rig_TT538;		// 85
+extern RIG_TT550		rig_TT550;		// 86
+extern RIG_TT563		rig_TT563;		// 87
+extern RIG_TT566		rig_TT566;		// 88
+extern RIG_TT588		rig_TT588;		// 89
+extern RIG_TT599		rig_TT599;		// 80
+extern RIG_AOR5K		rig_AOR5K;		// 91
+extern RIG_XI5105		rig_XI5105;		// 92
+extern RIG_Xiegu_G90	rig_XIG90;		// 93
+extern RIG_X6100		rig_X6100;		// 94
+extern RIG_PowerSDR		rig_PowerSDR;	// 95
+extern RIG_FLEX1500		rig_FLEX1500;	// 96
+extern RIG_TX500		rig_TX500;		// 97
 
 #endif
