@@ -24,6 +24,8 @@
 #include <sstream>
 
 #include "tod_clock.h"
+#include "status.h"
+
 #include "support.h"
 
 //=============================================================================
@@ -370,8 +372,6 @@ bool RIG_IC7100::check ()
 
 static int ret = 0;
 
-static bool IC7100onA = true;
-
 void RIG_IC7100::selectA()
 {
 	cmd = pre_to;
@@ -381,7 +381,7 @@ void RIG_IC7100::selectA()
 	set_trace(1, "selectA()");
 	waitFB("select A");
 	seth();
-	IC7100onA = true;
+	inuse = onA;
 }
 
 void RIG_IC7100::selectB()
@@ -393,13 +393,13 @@ void RIG_IC7100::selectB()
 	set_trace(1, "selectB()");
 	waitFB("select B");
 	seth();
-	IC7100onA = false;
+	inuse = onB;
 }
 
 unsigned long int RIG_IC7100::get_vfoA ()
 {
-	if (useB) return A.freq;
-	string resp = pre_fm;
+	if (inuse == onB) return A.freq;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -411,7 +411,7 @@ unsigned long int RIG_IC7100::get_vfoA ()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -435,8 +435,8 @@ void RIG_IC7100::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC7100::get_vfoB ()
 {
-	if (!useB) return B.freq;
-	string resp = pre_fm;
+	if (inuse == onA) return B.freq;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -448,7 +448,7 @@ unsigned long int RIG_IC7100::get_vfoB ()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -499,10 +499,10 @@ int RIG_IC7100::get_split()
 	geth();
 
 	if (ret) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x0F");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			read_split = replystr[p+5];
 		if (read_split != 0xFA) // fail byte
 			split = read_split;
@@ -528,7 +528,7 @@ int RIG_IC7100::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 
@@ -538,7 +538,7 @@ int RIG_IC7100::get_PTT()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	return ptt_;
@@ -576,7 +576,7 @@ int RIG_IC7100::get_modeA()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 
 	get_trace(1,"get_modeA()");
@@ -616,7 +616,7 @@ int RIG_IC7100::get_modeA()
 
 		if (ret) {
 			p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				if ((replystr[p+6] & 0x01) == 0x01) {
 					if (md == USB7100) md = USBD7100;
 					else if (md == LSB7100) md = LSBD7100;
@@ -693,7 +693,7 @@ int RIG_IC7100::get_modeB()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 
 	get_trace(1,"get_modeB()");
@@ -734,7 +734,7 @@ int RIG_IC7100::get_modeB()
 
 		if (ret) {
 			p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				if ((replystr[p+6] & 0x01) == 0x01) {
 					if (md == USB7100) md = USBD7100;
 					else if (md == LSB7100) md = LSBD7100;
@@ -787,7 +787,7 @@ int RIG_IC7100::get_bwA()
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x1a\x03");
 
 	get_trace(1,"get_bwA()");
@@ -824,7 +824,7 @@ int RIG_IC7100::get_bwB()
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x1a\x03");
 
 	get_trace(1,"get_bwB()");
@@ -854,7 +854,7 @@ void RIG_IC7100::set_bwB(int val)
 
 std::string RIG_IC7100::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -864,7 +864,7 @@ std::string RIG_IC7100::get_BANDWIDTHS()
 
 void RIG_IC7100::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -950,8 +950,8 @@ void RIG_IC7100::set_mic_gain(int val)
 int RIG_IC7100::get_mic_gain()
 {
 	int val = progStatus.volume;
-	string cstr = "\x14\x0B";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0B";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -963,7 +963,7 @@ int RIG_IC7100::get_mic_gain()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -998,7 +998,7 @@ int RIG_IC7100::get_attenuator()
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x11';
 
 	get_trace(1,"get_attenuator()");
@@ -1020,7 +1020,7 @@ int RIG_IC7100::get_attenuator()
 
 int RIG_IC7100::next_preamp()
 {
-	if (IC7100onA) {
+	if (inuse == onA) {
 		if (A.freq > 100000000) {
 			if (preamp_level) return 0;
 			return 1;
@@ -1058,8 +1058,8 @@ void RIG_IC7100::set_preamp(int val)
 	cmd += '\x02';
 
 	preamp_level = val;
-	if (IC7100onA && A.freq > 100000000 && val > 1) val = 1;
-	if (!IC7100onA && B.freq > 100000000 && val > 1) val = 1;
+	if (inuse == onA && A.freq > 100000000 && val > 1) val = 1;
+	if (inuse == onB && B.freq > 100000000 && val > 1) val = 1;
 	switch (val) {
 		case 1: 
 			preamp_label("Pre 1", true);
@@ -1083,8 +1083,8 @@ void RIG_IC7100::set_preamp(int val)
 
 int RIG_IC7100::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1096,7 +1096,7 @@ int RIG_IC7100::get_preamp()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			preamp_level = replystr[p+6];
 		if (preamp_level == 1) {
 			preamp_label("Pre 1", true);
@@ -1247,7 +1247,7 @@ int RIG_IC7100::get_break_in()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			progStatus.break_in = replystr[p+6];
 			if (progStatus.break_in == 0) break_in_label("qsk");
 			else  break_in_label("QSK ON");
@@ -1270,8 +1270,8 @@ void RIG_IC7100::set_power_control(double val)
 double RIG_IC7100::get_power_control()
 {
 	int val = progStatus.power_level;
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
@@ -1282,7 +1282,7 @@ double RIG_IC7100::get_power_control()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -1295,10 +1295,10 @@ void RIG_IC7100::get_pc_min_max_step(double &min, double &max, double &step)
 
 void RIG_IC7100::set_rf_gain(int val)
 {
-	if (IC7100onA && (A.imode == DV7100 ||
+	if (inuse == onA && (A.imode == DV7100 ||
 		A.imode == FM7100 || A.imode == WFM7100 || A.imode == FMD7100))
 		return;
-	if (!IC7100onA && (A.imode == DV7100 ||
+	if (inuse == onB && (A.imode == DV7100 ||
 		A.imode == FM7100 || A.imode == WFM7100 || A.imode == FMD7100))
 		return;
 
@@ -1313,16 +1313,16 @@ void RIG_IC7100::set_rf_gain(int val)
 
 int RIG_IC7100::get_rf_gain()
 {
-	if (IC7100onA && (A.imode == DV7100 ||
+	if (inuse == onA && (A.imode == DV7100 ||
 		A.imode == FM7100 || A.imode == WFM7100 || A.imode == FMD7100))
 		return progStatus.rfgain;
-	if (!IC7100onA && (A.imode == DV7100 ||
+	if (inuse == onB && (A.imode == DV7100 ||
 		A.imode == FM7100 || A.imode == WFM7100 || A.imode == FMD7100))
 		return progStatus.rfgain;
 
 	int val = progStatus.rfgain;
-	string cstr = "\x14\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x02";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
@@ -1333,7 +1333,7 @@ int RIG_IC7100::get_rf_gain()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	return val;
@@ -1359,8 +1359,8 @@ void RIG_IC7100::set_volume_control(int val)
 int RIG_IC7100::get_volume_control()
 {
 	int val = progStatus.volume;
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1372,7 +1372,7 @@ int RIG_IC7100::get_volume_control()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -1392,8 +1392,8 @@ void RIG_IC7100::set_squelch(int val)
 int  RIG_IC7100::get_squelch()
 {
 	int val = progStatus.squelch;
-	string cstr = "\x14\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1405,7 +1405,7 @@ int  RIG_IC7100::get_squelch()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -1425,8 +1425,8 @@ static meterpair smtrtbl[] = {
 
 int RIG_IC7100::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1439,7 +1439,7 @@ int RIG_IC7100::get_smeter()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
 			for (i = 0; i < sizeof(smtrtbl) / sizeof(meterpair) - 1; i++)
@@ -1457,8 +1457,8 @@ int RIG_IC7100::get_smeter()
 
 double RIG_IC7100::get_voltmeter()
 {
-	string cstr = "\x15\x15";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x15";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1473,7 +1473,7 @@ double RIG_IC7100::get_voltmeter()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			val = (2.0 * mtr / 77.0) + 9.82;
 			return val;
@@ -1497,8 +1497,8 @@ static meterpair pwrtbl[] = {
 
 int RIG_IC7100::get_power_out(void)
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1512,9 +1512,9 @@ int RIG_IC7100::get_power_out(void)
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = hex2val(replystr.substr(p+6, 2));
-			mtr = max(0, min(mtr, 255));
+			mtr = std::max(0, std::min(mtr, 255));
 			size_t i = 0;
 			for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 				if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
@@ -1529,8 +1529,8 @@ int RIG_IC7100::get_power_out(void)
 
 int RIG_IC7100::get_swr()
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1543,7 +1543,7 @@ int RIG_IC7100::get_swr()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.40);
 			if (mtr > 100) mtr = 100;
@@ -1554,8 +1554,8 @@ int RIG_IC7100::get_swr()
 
 int RIG_IC7100::get_alc()
 {
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1568,7 +1568,7 @@ int RIG_IC7100::get_alc()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /1.2);
 			if (mtr > 100) mtr = 100;
@@ -1628,8 +1628,8 @@ bool RIG_IC7100::get_notch(int &val)
 	bool on = false;
 	val = 1500;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1641,7 +1641,7 @@ bool RIG_IC7100::get_notch(int &val)
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6];
 		cmd = pre_to;
 		resp = pre_fm;
@@ -1656,7 +1656,7 @@ bool RIG_IC7100::get_notch(int &val)
 
 		if (ret) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
 				val -= 128;
 				val *= 20;
@@ -1713,8 +1713,8 @@ void RIG_IC7100::set_auto_notch(int val)
 
 int RIG_IC7100::get_auto_notch()
 {
-	string cstr = "\x16\x41";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x41";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1726,7 +1726,7 @@ int RIG_IC7100::get_auto_notch()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				auto_notch_label("AN", true);
 				return true;
@@ -1798,8 +1798,8 @@ void RIG_IC7100::set_pbt_outer(int val)
 int RIG_IC7100::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1811,7 +1811,7 @@ int RIG_IC7100::get_pbt_inner()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1822,8 +1822,8 @@ int RIG_IC7100::get_pbt_inner()
 int RIG_IC7100::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1835,7 +1835,7 @@ int RIG_IC7100::get_pbt_outer()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1863,8 +1863,8 @@ void RIG_IC7100::set_noise(bool val)
 
 int RIG_IC7100::get_noise()
 {
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1876,7 +1876,7 @@ int RIG_IC7100::get_noise()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return progStatus.noise;
@@ -1897,8 +1897,8 @@ void RIG_IC7100::set_nb_level(int val)
 int  RIG_IC7100::get_nb_level()
 {
 	int val = progStatus.nb_level;
-	string cstr = "\x14\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1910,7 +1910,7 @@ int  RIG_IC7100::get_nb_level()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -1929,8 +1929,8 @@ void RIG_IC7100::set_noise_reduction(int val)
 
 int RIG_IC7100::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1942,7 +1942,7 @@ int RIG_IC7100::get_noise_reduction()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return progStatus.noise_reduction;
@@ -1964,8 +1964,8 @@ void RIG_IC7100::set_noise_reduction_val(int val)
 int RIG_IC7100::get_noise_reduction_val()
 {
 	int val = 0;
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1977,7 +1977,7 @@ int RIG_IC7100::get_noise_reduction_val()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = fm_bcd(replystr.substr(p+6),3);
 			val -= 8;
 			val /= 16;
@@ -2020,7 +2020,7 @@ void RIG_IC7100::get_band_selection(int v)
 
 	if (ret) {
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p + 8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
@@ -2045,7 +2045,7 @@ void RIG_IC7100::get_band_selection(int v)
 					break;
 				}
 			}
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -2060,9 +2060,9 @@ void RIG_IC7100::get_band_selection(int v)
 
 void RIG_IC7100::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? B.filter : A.filter);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? B.filter : A.filter);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
@@ -2118,7 +2118,7 @@ double RIG_IC7100::getVfoAdj()
 
 	if (ret) {
 		size_t p = replystr.find(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			vfo_ = num100(replystr.substr(p+8));
 		}
 	}
@@ -2127,7 +2127,7 @@ double RIG_IC7100::getVfoAdj()
 
 int RIG_IC7100::get_FILT(int mode)
 {
-	if (useB) return mode_filterB[mode];
+	if (inuse == onB) return mode_filterB[mode];
 	return mode_filterA[mode];
 }
 
@@ -2136,7 +2136,7 @@ void RIG_IC7100::set_FILT(int filter)
 	if (filter < 1 || filter > 3)
 		return;
 
-	if (useB) {
+	if (inuse == onB) {
 		B.filter = filter;
 		mode_filterB[B.imode] = filter;
 
@@ -2197,7 +2197,7 @@ const char *RIG_IC7100::FILT(int val)
 const char *RIG_IC7100::nextFILT()
 {
 	int val = A.filter;
-	if (useB) val = B.filter;
+	if (inuse == onB) val = B.filter;
 	val++;
 	if (val > 3) val = 1;
 	set_FILT(val);
@@ -2206,7 +2206,7 @@ const char *RIG_IC7100::nextFILT()
 
 void RIG_IC7100::set_FILTERS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_filterA[i];
@@ -2228,7 +2228,7 @@ std::string RIG_IC7100::get_FILTERS()
 		if (mode_filterB[i] < 1) mode_filterB[i] = 1;
 		if (mode_filterB[i] > 3) mode_filterB[i] = 3;
 	}
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_filterA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
