@@ -27,9 +27,11 @@
 #include <iostream>
 
 #include "icom/IC7300.h"
-#include "support.h"
+#include "status.h"
 #include "trace.h"
 
+#include "support.h"
+
 //=============================================================================
 // IC-7300
 
@@ -254,6 +256,8 @@ RIG_IC7300::RIG_IC7300() {
 	can_change_alt_vfo = true;
 	has_a2b = true;
 
+	inuse = onA;
+
 	can_synch_clock = true;
 
 	CW_sense = 0; // CW is LSB
@@ -289,6 +293,7 @@ void RIG_IC7300::selectA()
 	set_trace(1, "select A");
 	waitFB("select A");
 	seth();
+	inuse = onA;
 }
 
 void RIG_IC7300::selectB()
@@ -300,6 +305,7 @@ void RIG_IC7300::selectB()
 	set_trace(1, "select B");
 	waitFB("select B");
 	seth();
+	inuse = onB;
 }
 
 //======================================================================
@@ -446,12 +452,12 @@ bool RIG_IC7300::check ()
 
 unsigned long int RIG_IC7300::get_vfoA ()
 {
-	string resp;
+	std::string resp;
 
 	cmd.assign(pre_to).append("\x25");
 	resp.assign(pre_fm).append("\x25");
 
-	if (useB) {
+	if (inuse == onB) {
 		cmd  += '\x01';
 		resp += '\x01';
 	} else {
@@ -461,13 +467,12 @@ unsigned long int RIG_IC7300::get_vfoA ()
 
 	cmd.append(post);
 
-	get_trace(1, "get_vfoA()");
 	ret = waitFOR(12, "get vfo A");
-	geth();
+//	igett("vfo A");
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -484,7 +489,7 @@ void RIG_IC7300::set_vfoA (unsigned long int freq)
 	A.freq = freq;
 
 	cmd.assign(pre_to).append("\x25");
-	if (useB) cmd += '\x01';
+	if (inuse == onB) cmd += '\x01';
 	else      cmd += '\x00';
 
 	cmd.append( to_bcd_be( freq, 10) );
@@ -497,12 +502,12 @@ void RIG_IC7300::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC7300::get_vfoB ()
 {
-	string resp;
+	std::string resp;
 
 	cmd.assign(pre_to).append("\x25");
 	resp.assign(pre_fm).append("\x25");
 
-	if (useB) {
+	if (inuse == onB) {
 		cmd  += '\x00';
 		resp += '\x00';
 	} else {
@@ -512,13 +517,12 @@ unsigned long int RIG_IC7300::get_vfoB ()
 
 	cmd.append(post);
 
-	get_trace(1, "get_vfoB()");
 	ret = waitFOR(12, "get vfo B");
-	geth();
+//	igett("vfo B");
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -535,7 +539,7 @@ void RIG_IC7300::set_vfoB (unsigned long int freq)
 	B.freq = freq;
 
 	cmd.assign(pre_to).append("\x25");
-	if (useB) cmd += '\x00';
+	if (inuse == onB) cmd += '\x00';
 	else      cmd += '\x01';
 
 	cmd.append( to_bcd_be( freq, 10 ) );
@@ -567,24 +571,23 @@ int RIG_IC7300::get_modeA()
 	int md = 0;
 	size_t p;
 
-	string resp;
+	std::string resp;
 	cmd.assign(pre_to).append("\x26");
 	resp.assign(pre_fm).append("\x26");
 
-	if (useB)
+	if (inuse == onB)
 		cmd += '\x01';
 	else
 		cmd += '\x00';
 
 	cmd.append(post);
 
-	get_trace(1, "get_modeA()");
 	ret = waitFOR(10, "get mode A");
-	geth();
+	igett("mode A");
 
 	if (ret) {
 		p = replystr.rfind(resp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			goto end_wait_modeA;
 
 		if (replystr[p+6] == -1) { md = A.imode = 0; }
@@ -644,7 +647,7 @@ void RIG_IC7300::set_modeA(int val)
 	A.imode = val;
 	cmd.assign(pre_to);
 	cmd += '\x26';
-	if (useB)
+	if (inuse == onB)
 		cmd += '\x01';					// unselected vfo
 	else
 		cmd += '\x00';					// selected vfo
@@ -666,23 +669,22 @@ int RIG_IC7300::get_modeB()
 	int md = 0;
 	size_t p;
 
-	string resp;
+	std::string resp;
 	cmd.assign(pre_to).append("\x26");
 	resp.assign(pre_fm).append("\x26");
 
-	if (useB)
+	if (inuse == onB)
 		cmd += '\x00';   // active vfo
 	else
 		cmd += '\x01';   // inactive vfo
 	cmd.append(post);
 
-	get_trace(1, "get_modeB()");
 	ret = waitFOR(10, "get mode B");
-	geth();
+	igett("mode B");
 
 	if (ret) {
 		p = replystr.rfind(resp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			goto end_wait_modeB;
 
 		if (replystr[p+6] == -1) { md = filA = 0; }
@@ -740,7 +742,7 @@ void RIG_IC7300::set_modeB(int val)
 	B.imode = val;
 	cmd.assign(pre_to);
 	cmd += '\x26';
-	if (useB)
+	if (inuse == onB)
 		cmd += '\x00';					// selected vfo
 	else
 		cmd += '\x01';					// unselected vfo
@@ -759,7 +761,7 @@ void RIG_IC7300::set_modeB(int val)
 
 int RIG_IC7300::get_FILT(int mode)
 {
-	if (useB) return mode_filterB[mode];
+	if (inuse == onB) return mode_filterB[mode];
 	return mode_filterA[mode];
 }
 
@@ -768,7 +770,7 @@ void RIG_IC7300::set_FILT(int filter)
 	if (filter < 1 || filter > 3)
 		return;
 
-	if (useB) {
+	if (inuse == onB) {
 		B.filter = filter;
 		mode_filterB[B.imode] = filter;
 		cmd.assign(pre_to);
@@ -812,7 +814,7 @@ const char *RIG_IC7300::FILT(int val)
 const char * RIG_IC7300::nextFILT()
 {
 	int val = A.filter;
-	if (useB) val = B.filter;
+	if (inuse == onB) val = B.filter;
 	val++;
 	if (val > 3) val = 1;
 	set_FILT(val);
@@ -821,7 +823,7 @@ const char * RIG_IC7300::nextFILT()
 
 void RIG_IC7300::set_FILTERS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_filterA[i];
@@ -837,7 +839,7 @@ void RIG_IC7300::set_FILTERS(std::string s)
 
 std::string RIG_IC7300::get_FILTERS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++) {
 		if (mode_filterA[i] < 1) mode_filterA[i] = 1;
 		if (mode_filterA[i] > 3) mode_filterA[i] = 3;
@@ -853,7 +855,7 @@ std::string RIG_IC7300::get_FILTERS()
 
 std::string RIG_IC7300::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -863,7 +865,7 @@ std::string RIG_IC7300::get_BANDWIDTHS()
 
 void RIG_IC7300::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -897,15 +899,14 @@ int RIG_IC7300::get_split()
 	cmd.append("\x0F");
 	cmd.append( post );
 
-	get_trace(1, "get_split()");
 	ret = waitFOR(7, "get split");
-	geth();
+	igett("split");
 
 	if (ret) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x0F");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			read_split = replystr[p+5];
 		if (read_split != 0xFA) // fail byte
 			split = read_split;
@@ -918,22 +919,22 @@ int RIG_IC7300::get_bwA()
 {
 	if (A.imode == 3 || A.imode == 11) return 0; // FM, FM-D
 
-	if (useB) selectA();
+	int current_vfo = inuse;
+	if (current_vfo == onB) selectA();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
 	int bwval = A.iBW;
 
-	get_trace(1, "get_bwA()");
 	ret = waitFOR(8, "get_bwA");
-	geth();
+	igett("bw A");
 
 	if (ret) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x1A\x03");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			bwval = fm_bcd(replystr.substr(p+6), 2);
 	}
 	if (bwval != A.iBW) {
@@ -941,7 +942,7 @@ int RIG_IC7300::get_bwA()
 		mode_bwA[A.imode] = bwval;
 	}
 
-	if (useB) selectB();
+	if (current_vfo == onB) selectB();
 
 	return A.iBW;
 }
@@ -953,7 +954,9 @@ void RIG_IC7300::set_bwA(int val)
 	if (A.imode == 3 || A.imode == 11) return; // FM, FM-D
 
 	A.iBW = val;
-	if (useB) selectA();
+
+	int current_vfo = inuse;
+	if (current_vfo == onB) selectA();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
@@ -965,29 +968,29 @@ void RIG_IC7300::set_bwA(int val)
 
 	mode_bwA[A.imode] = val;
 
-	if (useB) selectB();
+	if (current_vfo == onB) selectB();
 }
 
 int RIG_IC7300::get_bwB()
 {
 	if (B.imode == 3 || B.imode == 11) return 0; // FM, FM-D
 
-	if (!useB) selectB();
+	int current_vfo = inuse;
+	if (current_vfo == onA) selectB();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
 	int bwval = B.iBW;
 
-	get_trace(1, "get_bwA()");
 	ret = waitFOR(8, "get_bwB");
-	geth();
+	igett("bw B");
 
 	if (ret) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x1A\x03");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			bwval = fm_bcd(replystr.substr(p+6), 2);
 	}
 	if (bwval != B.iBW) {
@@ -995,7 +998,7 @@ int RIG_IC7300::get_bwB()
 		mode_bwB[B.imode] = bwval;
 	}
 
-	if (!useB) selectA();
+	if (current_vfo == onA) selectA();
 
 	return B.iBW;
 }
@@ -1006,7 +1009,8 @@ void RIG_IC7300::set_bwB(int val)
 	if (B.imode == 3 || B.imode == 11) return; // FM, FM-D
 	B.iBW = val;
 
-	if (!useB) selectB();
+	int current_vfo = inuse;
+	if (current_vfo == onA) selectB();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
@@ -1018,7 +1022,7 @@ void RIG_IC7300::set_bwB(int val)
 
 	mode_bwB[B.imode] = val;
 
-	if (!useB) selectA();
+	if (current_vfo == onA) selectA();
 }
 
 // LSB  USB  AM   FM   CW  CW-R  RTTY  RTTY-R  LSB-D  USB-D  AM-D  FM-D
@@ -1083,7 +1087,7 @@ const char ** RIG_IC7300::bwtable(int m)
 int RIG_IC7300::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -1096,20 +1100,19 @@ int RIG_IC7300::def_bandwidth(int m)
 int RIG_IC7300::get_mic_gain()
 {
 	int val = 0;
-	string cstr = "\x14\x0B";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0B";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 
-	get_trace(1, "get_mic_gain()");
 	ret = waitFOR(9, "get mic");
-	geth();
+	igett("mic");
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	return val;
@@ -1169,7 +1172,7 @@ void RIG_IC7300::get_compression(int &on, int &val)
 
 	if (ret) {
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = (replystr[p+6] == 0x01);
 	}
 
@@ -1183,7 +1186,7 @@ void RIG_IC7300::get_compression(int &on, int &val)
 	if (ret) {
 		size_t p = replystr.find(resp);
 		int level = 0;
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			level = fm_bcd(replystr.substr(p+6), 3);
 			for (val = 0; val < 11; val++)
 				if (level <= comp_level[val]) break;
@@ -1315,7 +1318,7 @@ int RIG_IC7300::get_break_in()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			progStatus.break_in = replystr[p+6];
 			if (progStatus.break_in == 0) break_in_label("qsk");
 			else  if (progStatus.break_in == 1) break_in_label("SEMI");
@@ -1392,17 +1395,16 @@ int RIG_IC7300::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 
-	get_trace(1, "get_PTT()");
 	ret = waitFOR(8, "get PTT");
-	geth();
+//	igett("ptt");
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	return ptt_;
@@ -1431,8 +1433,8 @@ FE FE E0 7A 14 01 00 65 FD
 int RIG_IC7300::get_volume_control()
 {
 	int val = 0;
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1444,7 +1446,7 @@ int RIG_IC7300::get_volume_control()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	return (val);
@@ -1461,28 +1463,28 @@ void RIG_IC7300::set_power_control(double val)
 	cmd.append("\x14\x0A");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-	set_trace(1, "set power control");
+
 	waitFB("set power");
-	seth();
+
+	isett("set pwr");
 
 }
 
 double RIG_IC7300::get_power_control()
 {
 	int val = progStatus.power_level;
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 
-	get_trace(1, "get_power_control()");
 	ret = waitFOR(9, "get power");
-	geth();
+//	igett("power control");
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -1495,8 +1497,8 @@ void RIG_IC7300::get_pc_min_max_step(double &min, double &max, double &step)
 
 int RIG_IC7300::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1509,7 +1511,7 @@ int RIG_IC7300::get_smeter()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr / 2.41);
 			if (mtr > 100) mtr = 100;
@@ -1520,8 +1522,8 @@ int RIG_IC7300::get_smeter()
 
 double RIG_IC7300::get_voltmeter()
 {
-	string cstr = "\x15\x15";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x15";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1530,13 +1532,12 @@ double RIG_IC7300::get_voltmeter()
 	int mtr = 0;
 	double val = 0;
 
-	get_trace(1, "get_voltmeter()");
 	ret = waitFOR(9, "get voltmeter");
-	geth();
+	igett("voltmeter");
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			val = 0.026 * mtr + 9.782;
 			return val;
@@ -1548,24 +1549,37 @@ double RIG_IC7300::get_voltmeter()
 struct pwrpair {int mtr; float pwr;};
 
 static pwrpair pwrtbl[] = { 
-	{0, 0.0},
-	{21, 5.0},
-	{43,10.0}, 
-	{65, 15.0},
-	{83, 20.0}, 
-	{95, 25.0}, 
-	{105, 30.0},
-	{114, 35.0}, 
-	{124, 40.0}, 
-	{143, 50.0}, 
-	{183, 75.0},
-	{213, 100.0},
-	{255, 120.0 } };
+{0, 0},
+{2, 0.5},
+{3, 1.1},
+{4, 1.7},
+{6, 2.2},
+{12, 3},
+{15, 3.6},
+{21, 5},
+{25, 5.6},
+{31, 7},
+{34, 7.9},
+{40, 9.6},
+{42, 9.9},
+{43, 10},
+{46, 11},
+{49, 12},
+{65, 15},
+{83, 20},
+{95, 25},
+{105, 30},
+{118, 35},
+{126, 40},
+{143, 50},
+{183, 75},
+{220, 100},
+{255, 120} };
 
 int RIG_IC7300::get_power_out(void)
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1573,15 +1587,14 @@ int RIG_IC7300::get_power_out(void)
 	int mtr= 0;
 	int val = 0;
 
-	get_trace(1, "get_power_out()");
 	ret = waitFOR(9, "get power out");
-	geth();
+	igett("power out");
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = hex2val(replystr.substr(p+6, 2));
-			mtr = max(0, min(mtr, 255));
+			mtr = std::max(0, std::min(mtr, 255));
 			size_t i = 0;
 			for (i = 0; i < sizeof(pwrtbl) / sizeof(*pwrtbl) - 1; i++)
 				if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
@@ -1612,21 +1625,20 @@ static swrpair swrtbl[] = {
 
 int RIG_IC7300::get_swr(void)
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	int mtr= -1;
 
-	get_trace(1, "get_swr()");
 	ret = waitFOR(9, "get swr");
-	geth();
+	igett("swr");
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
 			for (i = 0; i < sizeof(swrtbl) / sizeof(swrpair) - 1; i++)
@@ -1646,21 +1658,20 @@ int RIG_IC7300::get_swr(void)
 int RIG_IC7300::get_alc(void)
 {
 	get_trace(1, "get_alc()");
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	int mtr= -1;
 
-	get_trace(1, "get_alc");
 	ret = waitFOR(9, "get alc");
-	geth();
+	igett("alc");
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /1.2);
 			if (mtr > 100) mtr = 100;
@@ -1683,8 +1694,8 @@ void RIG_IC7300::set_rf_gain(int val)
 int RIG_IC7300::get_rf_gain()
 {
 	int val = progStatus.rfgain;
-	string cstr = "\x14\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x02";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
@@ -1695,7 +1706,7 @@ int RIG_IC7300::get_rf_gain()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	return val;
@@ -1753,8 +1764,8 @@ void RIG_IC7300::set_preamp(int val)
 
 int RIG_IC7300::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1766,7 +1777,7 @@ int RIG_IC7300::get_preamp()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			preamp_level = replystr[p+6];
 			if (preamp_level == 1) {
 				preamp_label("Amp 1", preamp_level);
@@ -1813,7 +1824,7 @@ int RIG_IC7300::get_attenuator()
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x11';
 
 	get_trace(1, "get_attenuator()");
@@ -1822,7 +1833,7 @@ int RIG_IC7300::get_attenuator()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x20) {
 				atten_level = 1;
 				atten_label("20 dB", atten_level);
@@ -1849,8 +1860,8 @@ void RIG_IC7300::set_noise(bool val)
 int RIG_IC7300::get_noise()
 {
 	int val = progStatus.noise;
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1862,7 +1873,7 @@ int RIG_IC7300::get_noise()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = replystr[p+6];
 		}
 	}
@@ -1883,8 +1894,8 @@ void RIG_IC7300::set_nb_level(int val)
 int  RIG_IC7300::get_nb_level()
 {
 	int val = progStatus.nb_level;
-	string cstr = "\x14\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1896,7 +1907,7 @@ int  RIG_IC7300::get_nb_level()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -1915,8 +1926,8 @@ void RIG_IC7300::set_noise_reduction(int val)
 
 int RIG_IC7300::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1928,7 +1939,7 @@ int RIG_IC7300::get_noise_reduction()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return progStatus.noise_reduction;
@@ -1966,8 +1977,8 @@ void RIG_IC7300::set_noise_reduction_val(int val)
 int RIG_IC7300::get_noise_reduction_val()
 {
 	int val = progStatus.noise_reduction_val;
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1979,7 +1990,7 @@ int RIG_IC7300::get_noise_reduction_val()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = fm_bcd(replystr.substr(p+6),3);
 			val -= 8;
 			val /= 16;
@@ -2003,8 +2014,8 @@ void RIG_IC7300::set_squelch(int val)
 int  RIG_IC7300::get_squelch()
 {
 	int val = progStatus.squelch;
-	string cstr = "\x14\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -2016,7 +2027,7 @@ int  RIG_IC7300::get_squelch()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -2036,8 +2047,8 @@ void RIG_IC7300::set_auto_notch(int val)
 
 int RIG_IC7300::get_auto_notch()
 {
-	string cstr = "\x16\x41";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x41";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -2049,7 +2060,7 @@ int RIG_IC7300::get_auto_notch()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				auto_notch_label("AN", true);
 				return true;
@@ -2113,8 +2124,8 @@ bool RIG_IC7300::get_notch(int &val)
 	bool on = false;
 	val = 1500;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -2127,7 +2138,7 @@ bool RIG_IC7300::get_notch(int &val)
 	if (ret) {
 		size_t p = replystr.rfind(resp);
 
-		if (p == string::npos) {
+		if (p == std::string::npos) {
 			return 0;
 		}
 		on = replystr[p + 6];
@@ -2145,7 +2156,7 @@ bool RIG_IC7300::get_notch(int &val)
 
 		if (ret) {
 			size_t p = replystr.rfind(resp);
-			if (p == string::npos) {
+			if (p == std::string::npos) {
 				return 0;
 			} else {
 				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
@@ -2204,11 +2215,10 @@ int  RIG_IC7300::get_agc()
 	get_trace(1, "get_agc");
 	ret = waitFOR(8, "get AGC");
 	geth();
-
 	if (ret) {
 		size_t p = replystr.find(retstr);
-		if (p != string::npos)
-			agcval = replystr[p+6]; // 1 == off, 2 = FAST, 3 = MED, 4 = SLOW
+		if (p != std::string::npos)
+			agcval = replystr[p+6]; // 1 == FAST, 2 = MED, 3 = SLOW
 	}
 	return agcval;
 }
@@ -2314,8 +2324,8 @@ void RIG_IC7300::set_pbt_outer(int val)
 int RIG_IC7300::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -2327,7 +2337,7 @@ int RIG_IC7300::get_pbt_inner()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -2338,8 +2348,8 @@ int RIG_IC7300::get_pbt_inner()
 int RIG_IC7300::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -2351,7 +2361,7 @@ int RIG_IC7300::get_pbt_outer()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -2393,7 +2403,7 @@ double RIG_IC7300::getVfoAdj()
 
 	if (ret) {
 		size_t p = replystr.find(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			vfo_ = 100 * (replystr[p+8] & 0x0F) + 10 * ((replystr[p+9] & 0xF0) >> 4) + (replystr[p+9] & 0x0F);
 			vfo_ /= 2.55;
 		}
@@ -2449,7 +2459,7 @@ void RIG_IC7300::get_band_selection(int v)
 
 	if (ret) {
 		size_t p = replystr.rfind(retstr);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
@@ -2464,7 +2474,7 @@ void RIG_IC7300::get_band_selection(int v)
 			for (index = 0; index < sizeof(PL_tones) / sizeof(*PL_tones); index++)
 				if (tone == PL_tones[index]) break;
 			rTONE = index;
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -2480,9 +2490,9 @@ void RIG_IC7300::get_band_selection(int v)
 void RIG_IC7300::set_band_selection(int v)
 {
 //	set_trace(1, "set_band_selection()");
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? B.filter : A.filter);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? B.filter : A.filter);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
