@@ -22,9 +22,11 @@
 #include <sstream>
 
 #include "icom/IC7610.h"
-#include "support.h"
+#include "status.h"
 #include "trace.h"
 
+#include "support.h"
+
 //=============================================================================
 // IC-7610
 
@@ -298,8 +300,8 @@ void RIG_IC7610::selectA()
 	cmd += '\xD0';
 	cmd.append(post);
 	waitFB("select A");
-
 	set_trace(2, "selectA() ", str2hex(cmd.c_str(), cmd.length()));
+	inuse = onA;
 }
 
 void RIG_IC7610::selectB()
@@ -308,8 +310,8 @@ void RIG_IC7610::selectB()
 	cmd += '\xD1';
 	cmd.append(post);
 	waitFB("select B");
-
 	set_trace(2, "selectB() ", str2hex(cmd.c_str(), cmd.length()));
+	inuse = onB;
 }
 
 //======================================================================
@@ -360,7 +362,7 @@ void RIG_IC7610::set_xcvr_auto_off()
 
 bool RIG_IC7610::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -383,7 +385,7 @@ bool RIG_IC7610::check ()
 
 unsigned long int RIG_IC7610::get_vfoA ()
 {
-	string resp;
+	std::string resp;
 
 	resp.assign(pre_fm).append("\x25");
 	resp += '\x00';
@@ -393,7 +395,7 @@ unsigned long int RIG_IC7610::get_vfoA ()
 	cmd.append(post);
 	if (waitFOR(12, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -423,7 +425,7 @@ void RIG_IC7610::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC7610::get_vfoB ()
 {
-	string resp;
+	std::string resp;
 
 	resp.assign(pre_fm).append("\x25");
 	resp += '\x01';
@@ -433,7 +435,7 @@ unsigned long int RIG_IC7610::get_vfoB ()
 	cmd.append(post);
 	if (waitFOR(12, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -482,7 +484,7 @@ int RIG_IC7610::get_modeA()
 	int md = 0;
 	size_t p;
 
-	string resp;
+	std::string resp;
 	resp.assign(pre_fm).append("\x26");
 
 	cmd.assign(pre_to).append("\x26");
@@ -491,7 +493,7 @@ int RIG_IC7610::get_modeA()
 
 	if (waitFOR(10, "get mode A")) {
 		p = replystr.rfind(resp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			goto end_wait_modeA;
 
 		if (replystr[p+6] == -1) { A.imode = A.filter = 0; return A.imode; }
@@ -559,7 +561,7 @@ int RIG_IC7610::get_modeB()
 	int md = 0;
 	size_t p;
 
-	string resp;
+	std::string resp;
 	resp.assign(pre_fm).append("\x26");
 
 	cmd.assign(pre_to).append("\x26");
@@ -568,7 +570,7 @@ int RIG_IC7610::get_modeB()
 
 	if (waitFOR(10, "get mode B")) {
 		p = replystr.rfind(resp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			goto end_wait_modeB;
 
 		if (replystr[p+6] == -1) { B.imode = B.filter = 0; return B.imode; }
@@ -630,13 +632,13 @@ void RIG_IC7610::set_modeB(int val)
 
 int RIG_IC7610::get_FILT(int mode)
 {
-	if (useB) return mode_filterB[mode];
+	if (inuse == onB) return mode_filterB[mode];
 	return mode_filterA[mode];
 }
 
 void RIG_IC7610::set_FILT(int filter)
 {
-	if (useB) {
+	if (inuse == onB) {
 		B.filter = filter;
 		mode_filterB[B.imode] = filter;
 		cmd.assign(pre_to);
@@ -696,7 +698,7 @@ const char *RIG_IC7610::FILT(int val)
 const char * RIG_IC7610::nextFILT()
 {
 	int val = A.filter;
-	if (useB) val = B.filter;
+	if (inuse == onB) val = B.filter;
 	val++;
 	if (val > 3) val = 1;
 	set_FILT(val);
@@ -705,7 +707,7 @@ const char * RIG_IC7610::nextFILT()
 
 void RIG_IC7610::set_FILTERS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_filterA[i];
@@ -715,7 +717,7 @@ void RIG_IC7610::set_FILTERS(std::string s)
 
 std::string RIG_IC7610::get_FILTERS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_filterA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -725,7 +727,7 @@ std::string RIG_IC7610::get_FILTERS()
 
 std::string RIG_IC7610::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -735,7 +737,7 @@ std::string RIG_IC7610::get_BANDWIDTHS()
 
 void RIG_IC7610::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -767,10 +769,10 @@ int RIG_IC7610::get_split()
 	cmd.append("\x0F");
 	cmd.append( post );
 	if (waitFOR(7, "get split")) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x0F");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			read_split = replystr[p+5];
 		if (read_split != 0xFA) // fail byte
 			split = read_split;
@@ -786,17 +788,18 @@ int RIG_IC7610::get_bwA()
 	if (A.imode == 3 || 
 		A.imode == 13 || A.imode == 17 || A.imode == 21) return 0; // FM, FM-D
 
-	if (useB) selectA();
+	int current_vfo = inuse;
+	if (current_vfo == onB) selectA();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
 	int bwval = A.iBW;
 	if (waitFOR(8, "get_bwA")) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x1A\x03");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			bwval = fm_bcd(replystr.substr(p+6), 2);
 	}
 	if (bwval != A.iBW) {
@@ -804,7 +807,7 @@ int RIG_IC7610::get_bwA()
 		mode_bwA[A.imode] = bwval;
 	}
 
-	if (useB) selectB();
+	if (current_vfo == onB) selectB();
 
 	get_trace(2, "get_bwA() ", str2hex(replystr.c_str(), replystr.length()));
 
@@ -818,7 +821,8 @@ void RIG_IC7610::set_bwA(int val)
 		A.imode == 13 || A.imode == 17 || A.imode == 21) return; // FM, FM-D
 
 	A.iBW = val;
-	if (useB) selectA();
+	int current_vfo = inuse;
+	if (current_vfo == onB) selectA();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
@@ -829,7 +833,7 @@ void RIG_IC7610::set_bwA(int val)
 	mode_bwA[A.imode] = val;
 	set_trace(2, "set_bwA() ", str2hex(cmd.c_str(), cmd.length()));
 
-	if (useB) selectB();
+	if (current_vfo == onB) selectB();
 }
 
 int RIG_IC7610::get_bwB()
@@ -837,17 +841,18 @@ int RIG_IC7610::get_bwB()
 	if (B.imode == 3 || 
 		B.imode == 13 || B.imode == 17 || B.imode == 21) return 0; // FM, FM-D
 
-	if (!useB) selectB();
+	int current_vfo = inuse;
+	if (current_vfo == onA) selectB();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
 	int bwval = B.iBW;
 	if (waitFOR(8, "get_bwB")) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x1A\x03");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			bwval = fm_bcd(replystr.substr(p+6), 2);
 	}
 	if (bwval != B.iBW) {
@@ -855,7 +860,7 @@ int RIG_IC7610::get_bwB()
 		mode_bwB[B.imode] = bwval;
 	}
 
-	if (!useB) selectA();
+	if (current_vfo == onA) selectA();
 
 	get_trace(2, "get_bwB() ", str2hex(replystr.c_str(), replystr.length()));
 
@@ -869,7 +874,8 @@ void RIG_IC7610::set_bwB(int val)
 
 	B.iBW = val;
 
-	if (!useB) selectB();
+	int current_vfo = inuse;
+	if (current_vfo == onA) selectB();
 
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
@@ -880,7 +886,7 @@ void RIG_IC7610::set_bwB(int val)
 	mode_bwB[B.imode] = val;
 	set_trace(2, "set_bwB() ", str2hex(cmd.c_str(), cmd.length()));
 
-	if (!useB) selectA();
+	if (current_vfo == onA) selectA();
 }
 
 // LSB  USB  AM   FM   CW  CW-R  RTTY  RTTY-R  PSK   PSK-R
@@ -952,7 +958,7 @@ const char ** RIG_IC7610::bwtable(int m)
 int RIG_IC7610::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -965,15 +971,15 @@ int RIG_IC7610::def_bandwidth(int m)
 int RIG_IC7610::get_mic_gain()
 {
 	int val = 0;
-	string cstr = "\x14\x0B";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0B";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get mic")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	get_trace(2, "get_mic_gain() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1028,7 +1034,7 @@ void RIG_IC7610::get_compression(int &on, int &val)
 
 	if (waitFOR(8, "get comp on/off")) {
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = (replystr[p+6] == 0x01);
 	}
 	get_trace(2, "get_comp on/off() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1039,7 +1045,7 @@ void RIG_IC7610::get_compression(int &on, int &val)
 	if (waitFOR(9, "get comp level")) {
 		size_t p = replystr.find(resp);
 		int level = 0;
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			level = fm_bcd(replystr.substr(p+6), 3);
 			for (val = 0; val < 11; val++)
 				if (level <= comp_level[val]) break;
@@ -1159,7 +1165,7 @@ int RIG_IC7610::get_break_in()
 	resp.assign(pre_fm);
 	if (waitFOR(8, "get break in")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			progStatus.break_in = replystr[p+6];
 			if (progStatus.break_in == 0) break_in_label("qsk");
 			else  if (progStatus.break_in == 1) break_in_label("SEMI");
@@ -1233,12 +1239,12 @@ int RIG_IC7610::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 	if (waitFOR(8, "get PTT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	get_trace(2, "get_PTT() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1267,15 +1273,15 @@ FE FE E0 7A 14 01 00 65 FD
 int RIG_IC7610::get_volume_control()
 {
 	int val = 0;
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	get_trace(2, "get_volume_control() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1300,14 +1306,14 @@ void RIG_IC7610::set_power_control(double val)
 double RIG_IC7610::get_power_control()
 {
 	int val = progStatus.power_level;
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get power")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	get_trace(2, "get_power_control() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1321,8 +1327,8 @@ void RIG_IC7610::get_pc_min_max_step(double &min, double &max, double &step)
 
 int RIG_IC7610::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1330,7 +1336,7 @@ int RIG_IC7610::get_smeter()
 	int mtr= -1;
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.41);
 			if (mtr > 100) mtr = 100;
@@ -1341,8 +1347,8 @@ int RIG_IC7610::get_smeter()
 
 double RIG_IC7610::get_voltmeter()
 {
-	string cstr = "\x15\x15";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x15";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1357,7 +1363,7 @@ double RIG_IC7610::get_voltmeter()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			val = 6.0 * mtr / 61.0 - 5.0;
 			return val;
@@ -1385,8 +1391,8 @@ static pwrpair pwrtbl[] = {
 
 int RIG_IC7610::get_power_out(void)
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1394,7 +1400,7 @@ int RIG_IC7610::get_power_out(void)
 	int mtr= 0;
 	if (waitFOR(9, "get power out")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
 			for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
@@ -1429,8 +1435,8 @@ static swrpair swrtbl[] = {
 
 int RIG_IC7610::get_swr(void)
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1438,7 +1444,7 @@ int RIG_IC7610::get_swr(void)
 	int mtr= -1;
 	if (waitFOR(9, "get swr")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
 			for (i = 0; i < sizeof(swrtbl) / sizeof(swrpair) - 1; i++)
@@ -1457,8 +1463,8 @@ int RIG_IC7610::get_swr(void)
 
 int RIG_IC7610::get_alc(void)
 {
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1466,7 +1472,7 @@ int RIG_IC7610::get_alc(void)
 	int mtr= -1;
 	if (waitFOR(9, "get alc")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /1.2);
 			if (mtr > 100) mtr = 100;
@@ -1488,14 +1494,14 @@ void RIG_IC7610::set_rf_gain(int val)
 int RIG_IC7610::get_rf_gain()
 {
 	int val = progStatus.rfgain;
-	string cstr = "\x14\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x02";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get RF")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	get_trace(2, "get_rf_gain() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1546,15 +1552,15 @@ void RIG_IC7610::set_preamp(int val)
 
 int RIG_IC7610::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get Preamp Level")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			preamp_level = replystr[p+6];
 			if (preamp_level == 1) {
 				preamp_label("Amp 1", true);
@@ -1583,15 +1589,15 @@ void RIG_IC7610::set_noise(bool val)
 int RIG_IC7610::get_noise()
 {
 	int val = progStatus.noise;
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = replystr[p+6];
 		}
 	}
@@ -1612,15 +1618,15 @@ void RIG_IC7610::set_nb_level(int val)
 int  RIG_IC7610::get_nb_level()
 {
 	int val = progStatus.nb_level;
-	string cstr = "\x14\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NB level")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	get_trace(2, "get_nb_level() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1639,15 +1645,15 @@ void RIG_IC7610::set_noise_reduction(int val)
 
 int RIG_IC7610::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get NR")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	get_trace(2, "get_noise_reduction() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1685,15 +1691,15 @@ void RIG_IC7610::set_noise_reduction_val(int val)
 int RIG_IC7610::get_noise_reduction_val()
 {
 	int val = progStatus.noise_reduction_val;
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NRval")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = fm_bcd(replystr.substr(p+6),3);
 			val -= 8;
 			val /= 16;
@@ -1716,15 +1722,15 @@ void RIG_IC7610::set_squelch(int val)
 int  RIG_IC7610::get_squelch()
 {
 	int val = progStatus.squelch;
-	string cstr = "\x14\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get squelch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	get_trace(2, "get_squelch() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1744,8 +1750,8 @@ void RIG_IC7610::set_auto_notch(int val)
 
 int RIG_IC7610::get_auto_notch()
 {
-	string cstr = "\x16\x41";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x41";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1753,7 +1759,7 @@ int RIG_IC7610::get_auto_notch()
 	if (waitFOR(8, "get AN")) {
 		get_trace(2, "get_auto_notch() ", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				auto_notch_label("AN", true);
 				return true;
@@ -1793,8 +1799,8 @@ bool RIG_IC7610::get_notch(int &val)
 {
 	bool on = false;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1802,7 +1808,7 @@ bool RIG_IC7610::get_notch(int &val)
 	if (waitFOR(8, "get notch")) {
 		get_trace(2, "get_notch() ", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6] ? 1 : 0;
 		cmd = pre_to;
 		resp = pre_fm;
@@ -1813,7 +1819,7 @@ bool RIG_IC7610::get_notch(int &val)
 		if (waitFOR(9, "get notch val")) {
 			get_trace(2, "get_notch_val() ", str2hex(replystr.c_str(), replystr.length()));
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				val = fm_bcd(replystr.substr(p+6),3);
 				val = (val - 53) * 20;
 				if (val < 0) val = 0;
@@ -1839,7 +1845,7 @@ int  RIG_IC7610::get_agc()
 	cmd.append(post);
 	if (waitFOR(8, "get AGC")) {
 		size_t p = replystr.find(pre_fm);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			agcval = replystr[p+6]; // 1 == off, 2 = FAST, 3 = MED, 4 = SLOW
 	}
 	get_trace(2, "get_agc() ", str2hex(replystr.c_str(), replystr.length()));
@@ -1940,15 +1946,15 @@ void RIG_IC7610::set_pbt_outer(int val)
 int RIG_IC7610::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1963,15 +1969,15 @@ int RIG_IC7610::get_pbt_outer()
 	get_digi_sel();
 
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -2003,7 +2009,7 @@ double RIG_IC7610::getVfoAdj()
 
 	if (waitFOR(11, "get vfo adj")) {
 		size_t p = replystr.find(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			vfo_ = fm_bcd(replystr.substr(p+8), 4);
 		}
 	}
@@ -2027,7 +2033,7 @@ int RIG_IC7610::get_digi_sel()
 	cmd.append(post);
 	if (waitFOR(8, "get AGC")) {
 		size_t p = replystr.find(pre_fm);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			progStatus.digi_sel_on_off = replystr[p+6];
 	}
 	get_trace(2, "get_digi_sel() ", str2hex(replystr.c_str(), replystr.length()));
@@ -2051,7 +2057,7 @@ int RIG_IC7610::get_digi_val()
 	cmd.append( post );
 	if (waitFOR(9, "get digi val")) {
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			progStatus.digi_sel_val = num100(replystr.substr(p+6));
 			Fl::awake(set_ic7610_digi_sel_val);
 		}
@@ -2078,7 +2084,7 @@ int RIG_IC7610::get_dual_watch()
 	cmd += '\x07';
 	cmd += '\xC2';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	cmd += '\x07'; cmd += '\xC2';
 	if (waitFOR(8, "get dual watch")) {
 		size_t p = replystr.rfind(resp);
@@ -2113,11 +2119,11 @@ int RIG_IC7610::get_attenuator()
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x11';
 	if (waitFOR(7, "get ATT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			atten_level = replystr[p+5];
 			size_t i = 0;
 			for (i = 0; i < sizeof(attval); i++) {
@@ -2175,7 +2181,7 @@ void RIG_IC7610::get_band_selection(int v)
 	if (waitFOR(23, "get band stack")) {
 		get_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
@@ -2211,7 +2217,7 @@ void RIG_IC7610::get_band_selection(int v)
 				default:
 						break;
 			}
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -2227,9 +2233,9 @@ void RIG_IC7610::get_band_selection(int v)
 
 void RIG_IC7610::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? filB : filA);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? filB : filA);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
