@@ -20,6 +20,8 @@
 
 #include "icom/IC7700.h"
 #include "debug.h"
+#include "status.h"
+
 #include "support.h"
 
 //=============================================================================
@@ -202,6 +204,7 @@ void RIG_IC7700::selectA()
 	cmd.append(post);
 	waitFB("select A");
 	isett("selectA");
+	inuse = onA;
 }
 
 void RIG_IC7700::selectB()
@@ -212,6 +215,7 @@ void RIG_IC7700::selectB()
 	cmd.append(post);
 	waitFB("select B");
 	isett("selectB");
+	inuse = onB;
 }
 
 void RIG_IC7700::set_modeA(int val)
@@ -244,7 +248,7 @@ int RIG_IC7700::get_modeA()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 	if (waitFOR(8, "get mode A")) {
 		igett("get mode A");
@@ -306,7 +310,7 @@ int RIG_IC7700::get_modeB()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 	if (waitFOR(8, "get mode B")) {
 		igett("get mode B");
@@ -345,7 +349,7 @@ int RIG_IC7700::get_bwA()
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x1a\x03");
 	if (waitFOR(8, "get bw A")) {
 		igett("get bw A");
@@ -372,7 +376,7 @@ int RIG_IC7700::get_bwB()
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x1a\x03");
 	if (waitFOR(8, "get bw B")) {
 		igett("get bw B");
@@ -485,7 +489,7 @@ int RIG_IC7700::get_attenuator()
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x11';
 	if (waitFOR(7, "get attenuator")) {
 		igett("get attenuator");
@@ -635,13 +639,13 @@ int RIG_IC7700::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 	if (waitFOR(8, "get PTT")) {
 		igett("get ptt");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	return ptt_;
@@ -678,8 +682,8 @@ void RIG_IC7700::set_pbt_outer(int val)
 int RIG_IC7700::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -687,7 +691,7 @@ int RIG_IC7700::get_pbt_inner()
 	if (waitFOR(9, "get pbt inner")) {
 		igett("get pbt inner");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -698,8 +702,8 @@ int RIG_IC7700::get_pbt_inner()
 int RIG_IC7700::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -707,7 +711,7 @@ int RIG_IC7700::get_pbt_outer()
 	if (waitFOR(9, "get pbt outer")) {
 		igett("get pbt inner");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -717,7 +721,7 @@ int RIG_IC7700::get_pbt_outer()
 
 const char *RIG_IC7700::FILT(int &val)
 {
-	if (useB) {
+	if (inuse == onB) {
 		if (filB < 0) filB = 0;
 		if (filB > 3) filB = 3;
 		val = filB;
@@ -733,7 +737,7 @@ const char *RIG_IC7700::FILT(int &val)
 
 const char *RIG_IC7700::nextFILT()
 {
-	if (useB) {
+	if (inuse == onB) {
 		filB++;
 		if (filB > 3) filB = 1;
 		set_modeB(B.imode);
@@ -781,7 +785,7 @@ void RIG_IC7700::get_band_selection(int v)
 	if (waitFOR(23, "get band stack")) {
 		igett("get band stack");
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
@@ -799,7 +803,7 @@ void RIG_IC7700::get_band_selection(int v)
 			if ((bandmode == 1) && banddata) bandmode = 11;
 			if ((bandmode == 2) && banddata) bandmode = 12;
 			if ((bandmode == 3) && banddata) bandmode = 13;
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -815,9 +819,9 @@ void RIG_IC7700::get_band_selection(int v)
 
 void RIG_IC7700::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int fil = (useB ? filB : filA);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int fil = (inuse == onB ? filB : filA);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
@@ -887,15 +891,15 @@ bool RIG_IC7700::get_notch(int &val)
 	bool on = false;
 	val = 1500;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6];
 		cmd = pre_to;
 		resp = pre_fm;
@@ -905,7 +909,7 @@ bool RIG_IC7700::get_notch(int &val)
 		cmd.append(post);
 		if (waitFOR(9, "notch val")) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
 				val -= 128;
 				val *= 20;
