@@ -20,6 +20,8 @@
 
 #include "icom/IC7851.h"
 
+#include "support.h"
+
 bool IC7851_DEBUG = true;
 
 //=============================================================================
@@ -232,6 +234,7 @@ void RIG_IC7851::selectA()
 	cmd.append(post);
 	sendICcommand(cmd, 6);
 	waitFB("Select A");
+	inuse = onA;
 }
 
 void RIG_IC7851::selectB()
@@ -241,6 +244,7 @@ void RIG_IC7851::selectB()
 	cmd.append(post);
 	sendICcommand(cmd, 6);
 	waitFB("Select B");
+	inuse = onB;
 }
 
 void RIG_IC7851::set_xcvr_auto_on()
@@ -277,7 +281,7 @@ void RIG_IC7851::set_xcvr_auto_off()
 
 bool RIG_IC7851::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -291,12 +295,12 @@ static int ret = 0;
 
 unsigned long int RIG_IC7851::get_vfoA ()
 {
-	string resp;
+	std::string resp;
 
 	cmd.assign(pre_to).append("\x25");
 	resp.assign(pre_fm).append("\x25");
 
-	if (useB) {
+	if (inuse == onA) {
 		cmd  += '\x01';
 		resp += '\x01';
 	} else {
@@ -312,7 +316,7 @@ unsigned long int RIG_IC7851::get_vfoA ()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -328,7 +332,7 @@ void RIG_IC7851::set_vfoA (unsigned long int freq)
 	A.freq = freq;
 
 	cmd.assign(pre_to).append("\x25");
-	if (useB) cmd += '\x01';
+	if (inuse == onA) cmd += '\x01';
 	else      cmd += '\x00';
 
 	cmd.append( to_bcd_be( freq, 10) );
@@ -341,12 +345,12 @@ void RIG_IC7851::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC7851::get_vfoB ()
 {
-	string resp;
+	std::string resp;
 
 	cmd.assign(pre_to).append("\x25");
 	resp.assign(pre_fm).append("\x25");
 
-	if (useB) {
+	if (inuse == onA) {
 		cmd  += '\x00';
 		resp += '\x00';
 	} else {
@@ -362,7 +366,7 @@ unsigned long int RIG_IC7851::get_vfoB ()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -378,7 +382,7 @@ void RIG_IC7851::set_vfoB (unsigned long int freq)
 	B.freq = freq;
 
 	cmd.assign(pre_to).append("\x25");
-	if (useB) cmd += '\x00';
+	if (inuse == onA) cmd += '\x00';
 	else      cmd += '\x01';
 
 	cmd.append( to_bcd_be( freq, 10 ) );
@@ -411,10 +415,10 @@ int RIG_IC7851::get_split()
 	cmd.append("\x0F");
 	cmd.append( post );
 	if (waitFOR(7, "get split")) {
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x0F");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			read_split = replystr[p+5];
 		if (read_split != 0xFA) // fail byte
 			split = read_split;
@@ -469,7 +473,7 @@ int RIG_IC7851::get_modeA()
 	int md = 0;
 	size_t p;
 
-	string resp;
+	std::string resp;
 	resp.assign(pre_fm).append("\x26");
 
 	cmd.assign(pre_to).append("\x26");
@@ -478,7 +482,7 @@ int RIG_IC7851::get_modeA()
 
 	if (waitFOR(10, "get mode A")) {
 		p = replystr.rfind(resp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			goto end_wait_modeA;
 
 		if (replystr[p+6] == -1) { A.imode = A.filter = 0; return A.imode; }
@@ -543,7 +547,7 @@ int RIG_IC7851::get_modeB()
 	int md = 0;
 	size_t p;
 
-	string resp;
+	std::string resp;
 	resp.assign(pre_fm).append("\x26");
 
 	cmd.assign(pre_to).append("\x26");
@@ -552,7 +556,7 @@ int RIG_IC7851::get_modeB()
 
 	if (waitFOR(10, "get mode B")) {
 		p = replystr.rfind(resp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			goto end_wait_modeB;
 
 		if (replystr[p+6] == -1) { B.imode = B.filter = 0; return B.imode; }
@@ -851,7 +855,7 @@ void RIG_IC7851::set_cw_wpm()
 //	cmd.append("\x14\x0C");
 //	if (waitFOR(9, "get WPM")) {
 //		size_t p = replystr.rfind(resp);
-//		if (p != string::npos) {
+//		if (p != std::string::npos) {
 //			wpm = replystr[p + 6];
 //			
 //	}
@@ -917,12 +921,12 @@ int RIG_IC7851::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 	if (waitFOR(8, "get PTT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	return ptt_;
@@ -946,15 +950,15 @@ void RIG_IC7851::set_volume_control(int val)
 int RIG_IC7851::get_volume_control()
 {
 	int val = progStatus.volume;
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	return val;
@@ -967,8 +971,8 @@ void RIG_IC7851::get_vol_min_max_step(int &min, int &max, int &step)
 
 int RIG_IC7851::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -976,7 +980,7 @@ int RIG_IC7851::get_smeter()
 	int mtr= -1;
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -1001,8 +1005,8 @@ static pwrpair pwrtbl[] = {
 
 int RIG_IC7851::get_power_out(void)
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1010,7 +1014,7 @@ int RIG_IC7851::get_power_out(void)
 	int mtr= 0;
 	if (waitFOR(9, "get power out")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
 			for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
@@ -1029,8 +1033,8 @@ int RIG_IC7851::get_power_out(void)
 
 int RIG_IC7851::get_swr(void) 
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1038,7 +1042,7 @@ int RIG_IC7851::get_swr(void)
 	int mtr= -1;
 	if (waitFOR(9, "get swr")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -1049,8 +1053,8 @@ int RIG_IC7851::get_swr(void)
 
 int RIG_IC7851::get_alc(void)
 {
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1058,7 +1062,7 @@ int RIG_IC7851::get_alc(void)
 	int mtr= -1;
 	if (waitFOR(9, "get alc")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -1096,15 +1100,15 @@ void RIG_IC7851::set_pbt_outer(int val)
 int RIG_IC7851::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1116,15 +1120,15 @@ int RIG_IC7851::get_pbt_inner()
 int RIG_IC7851::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1168,7 +1172,7 @@ void RIG_IC7851::get_band_selection(int v)
 	if (waitFOR(23, "get band stack")) {
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
@@ -1190,7 +1194,7 @@ void RIG_IC7851::get_band_selection(int v)
 				bandmode = ((banddata == 0x10) ? 13 : 
 							(banddata == 0x20) ? 14 :
 							(banddata == 0x30) ? 15 : 1);
-			if (useB) {
+			if (inuse == onA) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -1206,8 +1210,8 @@ void RIG_IC7851::get_band_selection(int v)
 
 void RIG_IC7851::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
@@ -1274,15 +1278,15 @@ bool RIG_IC7851::get_notch(int &val)
 	bool on = false;
 	val = 1500;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6];
 		cmd = pre_to;
 		resp = pre_fm;
@@ -1292,7 +1296,7 @@ bool RIG_IC7851::get_notch(int &val)
 		cmd.append(post);
 		if (waitFOR(9, "notch val")) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
 				val -= 128;
 				val *= 20;
