@@ -22,6 +22,8 @@
 
 #include "icom/IC9700.h"
 
+#include "support.h"
+
 //=============================================================================
 // IC-9700
 
@@ -317,9 +319,9 @@ void RIG_IC9700::selectA()
 	cmd += '\x07';
 	cmd += '\xD0';
 	cmd.append(post);
-
 	waitFB("select A");
 	set_trace(2, "selectA()", str2hex(replystr.c_str(), replystr.length()));
+	inuse = onA;
 }
 
 void RIG_IC9700::selectB()
@@ -330,11 +332,12 @@ void RIG_IC9700::selectB()
 	cmd.append(post);
 	waitFB("select B");
 	set_trace(2, "selectB()", str2hex(replystr.c_str(), replystr.length()));
+	inuse = onB;
 }
 
 bool RIG_IC9700::check ()
 {
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -348,12 +351,12 @@ static int ret = 0;
 
 unsigned long int RIG_IC9700::get_vfoA ()
 {
-	string resp;
+	std::string resp;
 
 	cmd.assign(pre_to).append("\x25");
 	resp.assign(pre_fm).append("\x25");
 
-	if (useB) {
+	if (inuse == onB) {
 		cmd  += '\x01';
 		resp += '\x01';
 	} else {
@@ -369,7 +372,7 @@ unsigned long int RIG_IC9700::get_vfoA ()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -385,7 +388,7 @@ void RIG_IC9700::set_vfoA (unsigned long int freq)
 	A.freq = freq;
 
 	cmd.assign(pre_to).append("\x25");
-	if (useB) cmd += '\x01';
+	if (inuse == onB) cmd += '\x01';
 	else      cmd += '\x00';
 
 	cmd.append( to_bcd_be( freq, 10) );
@@ -398,12 +401,12 @@ void RIG_IC9700::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_IC9700::get_vfoB ()
 {
-	string resp;
+	std::string resp;
 
 	cmd.assign(pre_to).append("\x25");
 	resp.assign(pre_fm).append("\x25");
 
-	if (useB) {
+	if (inuse == onB) {
 		cmd  += '\x00';
 		resp += '\x00';
 	} else {
@@ -419,7 +422,7 @@ unsigned long int RIG_IC9700::get_vfoB ()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == -1)
 				A.freq = 0;
 			else
@@ -435,7 +438,7 @@ void RIG_IC9700::set_vfoB (unsigned long int freq)
 	B.freq = freq;
 
 	cmd.assign(pre_to).append("\x25");
-	if (useB) cmd += '\x00';
+	if (inuse == onB) cmd += '\x00';
 	else      cmd += '\x01';
 
 	cmd.append( to_bcd_be( freq, 10 ) );
@@ -454,7 +457,7 @@ void RIG_IC9700::set_modeA(int val)
 	cmd += IC9700_mode_nbr[val];
 	cmd.append( post );
 	waitFB("set mode A");
-	stringstream ss;
+	std::stringstream ss;
 	ss << "set_modeA(" << val << ") [" << IC9700modes_[val] << "] " <<
 		str2hex(replystr.c_str(), replystr.length());
 	set_trace(1, ss.str().c_str());
@@ -474,11 +477,11 @@ int RIG_IC9700::get_modeA()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 	int ret = waitFOR(8, "get mode/bw A");
 
-	stringstream ss;
+	std::stringstream ss;
 	ss << "get_modeA() " << str2hex(replystr.c_str(), replystr.length());
 	get_trace(2, "get_modeA()", ss.str().c_str());
 
@@ -509,7 +512,7 @@ int RIG_IC9700::get_modeA()
 		resp += "\x1A\x06";
 		if (waitFOR(9, "data mode?")) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				if ((replystr[p+6] & 0x01) == 0x01) {
 					if (md == LSB9700) md = LSB9700D;
 					if (md == USB9700) md = USB9700D;
@@ -535,7 +538,7 @@ void RIG_IC9700::set_modeB(int val)
 	cmd += IC9700_mode_nbr[val];
 	cmd.append( post );
 	waitFB("set mode B");
-	stringstream ss;
+	std::stringstream ss;
 	ss << "set_modeB(" << val << ") [" << IC9700modes_[val] << "] " <<
 		str2hex(replystr.c_str(), replystr.length());
 	set_trace(1, ss.str().c_str());
@@ -555,11 +558,11 @@ int RIG_IC9700::get_modeB()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 	int ret = waitFOR(8, "get mode/bw B");
 
-	stringstream ss;
+	std::stringstream ss;
 	ss << "get_modeA() " << str2hex(replystr.c_str(), replystr.length());
 	get_trace(1, ss.str().c_str());
 
@@ -590,7 +593,7 @@ int RIG_IC9700::get_modeB()
 		resp += "\x1A\x06";
 		if (waitFOR(9, "data mode?")) {
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos) {
+			if (p != std::string::npos) {
 				if ((replystr[p+6] & 0x01) == 0x01) {
 					if (md == LSB9700) md = LSB9700D;
 					if (md == USB9700) md = USB9700D;
@@ -616,7 +619,7 @@ int RIG_IC9700::get_bwA()
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x1a\x03");
 	int ret = waitFOR(8, "get_bw A");
 
@@ -642,7 +645,7 @@ void RIG_IC9700::set_bwA(int val)
 
 	waitFB("set bw A");
 
-	stringstream ss;
+	std::stringstream ss;
 	const char *bwstr = IC9700_ssb_bws[val];
 	if ((A.imode == AM9700) || (A.imode == AM9700D)) bwstr = IC9700_am_bws[val];
 	if ((A.imode == RTTY9700) || (A.imode == RTTY9700R)) bwstr = IC9700_rtty_bws[val];
@@ -660,7 +663,7 @@ int RIG_IC9700::get_bwB()
 	cmd = pre_to;
 	cmd.append("\x1a\x03");
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp.append("\x1a\x03");
 	int ret = waitFOR(8, "get_bw B");
 
@@ -686,7 +689,7 @@ void RIG_IC9700::set_bwB(int val)
 	cmd.append(post);
 	waitFB("set bw B");
 
-	stringstream ss;
+	std::stringstream ss;
 	const char *bwstr = IC9700_ssb_bws[val];
 	if ((B.imode == AM9700) || (B.imode == AM9700D)) bwstr = IC9700_am_bws[val];
 	if ((B.imode == RTTY9700) || (B.imode == RTTY9700R)) bwstr = IC9700_rtty_bws[val];
@@ -790,15 +793,15 @@ void RIG_IC9700::set_mic_gain(int val)
 int RIG_IC9700::get_mic_gain()
 {
 	int val = 0;
-	string cstr = "\x14\x0B";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0B";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get mic")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	get_trace(2, "get_mic_gain()", str2hex(replystr.c_str(), replystr.length()));
@@ -966,15 +969,15 @@ FE FE E0 7A 14 01 00 65 FD
 int RIG_IC9700::get_volume_control()
 {
 	int val = 0;
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	get_trace(2, "get_volume_control()", str2hex(replystr.c_str(), replystr.length()));
@@ -999,14 +1002,14 @@ void RIG_IC9700::set_power_control(double val)
 double RIG_IC9700::get_power_control()
 {
 	int val = progStatus.power_level;
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get power")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	get_trace(2, "get_power_control()", str2hex(replystr.c_str(), replystr.length()));
@@ -1031,14 +1034,14 @@ void RIG_IC9700::set_rf_gain(int val)
 int RIG_IC9700::get_rf_gain()
 {
 	int val = progStatus.rfgain;
-	string cstr = "\x14\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x02";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get RF")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
 	get_trace(2, "get_rf_gain()", str2hex(replystr.c_str(), replystr.length()));
@@ -1052,8 +1055,8 @@ void RIG_IC9700::get_rf_min_max_step(double &min, double &max, double &step)
 
 int RIG_IC9700::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1061,7 +1064,7 @@ int RIG_IC9700::get_smeter()
 	int mtr= -1;
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.40);
 			if (mtr > 100) mtr = 100;
@@ -1073,8 +1076,8 @@ int RIG_IC9700::get_smeter()
 
 double RIG_IC9700::get_voltmeter()
 {
-	string cstr = "\x15\x15";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x15";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1089,7 +1092,7 @@ double RIG_IC9700::get_voltmeter()
 
 	if (ret) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			val = 6.0 * mtr / 228.0 + 9.7;
 			return val;
@@ -1100,8 +1103,8 @@ double RIG_IC9700::get_voltmeter()
 
 int RIG_IC9700::get_power_out()
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1109,7 +1112,7 @@ int RIG_IC9700::get_power_out()
 	int mtr= -1;
 	if (waitFOR(9, "get pout")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.15);
 			if (mtr > 100) mtr = 100;
@@ -1121,8 +1124,8 @@ int RIG_IC9700::get_power_out()
 
 int RIG_IC9700::get_swr()
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1130,7 +1133,7 @@ int RIG_IC9700::get_swr()
 	int mtr= -1;
 	if (waitFOR(9, "get SWR")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.40);
 			if (mtr > 100) mtr = 100;
@@ -1142,8 +1145,8 @@ int RIG_IC9700::get_swr()
 
 int RIG_IC9700::get_alc()
 {
-	string cstr = "\x15\x13";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x13";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1151,7 +1154,7 @@ int RIG_IC9700::get_alc()
 	int mtr= -1;
 	if (waitFOR(9, "get alc")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
@@ -1177,7 +1180,7 @@ void RIG_IC9700::set_notch(bool on, int val)
 	cmd.append(post);
 	waitFB("set notch val");
 
-	stringstream ss;
+	std::stringstream ss;
 	ss << "set_notch(" << on << ", " << val << ") " << str2hex(replystr.data(), replystr.length());
 	set_trace(2, "set_notch()", ss.str().c_str());
 
@@ -1188,8 +1191,8 @@ bool RIG_IC9700::get_notch(int &val)
 	bool on = false;
 	val = 0;
 
-	string cstr = "\x16\x48";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x48";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1197,7 +1200,7 @@ bool RIG_IC9700::get_notch(int &val)
 	if (waitFOR(8, "get notch")) {
 		get_trace(2, "get_notch()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			on = replystr[p + 6];
 		cmd = pre_to;
 		resp = pre_fm;
@@ -1208,7 +1211,7 @@ bool RIG_IC9700::get_notch(int &val)
 		if (waitFOR(9, "notch val")) {
 			get_trace(2, "get_notch_val()", str2hex(replystr.c_str(), replystr.length()));
 			size_t p = replystr.rfind(resp);
-			if (p != string::npos)
+			if (p != std::string::npos)
 				val = (int)ceil(fm_bcd(replystr.substr(p+6),3) * 3000.0 / 255.0);
 		}
 	}
@@ -1235,8 +1238,8 @@ void RIG_IC9700::set_auto_notch(int val)
 
 int RIG_IC9700::get_auto_notch()
 {
-	string cstr = "\x16\x41";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x41";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -1244,7 +1247,7 @@ int RIG_IC9700::get_auto_notch()
 	if (waitFOR(8, "get AN")) {
 		get_trace(2, "get_auto_notch()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+6] == 0x01) {
 				auto_notch_label("AN", true);
 				return true;
@@ -1281,7 +1284,7 @@ int  RIG_IC9700::get_agc()
 	cmd.append(post);
 	if (waitFOR(8, "get AGC")) {
 		size_t p = replystr.find(pre_fm);
-		if (p == string::npos) return agcval;
+		if (p == std::string::npos) return agcval;
 		return (agcval = replystr[p+6]); // 1 = FAST, 2 = MID, 3 = SLOW
 	}
 	get_trace(2, "get_agc()", str2hex(replystr.c_str(), replystr.length()));
@@ -1328,7 +1331,7 @@ void RIG_IC9700::set_attenuator(int val)
 	cmd += atten_level ? '\x10' : '\x00';
 	cmd.append( post );
 	waitFB("set att");
-	stringstream ss;
+	std::stringstream ss;
 	ss << "set_attenuator(" << val << ") " << str2hex(replystr.data(), replystr.length());
 	set_trace(1, ss.str().c_str());
 
@@ -1345,11 +1348,11 @@ int RIG_IC9700::get_attenuator()
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x11';
 	if (waitFOR(7, "get ATT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (!replystr[p+5]) {
 				atten_label("ATT", false);
 				atten_level = 0;
@@ -1407,7 +1410,7 @@ void RIG_IC9700::set_preamp(int val)
 	cmd.append( post );
 	waitFB("set Pre");
 
-	stringstream ss;
+	std::stringstream ss;
 	ss << "set_preamp(" << val << ") " << str2hex(replystr.data(), replystr.length());
 	set_trace(1, ss.str().c_str());
 
@@ -1415,15 +1418,15 @@ void RIG_IC9700::set_preamp(int val)
 
 int RIG_IC9700::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get Pre")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			switch (replystr[p+6]) {
 			default:
 			case 0 :
@@ -1460,7 +1463,7 @@ void RIG_IC9700::set_PTT_control(int val)
 	cmd.append( post );
 	waitFB("set ptt");
 
-	stringstream ss;
+	std::stringstream ss;
 	ss << "set_PTT_control(" << val << ") " << str2hex(replystr.data(), replystr.length());
 	set_trace(1, ss.str().c_str());
 
@@ -1471,12 +1474,12 @@ int RIG_IC9700::get_PTT()
 {
 	cmd = pre_to;
 	cmd += '\x1c'; cmd += '\x00';
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x1c'; resp += '\x00';
 	cmd.append(post);
 	if (waitFOR(8, "get PTT")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			ptt_ = replystr[p + 6];
 	}
 	get_trace(2, "get_PTT()", str2hex(replystr.data(), replystr.length()));
@@ -1496,15 +1499,15 @@ void RIG_IC9700::set_noise(bool val)
 int RIG_IC9700::get_noise()
 {
 	int val = progStatus.noise;
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = replystr[p+6];
 		}
 	}
@@ -1525,15 +1528,15 @@ void RIG_IC9700::set_nb_level(int val)
 int  RIG_IC9700::get_nb_level()
 {
 	int val = progStatus.nb_level;
-	string cstr = "\x14\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NB level")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	get_trace(2, "get_nb_level()", str2hex(replystr.data(), replystr.length()));
@@ -1552,15 +1555,15 @@ void RIG_IC9700::set_noise_reduction(int val)
 
 int RIG_IC9700::get_noise_reduction()
 {
-	string cstr = "\x16\x40";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x40";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(8, "get NR")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	get_trace(2, "get_noise_reduction()", str2hex(replystr.data(), replystr.length()));
@@ -1598,15 +1601,15 @@ void RIG_IC9700::set_noise_reduction_val(int val)
 int RIG_IC9700::get_noise_reduction_val()
 {
 	int val = progStatus.noise_reduction_val;
-	string cstr = "\x14\x06";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x06";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get NRval")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = fm_bcd(replystr.substr(p+6),3);
 			val -= 8;
 			val /= 16;
@@ -1629,15 +1632,15 @@ void RIG_IC9700::set_squelch(int val)
 int  RIG_IC9700::get_squelch()
 {
 	int val = progStatus.squelch;
-	string cstr = "\x14\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
 	if (waitFOR(9, "get squelch")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			val = num100(replystr.substr(p+6));
 	}
 	get_trace(2, "get_squelch()", str2hex(replystr.data(), replystr.length()));
@@ -1713,15 +1716,15 @@ void RIG_IC9700::set_pbt_outer(int val)
 int RIG_IC9700::get_pbt_inner()
 {
 	int val = 0;
-	string cstr = "\x14\x07";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x07";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1733,15 +1736,15 @@ int RIG_IC9700::get_pbt_inner()
 int RIG_IC9700::get_pbt_outer()
 {
 	int val = 0;
-	string cstr = "\x14\x08";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x08";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(9, "get pbt inner")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			val = num100(replystr.substr(p+6));
 			val -= 50;
 		}
@@ -1785,7 +1788,7 @@ void RIG_IC9700::get_band_selection(int v)
 	if (waitFOR(23, "get band stack")) {
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
@@ -1803,7 +1806,7 @@ void RIG_IC9700::get_band_selection(int v)
 			if ((bandmode == 1) && banddata) bandmode = 10;
 			if ((bandmode == 2) && banddata) bandmode = 11;
 			if ((bandmode == 3) && banddata) bandmode = 12;
-			if (useB) {
+			if (inuse == onB) {
 				set_vfoB(bandfreq);
 				set_modeB(bandmode);
 				set_FILT(bandfilter);
@@ -1819,8 +1822,8 @@ void RIG_IC9700::get_band_selection(int v)
 
 void RIG_IC9700::set_band_selection(int v)
 {
-	unsigned long int freq = (useB ? B.freq : A.freq);
-	int mode = (useB ? B.imode : A.imode);
+	unsigned long int freq = (inuse == onB ? B.freq : A.freq);
+	int mode = (inuse == onB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
 	cmd.append("\x1A\x01");
