@@ -55,6 +55,7 @@ RIG_FT991		rig_FT991;
 RIG_FT991A		rig_FT991A;
 RIG_FT1000		rig_FT1000;
 RIG_FT1000MP	rig_FT1000MP;
+RIG_FT1000MP_A	rig_FT1000MP_A;
 RIG_FT2000		rig_FT2000;
 RIG_FTdx10		rig_FTdx10;
 RIG_FTdx101D	rig_FTdx101D;
@@ -121,6 +122,7 @@ RIG_TT588		rig_TT588;
 RIG_TT599		rig_TT599;
 RIG_XI5105		rig_XI5105;
 RIG_Xiegu_G90	rig_XIG90;
+RIG_X6100		rig_X6100;
 RIG_PowerSDR	rig_PowerSDR;
 RIG_FLEX1500	rig_FLEX1500;
 RIG_TX500		rig_TX500;
@@ -152,76 +154,78 @@ rigbase *rigs[] = {
 	&rig_FT991A,	// 23
 	&rig_FT1000,	// 24
 	&rig_FT1000MP,	// 25
-	&rig_FT2000,	// 26
-	&rig_FTdx10,	// 27
-	&rig_FTdx101D,	// 28
-	&rig_FTdx101MP,	// 29
-	&rig_FTdx1200,	// 20
-	&rig_FTdx3000,	// 31
-	&rig_FT5000,	// 32
-	&rig_FTdx9000,	// 33
-	&rig_IC703,		// 34
-	&rig_IC705,		// 35
-	&rig_IC706MKIIG,// 36
-	&rig_IC718,		// 37
-	&rig_IC728,		// 38
-	&rig_IC735,		// 39
-	&rig_IC746,		// 40
-	&rig_IC746PRO,	// 41
-	&rig_IC756,		// 42
-	&rig_IC756PRO,	// 43
-	&rig_IC756PRO2,	// 44
-	&rig_IC756PRO3,	// 45
-	&rig_IC7000,	// 46
-	&rig_IC7100,	// 47
-	&rig_IC7200,	// 48
-	&rig_IC7300,	// 49
-	&rig_IC7410,	// 50
-	&rig_IC7600,	// 51
-	&rig_IC7610,	// 52
-	&rig_IC7700,	// 53
-	&rig_IC7800,	// 54
-	&rig_IC7851,	// 55
-	&rig_IC9100,	// 56
-	&rig_IC9700,	// 57
-	&rig_IC910H,	// 58
-	&rig_ICF8101,	// 59
-	&rig_K2,		// 60
-	&rig_K3,		// 61
-	&rig_KX3,		// 62
-	&rig_PCR1000,	// 63
-	&rig_RAY152,	// 64
-	&rig_TMD710,	// 65
-	&rig_TS140,		// 66
-	&rig_TS440,		// 67
-	&rig_TS450S,	// 68
-	&rig_TS480HX,	// 69
-	&rig_TS480SAT,	// 70
-	&rig_TS570,		// 71
-	&rig_TS590S,	// 72
-	&rig_TS590SG,	// 73
-	&rig_TS790,		// 74
-	&rig_TS850,		// 75
-	&rig_TS870S,	// 76
-	&rig_TS890S,	// 77
-	&rig_TS940S,	// 78
-	&rig_TS950,		// 79
-	&rig_TS990,		// 80
-	&rig_TS2000,	// 81
-	&rig_TT516,		// 82
-	&rig_TT535,		// 83
-	&rig_TT538,		// 84
-	&rig_TT550,		// 85
-	&rig_TT563,		// 86
-	&rig_TT566,		// 87
-	&rig_TT588,		// 88
-	&rig_TT599,		// 89
-	&rig_AOR5K,		// 90
-	&rig_XI5105,	// 91
-	&rig_XIG90,		// 92
-	&rig_PowerSDR,	// 93
-	&rig_FLEX1500,	// 94
-	&rig_TX500,		// 95
+	&rig_FT1000MP_A,// 26
+	&rig_FT2000,	// 27
+	&rig_FTdx10,	// 28
+	&rig_FTdx101D,	// 29
+	&rig_FTdx101MP,	// 20
+	&rig_FTdx1200,	// 21
+	&rig_FTdx3000,	// 32
+	&rig_FT5000,	// 33
+	&rig_FTdx9000,	// 34
+	&rig_IC703,		// 35
+	&rig_IC705,		// 36
+	&rig_IC706MKIIG,// 37
+	&rig_IC718,		// 38
+	&rig_IC728,		// 39
+	&rig_IC735,		// 30
+	&rig_IC746,		// 41
+	&rig_IC746PRO,	// 42
+	&rig_IC756,		// 43
+	&rig_IC756PRO,	// 44
+	&rig_IC756PRO2,	// 45
+	&rig_IC756PRO3,	// 46
+	&rig_IC7000,	// 47
+	&rig_IC7100,	// 48
+	&rig_IC7200,	// 49
+	&rig_IC7300,	// 40
+	&rig_IC7410,	// 51
+	&rig_IC7600,	// 52
+	&rig_IC7610,	// 53
+	&rig_IC7700,	// 54
+	&rig_IC7800,	// 55
+	&rig_IC7851,	// 56
+	&rig_IC9100,	// 57
+	&rig_IC9700,	// 58
+	&rig_IC910H,	// 59
+	&rig_ICF8101,	// 50
+	&rig_K2,		// 61
+	&rig_K3,		// 62
+	&rig_KX3,		// 63
+	&rig_PCR1000,	// 64
+	&rig_RAY152,	// 65
+	&rig_TMD710,	// 66
+	&rig_TS140,		// 67
+	&rig_TS440,		// 68
+	&rig_TS450S,	// 69
+	&rig_TS480HX,	// 60
+	&rig_TS480SAT,	// 71
+	&rig_TS570,		// 72
+	&rig_TS590S,	// 73
+	&rig_TS590SG,	// 74
+	&rig_TS790,		// 75
+	&rig_TS850,		// 76
+	&rig_TS870S,	// 77
+	&rig_TS890S,	// 78
+	&rig_TS940S,	// 79
+	&rig_TS950,		// 70
+	&rig_TS990,		// 81
+	&rig_TS2000,	// 82
+	&rig_TT516,		// 83
+	&rig_TT535,		// 84
+	&rig_TT538,		// 85
+	&rig_TT550,		// 86
+	&rig_TT563,		// 87
+	&rig_TT566,		// 88
+	&rig_TT588,		// 89
+	&rig_TT599,		// 80
+	&rig_AOR5K,		// 91
+	&rig_XI5105,	// 92
+	&rig_XIG90,		// 93
+	&rig_X6100,		// 94
+	&rig_PowerSDR,	// 95
+	&rig_FLEX1500,	// 96
+	&rig_TX500,		// 97
 
 	NULL
 };
