@@ -27,6 +27,8 @@
 
 #include "gettext.h"
 
+#include "support.h"
+
 //=============================================================================
 // IC-_g90
 /*
@@ -78,6 +80,12 @@ static void btn_label(void *p)
 	b->redraw();
 }
 
+static inline void minmax(int min, int max, int &val)
+{
+	if (val > max) val = max;
+	if (val < min) val = min;
+}
+
 static GUI Xiegu_G90_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },	//0
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },	//1
@@ -160,8 +168,10 @@ RIG_Xiegu_G90::RIG_Xiegu_G90() {
 	has_extras = 
 	has_cw_wpm = 
 	has_cw_vol = 
+	has_cw_spot_tone = 
 	has_band_selection = 
 	has_compON = 
+	has_tune_control = 
 	has_nb_level = true;
 // false
 	CW_sense =
@@ -175,7 +185,6 @@ RIG_Xiegu_G90::RIG_Xiegu_G90() {
 	has_noise_reduction_control = 
 	has_auto_notch = 
 	has_notch_control = 
-	has_cw_spot_tone = 
 	has_cw_qsk = 
 	has_vox_onoff = 
 	has_vox_gain = 
@@ -184,7 +193,6 @@ RIG_Xiegu_G90::RIG_Xiegu_G90() {
 	has_compression = 
 	has_vfo_adj = 
 	restore_mbw = 
-	has_tune_control = 
 	has_xcvr_auto_on_off = false;
 
 };
@@ -196,7 +204,7 @@ RIG_Xiegu_G90::RIG_Xiegu_G90() {
 bool RIG_Xiegu_G90::check ()
 {
 	bool ok = false;
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -207,8 +215,6 @@ bool RIG_Xiegu_G90::check ()
 	return ok;
 }
 
-static bool Xiegu_G90onA = true;
-
 void RIG_Xiegu_G90::selectA()
 {
 	cmd = pre_to;
@@ -218,7 +224,7 @@ void RIG_Xiegu_G90::selectA()
 	set_trace(1, "selectA()");
 	waitFB("select A");
 	isett("");
-	Xiegu_G90onA = true;
+	inuse = onA;
 }
 
 void RIG_Xiegu_G90::selectB()
@@ -230,13 +236,13 @@ void RIG_Xiegu_G90::selectB()
 	set_trace(1, "selectB()");
 	waitFB("select B");
 	isett("");
-	Xiegu_G90onA = false;
+	inuse = onB;
 }
 
 unsigned long int RIG_Xiegu_G90::get_vfoA ()
 {
-	if (useB) return A.freq;
-	string resp = pre_fm;
+	if (inuse == onB) return A.freq;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -245,7 +251,7 @@ unsigned long int RIG_Xiegu_G90::get_vfoA ()
 	if (waitFOR(11, "get vfo A")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -269,8 +275,8 @@ void RIG_Xiegu_G90::set_vfoA (unsigned long int freq)
 
 unsigned long int RIG_Xiegu_G90::get_vfoB ()
 {
-	if (!useB) return B.freq;
-	string resp = pre_fm;
+	if (inuse == onA) return B.freq;
+	std::string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
 	cmd += '\x03';
@@ -279,7 +285,7 @@ unsigned long int RIG_Xiegu_G90::get_vfoB ()
 	if (waitFOR(11, "get vfo B")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p+5] == -1)
 				A.freq = 0;
 			else
@@ -327,10 +333,10 @@ int RIG_Xiegu_G90::get_split()
 	get_trace(1, "get split");
 	if (waitFOR(7, "get split")) {
 		igett("");
-		string resp = pre_fm;
+		std::string resp = pre_fm;
 		resp.append("\x0F");
 		size_t p = replystr.find(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			read_split = replystr[p+5];
 		if (read_split != 0xFA) // fail byte
 			split = read_split;
@@ -372,7 +378,7 @@ int RIG_Xiegu_G90::get_modeA()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 
 	get_trace(1, "get modeA");
@@ -423,7 +429,7 @@ int RIG_Xiegu_G90::get_modeB()
 	cmd = pre_to;
 	cmd += '\x04';
 	cmd.append(post);
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x04';
 
 	get_trace(1, "get modeB");
@@ -477,7 +483,7 @@ int RIG_Xiegu_G90::get_attenuator()
 	cmd = pre_to;
 	cmd += '\x11';
 	cmd.append( post );
-	string resp = pre_fm;
+	std::string resp = pre_fm;
 	resp += '\x11';
 	get_trace(1, "get ATT");
 	if (waitFOR(7, "get ATT")) {
@@ -519,8 +525,8 @@ void RIG_Xiegu_G90::set_preamp(int val)
 
 int RIG_Xiegu_G90::get_preamp()
 {
-	string cstr = "\x16\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -529,7 +535,7 @@ int RIG_Xiegu_G90::get_preamp()
 	if (waitFOR(8, "get Preamp Level")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			preamp_level = replystr[p+6];
 		if (preamp_level == 1) {
 			preamp_label("PRE", true);
@@ -642,8 +648,8 @@ double RIG_Xiegu_G90::get_power_control()
 {
 	int val = pwrtbl[int(progStatus.power_level) - 1].mtr;
 
-	string cstr = "\x14\x0A";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x0A";
+	std::string resp = pre_fm;
 	cmd = pre_to;
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
@@ -651,7 +657,7 @@ double RIG_Xiegu_G90::get_power_control()
 	if (waitFOR(9, "get power")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p + 7] == '\xFD') {
 				val = hexval(replystr[p + 6]);
 			} else {
@@ -679,8 +685,8 @@ void RIG_Xiegu_G90::get_pc_min_max_step(double &min, double &max, double &step)
 
 int RIG_Xiegu_G90::get_power_out(void)
 {
-	string cstr = "\x15\x11";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x11";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -690,7 +696,7 @@ int RIG_Xiegu_G90::get_power_out(void)
 	if (waitFOR(9, "get power out")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			// Power is 10 * output in watts, as BCD
 			if (replystr[p + 7] == '\xFD') {
 				mtr = hexval(replystr[p + 6]);
@@ -730,8 +736,8 @@ void RIG_Xiegu_G90::set_volume_control(int val)
 int RIG_Xiegu_G90::get_volume_control()
 {
 	int val = progStatus.volume;
-	string cstr = "\x14\x01";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x01";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -740,7 +746,7 @@ int RIG_Xiegu_G90::get_volume_control()
 	if (waitFOR(9, "get vol")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p + 7] == '\xFD') {
 				val = hexval(replystr[p + 6]);
 			} else {
@@ -780,8 +786,8 @@ S9  FE FE 88 E0 14 03 FD FE FE E0 88 14 03 02 55 FD
 int  RIG_Xiegu_G90::get_squelch()
 {
 	int val = progStatus.squelch;
-	string cstr = "\x14\x03";
-	string resp = pre_fm;
+	std::string cstr = "\x14\x03";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -790,7 +796,7 @@ int  RIG_Xiegu_G90::get_squelch()
 	if (waitFOR(9, "get squelch")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p + 7] == '\xFD') {
 				val = hexval(replystr[p + 6]);
 			} else {
@@ -831,8 +837,8 @@ static meterpair smtrtbl[] = {
 
 int RIG_Xiegu_G90::get_smeter()
 {
-	string cstr = "\x15\x02";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x02";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -842,7 +848,7 @@ int RIG_Xiegu_G90::get_smeter()
 	if (waitFOR(8, "get smeter")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p + 7] == '\xFD') {
 				mtr = hexval(replystr[p + 6]);
 			} else {
@@ -876,8 +882,8 @@ static meterpair swrtbl[] = {
 
 int RIG_Xiegu_G90::get_swr()
 {
-	string cstr = "\x15\x12";
-	string resp = pre_fm;
+	std::string cstr = "\x15\x12";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -887,7 +893,7 @@ int RIG_Xiegu_G90::get_swr()
 	if (waitFOR(9, "get SWR")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos) {
+		if (p != std::string::npos) {
 			if (replystr[p + 7] == '\xFD') {
 				mtr = hexval(replystr[p + 6]);
 			} else {
@@ -923,8 +929,8 @@ void RIG_Xiegu_G90::set_noise(bool val)
 
 int RIG_Xiegu_G90::get_noise()
 {
-	string cstr = "\x16\x22";
-	string resp = pre_fm;
+	std::string cstr = "\x16\x22";
+	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
@@ -933,7 +939,7 @@ int RIG_Xiegu_G90::get_noise()
 	if (waitFOR(8, "get noise")) {
 		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
+		if (p != std::string::npos)
 			return (replystr[p+6] ? 1 : 0);
 	}
 	return progStatus.noise;
@@ -958,7 +964,7 @@ void RIG_Xiegu_G90::get_band_selection(int v)
 	}
 	if (bandmode < 0) bandmode = 0;
 	if (bandmode > 4) bandmode = 0;
-	if (useB) {
+	if (inuse == onB) {
 		set_vfoB(bandfreq);
 		set_modeB(bandmode);
 	} else {
@@ -997,7 +1003,7 @@ int  RIG_Xiegu_G90::get_agc()
 	if (waitFOR(8, "get AGC")) {
 		igett("");
 		size_t p = replystr.find(pre_fm);
-		if (p == string::npos) return agcval;
+		if (p == std::string::npos) return agcval;
 		return (agcval = replystr[p + 6]); // 1 = off, 2 = FAST, 3 = SLOW 4 = AUTO
 	}
 	return agcval;
@@ -1017,7 +1023,7 @@ int RIG_Xiegu_G90::incr_agc()
 	return agcval;
 }
 
-static const char *agcstrs[] = {"AGC", "FST", "SLO","AUT"};
+static const char *agcstrs[] = {"AGC-O", "AGC-F", "AGC-M","AGC-S"};
 const char *RIG_Xiegu_G90::agc_label()
 {
 	return agcstrs[agcval];
@@ -1028,4 +1034,52 @@ int RIG_Xiegu_G90::agc_val()
 	return (agcval);
 }
 
+void RIG_Xiegu_G90::set_cw_spot_tone()
+{
+	cmd.assign(pre_to).append("\x14\x09"); // values 0=300Hz 255=900Hz
+	int n = round((progStatus.cw_spot_tone - 300) * 255.0 / 600.0 + 0.5);
+	minmax(0, 255, n);
+
+	cmd.append(to_bcd(n, 3));
+	cmd.append( post );
+	set_trace(1, "set cw spot tone");
+	waitFB("SET cw spot tone");
+	seth();
+}
+
+void RIG_Xiegu_G90::tune_rig(int how)
+{
+	cmd = pre_to;
+	cmd.append("\x1c\x01");
+	switch (how) {
+		default:
+		case 0:
+			cmd += '\x00'; // off
+			break;
+		case 1:
+			cmd += '\x01'; // ON
+			break;
+		case 2:
+			cmd += '\x02'; // start tuning
+			break;
+	}
+	cmd.append( post );
+	waitFB("tune rig");
+	ICtrace("tune rig", replystr);
+}
+
+int RIG_Xiegu_G90::get_tune()
+{
+	std::string resp;
+	std::string cstr = "\x1C\x01";
+	cmd.assign(pre_to).append(cstr).append(post);
+	resp.assign(pre_fm).append(cstr);
+	int val = tune_;
+	if (waitFOR(8, "get TUNE")) {
+		size_t p = replystr.rfind(resp);
+		if (p != std::string::npos)
+			val = replystr[p + 6];
+	}
+	return (tune_ = val);
+}
 
