@@ -26,6 +26,8 @@
 #include "yaesu/FT450D.h"
 #include "rig.h"
 
+#include "support.h"
+
 #define FL450D_WAIT_TIME 200
 
 static const char FT450Dname_[] = "FT-450D";
@@ -206,6 +208,7 @@ void RIG_FT450D::selectA()
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select vfo A", cmd, replystr);
 	sett("selectA");
+	inuse = onA;
 }
 
 void RIG_FT450D::selectB()
@@ -214,6 +217,7 @@ void RIG_FT450D::selectB()
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select vfo B", cmd, replystr);
 	sett("selectB");
+	inuse = onB;
 }
 
 void RIG_FT450D::A2B()
@@ -245,7 +249,7 @@ unsigned long int RIG_FT450D::get_vfoA ()
 	gett("get_vfoA");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqA;
+	if (p == std::string::npos) return freqA;
 	int f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -255,7 +259,8 @@ unsigned long int RIG_FT450D::get_vfoA ()
 
 void RIG_FT450D::set_vfoA (unsigned long int freq)
 {
-	if (useB) selectA();
+	int current_vfo = inuse;
+	if (current_vfo == onB) selectA();
 	freqA = freq;
 	cmd = "FA00000000;";
 	for (int i = 9; i > 1; i--) {
@@ -265,7 +270,7 @@ void RIG_FT450D::set_vfoA (unsigned long int freq)
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET vfo A", cmd, replystr);
 	sett("set_vfoA");
-	if (useB) selectB();
+	if (current_vfo == onB) selectB();
 }
 
 unsigned long int RIG_FT450D::get_vfoB ()
@@ -277,7 +282,7 @@ unsigned long int RIG_FT450D::get_vfoB ()
 	gett("get_vfoB");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqB;
+	if (p == std::string::npos) return freqB;
 	int f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -287,7 +292,8 @@ unsigned long int RIG_FT450D::get_vfoB ()
 
 void RIG_FT450D::set_vfoB (unsigned long int freq)
 {
-	if (!useB) selectB();
+	int current_vfo = inuse;
+	if (current_vfo == onA) selectB();
 	freqB = freq;
 	cmd = "FB00000000;";
 	for (int i = 9; i > 1; i--) {
@@ -297,7 +303,7 @@ void RIG_FT450D::set_vfoB (unsigned long int freq)
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET vfo B", cmd, replystr);
 	sett("set_vfoB");
-	if (!useB) selectA();
+	if (current_vfo == onA) selectA();
 }
 
 int RIG_FT450D::get_vfoAorB()
@@ -313,7 +319,7 @@ int RIG_FT450D::get_vfoAorB()
 
 void RIG_FT450D::set_split(bool on)
 {
-	if (useB) {
+	if (inuse == onB) {
 		if (on) cmd = "FT0;";
 		else cmd = "FT1;";
 	} else {
@@ -338,10 +344,10 @@ int RIG_FT450D::get_split()
 	gett("");
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos) return false;
+	if (p == std::string::npos) return false;
 	tx = replystr[p+2];
 
-	if (useB)
+	if (inuse == onB)
 		split = (tx == '0');
 	else
 		split = (tx == '1');
@@ -369,7 +375,7 @@ int RIG_FT450D::get_smeter()
 	gett("");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int val = atoi(&replystr[p+3]);
 	
@@ -404,7 +410,7 @@ int RIG_FT450D::get_swr()
 	gett("");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	return (int)ceil(mtr / 2.56);
@@ -419,7 +425,7 @@ int RIG_FT450D::get_alc()
 	gett("");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	return (int)ceil(mtr / 2.56);
@@ -454,7 +460,7 @@ int RIG_FT450D::get_power_out()
 	gett("");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int    mtr = atoi(&replystr[p+3]);
 	if (mtr < 0) mtr = 0;
@@ -482,7 +488,7 @@ double RIG_FT450D::get_power_control()
 	gett("");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.power_level;
+	if (p == std::string::npos) return progStatus.power_level;
 	if (p + 5 >= replystr.length()) return progStatus.power_level;
 
 	int mtr = atoi(&replystr[p+2]);
@@ -512,7 +518,7 @@ int RIG_FT450D::get_volume_control()
 	gett("get_volume_control");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.volume;
+	if (p == std::string::npos) return progStatus.volume;
 	if (p + 6 >= replystr.length()) return progStatus.volume;
 	int val = round(atoi(&replystr[p+3]) / 2.55);
 	if (val > 100) val = 100;
@@ -556,7 +562,7 @@ int RIG_FT450D::get_PTT()
 	gett("get_PTT");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ptt_;
+	if (p == std::string::npos) return ptt_;
 	ptt_ =  (replystr[p+2] != '0' ? 1 : 0);
 	return ptt_;
 }
@@ -590,7 +596,7 @@ int RIG_FT450D::get_tune()
 	rig_trace(2, "get_tuner status()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	int val = replystr[p+4] - '0';
 	return (val > 0);
 }
@@ -617,7 +623,7 @@ int RIG_FT450D::get_attenuator()
 
 	size_t p = replystr.rfind(rsp);
 	int val = attval;
-	if (p != string::npos)
+	if (p != std::string::npos)
 		val = (replystr[p+3] == '3' ? 1 : 0);
 	attval = val;
 	return val;
@@ -649,10 +655,10 @@ int RIG_FT450D::get_preamp()
 	if (replystr.empty()) return preval;
 
 	size_t p = replystr.rfind("PA00;");
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		preval = 1;
 		preamp_label("IPO", true);
-	} else if (replystr.rfind("PA01;") != string::npos) {
+	} else if (replystr.rfind("PA01;") != std::string::npos) {
 		preval = 0;
 		preamp_label("IPO", false);
 	}
@@ -695,7 +701,7 @@ int RIG_FT450D::adjust_bandwidth(int val)
 int RIG_FT450D::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -757,7 +763,7 @@ int RIG_FT450D::get_modeA()
 	gett("get_modeA");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return modeA;
+	if (p == std::string::npos) return modeA;
 	int md = replystr[p+3];
 	if (md <= '9') md = md - '1';
 	else md = 9 + md - 'B';
@@ -790,8 +796,8 @@ int RIG_FT450D::get_bwA()
 	gett("get_bwA");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return bwA;
-	string bws = replystr.substr(p+3,2);
+	if (p == std::string::npos) return bwA;
+	std::string bws = replystr.substr(p+3,2);
 	if (bws == "00") bwA = 0;
 	else if (bws == "16") bwA = 1;
 	else if (bws == "31") bwA = 2;
@@ -831,7 +837,7 @@ int RIG_FT450D::get_modeB()
 	gett("get_modeB");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return modeB;
+	if (p == std::string::npos) return modeB;
 	int md = replystr[p+3];
 	if (md <= '9') md = md - '1';
 	else md = 9 + md - 'B';
@@ -864,8 +870,8 @@ int RIG_FT450D::get_bwB()
 	gett("get_bwB");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return bwB;
-	string bws = replystr.substr(p+3,2);
+	if (p == std::string::npos) return bwB;
+	std::string bws = replystr.substr(p+3,2);
 	if (bws == "00") bwB = 0;
 	else if (bws == "16") bwB = 1;
 	else if (bws == "31") bwB = 2;
@@ -875,7 +881,7 @@ int RIG_FT450D::get_bwB()
 
 std::string RIG_FT450D::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -885,7 +891,7 @@ std::string RIG_FT450D::get_BANDWIDTHS()
 
 void RIG_FT450D::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -922,7 +928,7 @@ bool RIG_FT450D::get_if_shift(int &val)
 
 	size_t p = replystr.rfind(rsp);
 	val = progStatus.shift_val;
-	if (p == string::npos) return progStatus.shift;
+	if (p == std::string::npos) return progStatus.shift;
 	val = atoi(&replystr[p+4]);
 	if (replystr[p+3] == '-') val = -val;
 	return (val != 0);
@@ -978,7 +984,7 @@ bool  RIG_FT450D::get_notch(int &val)
 
 	size_t p = replystr.rfind(rsp);
 	val = progStatus.notch_val = 0; // disabled default slider position
-	if (p == string::npos) return ison;
+	if (p == std::string::npos) return ison;
 
 	if (replystr[p+6] == '1') { // manual notch enabled
 		ison = true;
@@ -990,7 +996,7 @@ bool  RIG_FT450D::get_notch(int &val)
 		gett("get_notch_val");
 
 		p = replystr.rfind(rsp);
-		if (p == string::npos || rsp.length() < 8) return ison;
+		if (p == std::string::npos || rsp.length() < 8) return ison;
 		val = atoi(&replystr[p+4]);
 		val = val * 10;
 	}
@@ -1060,7 +1066,7 @@ int RIG_FT450D::get_mic_gain()
 	gett("get_mic_gain");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return mg;
+	if (p == std::string::npos) return mg;
 	replystr[p+5] = 0;
 	int val = atoi(&replystr[p+2]);
 	if (val < 86) return 1;
@@ -1242,7 +1248,7 @@ int  RIG_FT450D::get_noise_reduction_val()
 	gett("get_noise_reduction_val");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return val;
+	if (p == std::string::npos) return val;
 	val = atoi(&replystr[p+3]);
 	return val;
 }
@@ -1265,7 +1271,7 @@ int  RIG_FT450D::get_noise_reduction()
 	gett("get_noise_reduction");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	val = replystr[p+3] - '0';
 	return val;
 }
@@ -1293,7 +1299,7 @@ int  RIG_FT450D::get_rf_gain()
 	gett("get_rf_gain");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.rfgain;
+	if (p == std::string::npos) return progStatus.rfgain;
 	// Parse the RF value from the position returned by rfind for the response.
 	// Valid values are 0-255.
 	int rfval =
@@ -1324,7 +1330,7 @@ void RIG_FT450D::get_cw_weight()
 	gett("get_cw_weight");
 
 	size_t p = replystr.rfind("EX024");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	replystr[p+8] = 0;
 	int val = atoi(&replystr[p+5]);
 	progStatus.cw_weight = val / 10.0;
@@ -1337,7 +1343,7 @@ void RIG_FT450D::get_cw_wpm()
 	gett("get_cw_wpm");
 
 	size_t p = replystr.rfind("KS");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 
 	replystr[p+5] = 0;
 	int val = atoi(&replystr[p+2]);
@@ -1351,7 +1357,7 @@ void RIG_FT450D::get_qsk()
 	gett("get_qsk");
 
 	size_t p = replystr.rfind("EX018");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 
 	switch (replystr[p+5]) {
 		default :
@@ -1369,7 +1375,7 @@ void RIG_FT450D::get_qsk_delay()
 	gett("get_qsk_delay");
 
 	size_t p = replystr.rfind("EX016");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	replystr[p+9] = 0;
 	progStatus.cw_delay = atoi(&replystr[p+5]);
 }
@@ -1381,7 +1387,7 @@ void RIG_FT450D::get_cw_spot_tone()
 	gett("get_cw_spot_tone");
 
 	size_t p = replystr.rfind("EX020");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	replystr[p+7] = 0;
 	int n = atoi(&replystr[p+5]);
 	switch (n) {
@@ -1401,7 +1407,7 @@ void RIG_FT450D::get_vox_gain()
 	gett("get_vox_gain");
 
 	size_t p = replystr.rfind("VG");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	replystr[p+5] = 0;
 	progStatus.vox_gain = atoi(&replystr[p+2]);
 }
@@ -1413,7 +1419,7 @@ void RIG_FT450D::get_vox_hang()
 	gett("get_vox_hang");
 
 	size_t p = replystr.rfind("VD");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	replystr[p+6] = 0;
 	progStatus.vox_hang = atoi(&replystr[p+2]);
 }
@@ -1485,7 +1491,7 @@ void RIG_FT450D::get_band_selection(int v)
 	sett("get band");
 
 	size_t p = replystr.rfind("IF");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	if (replystr[p+21] != '0') {	// vfo 60M memory mode
 		inc_60m = true;
 	}
