@@ -221,7 +221,7 @@ void RIG_FT5000::get_band_selection(int v)
 	gett("get band");
 
 	size_t p = replystr.rfind("IF");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	if (replystr[p+21] != '0') {	// vfo 60M memory mode
 		inc_60m = true;
 	}
@@ -269,7 +269,7 @@ unsigned long int RIG_FT5000::get_vfoA ()
 	gett("get_vfoA");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqA;
+	if (p == std::string::npos) return freqA;
 	int f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -299,7 +299,7 @@ unsigned long int RIG_FT5000::get_vfoB ()
 	gett("get_vfoB");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqB;
+	if (p == std::string::npos) return freqB;
 	int f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -333,6 +333,7 @@ void RIG_FT5000::selectA()
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select A", cmd, replystr);
 	sett("selectA");
+	inuse = onA;
 }
 
 void RIG_FT5000::selectB()
@@ -341,6 +342,7 @@ void RIG_FT5000::selectB()
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select B", cmd, replystr);
 	sett("selectB");
+	inuse = onB;
 }
 
 void RIG_FT5000::A2B()
@@ -360,7 +362,6 @@ void RIG_FT5000::set_split(bool val)
 {
 	split = val;
 	if (val) {
-		useB = false;
 		cmd = "FR2;";
 		sendCommand(cmd);
 		showresp(WARN, ASC, "Rx on A", cmd, replystr);
@@ -397,7 +398,7 @@ int RIG_FT5000::get_smeter()
 	gett("get_smeter");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	mtr *= 100;
@@ -430,7 +431,7 @@ int RIG_FT5000::get_swr()
 	gett("get_swr");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int rcvd = atoi(&replystr[p+3]);
 
@@ -486,7 +487,7 @@ int RIG_FT5000::get_power_out()
 	gett("get_power_out");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 
@@ -512,7 +513,7 @@ double RIG_FT5000::get_power_control()
 	gett("get_power_control");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.power_level;
+	if (p == std::string::npos) return progStatus.power_level;
 	if (p + 5 >= replystr.length()) return progStatus.power_level;
 
 	int mtr = atoi(&replystr[p+2]);
@@ -546,7 +547,7 @@ int RIG_FT5000::get_volume_control()
 	gett("get_volume_control");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.volume;
+	if (p == std::string::npos) return progStatus.volume;
 	if (p + 6 >= replystr.length()) return progStatus.volume;
 	int val = atoi(&replystr[p+3]) * 100 / 255;
 	if (val > 100) val = 100;
@@ -585,7 +586,7 @@ int RIG_FT5000::get_PTT()
 	gett("get_PTT");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ptt_;
+	if (p == std::string::npos) return ptt_;
 	ptt_ =  (replystr[p+2] != '0' ? 1 : 0);
 	return ptt_;
 }
@@ -618,7 +619,7 @@ int RIG_FT5000::get_tune()
 	rig_trace(2, "get_tuner status()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	int val = replystr[p+4] - '0';
 	return !(val < 2);
 }
@@ -662,7 +663,7 @@ int RIG_FT5000::get_attenuator()
 	gett("get_attenuator");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.attenuator;
+	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
 	atten_level = replystr[p+3] - '0';
 	if (atten_level == 1) {
@@ -716,7 +717,7 @@ int RIG_FT5000::get_preamp()
 	gett("get_preamp");
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos)
+	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
 	if (preamp_level == 1) {
 		preamp_label("Amp 1", true);
@@ -760,7 +761,7 @@ int RIG_FT5000::adjust_bandwidth(int val)
 int RIG_FT5000::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -817,7 +818,7 @@ int RIG_FT5000::get_modeA()
 	gett("get_modeA");
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			if (md <= '9') md = md - '1';
@@ -861,7 +862,7 @@ int RIG_FT5000::get_modeB()
 	gett("get_modeB");
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			if (md <= '9') md = md - '1';
@@ -912,7 +913,7 @@ int RIG_FT5000::get_bwA()
 	gett("get_bwA");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return bwA;
+	if (p == std::string::npos) return bwA;
 	if (p + 5 >= replystr.length()) return bwA;
 
 	replystr[p+5] = 0;
@@ -969,7 +970,7 @@ int RIG_FT5000::get_bwB()
 	gett("get_bwB");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return bwB;
+	if (p == std::string::npos) return bwB;
 	if (p + 5 >= replystr.length()) return bwB;
 
 	replystr[p+5] = 0;
@@ -989,7 +990,7 @@ int RIG_FT5000::get_bwB()
 
 std::string RIG_FT5000::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -999,7 +1000,7 @@ std::string RIG_FT5000::get_BANDWIDTHS()
 
 void RIG_FT5000::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -1037,7 +1038,7 @@ bool RIG_FT5000::get_if_shift(int &val)
 
 	size_t p = replystr.rfind(rsp);
 	val = progStatus.shift_val;
-	if (p == string::npos) return progStatus.shift;
+	if (p == std::string::npos) return progStatus.shift;
 	val = atoi(&replystr[p+4]);
 	if (replystr[p+3] == '-') val = -val;
 	return (val != 0);
@@ -1083,7 +1084,7 @@ bool  RIG_FT5000::get_notch(int &val)
 	gett("get_notch");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ison;
+	if (p == std::string::npos) return ison;
 
 	if (replystr[p+6] == '1') // manual notch enabled
 		ison = true;
@@ -1096,7 +1097,7 @@ bool  RIG_FT5000::get_notch(int &val)
 	gett("get_notch_val");
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos)
+	if (p == std::string::npos)
 		val = 10;
 	else
 		val = fm_decimal(replystr.substr(p+4),3) * 10;
@@ -1127,7 +1128,7 @@ int  RIG_FT5000::get_auto_notch()
 	gett("get_auto_notch");
 
 	size_t p = replystr.rfind("BC0");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (replystr[p+3] == '1') return 1;
 	return 0;
 }
@@ -1161,7 +1162,7 @@ int RIG_FT5000::get_noise()
 	gett("get_noise");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return FT5000_blanker_level;
+	if (p == std::string::npos) return FT5000_blanker_level;
 
 	FT5000_blanker_level = replystr[p+3] - '0';
 	if (FT5000_blanker_level == 1) {
@@ -1198,7 +1199,7 @@ int RIG_FT5000::get_mic_gain()
 	gett("get_mic_gain");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.mic_gain;
+	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
 	return val * 100 / 255;
 }
@@ -1233,7 +1234,7 @@ int  RIG_FT5000::get_rf_gain()
 	gett("get_rf_gain");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.rfgain;
+	if (p == std::string::npos) return progStatus.rfgain;
 	for (int i = 3; i < 6; i++) {
 		rfval *= 10;
 		rfval += replystr[p+i] - '0';
