@@ -229,7 +229,7 @@ void RIG_FT991::initialize()
 	cmd = "MR118;";
 	wait_char(';', 27, FL991_WAIT_TIME, "Read UK 60m Channel Mem", ASC);
 	size_t p = replystr.rfind("MR");
-	if (p == string::npos) {
+	if (p == std::string::npos) {
 		Channels_60m = US_60m_chan;
 		label_60m    = US_60m_label;
 		op_yaesu_select60->clear();
@@ -269,7 +269,7 @@ unsigned long int RIG_FT991::get_vfoA ()
 	wait_char(';',12, FL991_WAIT_TIME, "get vfo A", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqA;
+	if (p == std::string::npos) return freqA;
 	p += 2;
 	int f = 0;
 	for (int n = 0; n < ndigits; n++)
@@ -297,7 +297,7 @@ unsigned long int RIG_FT991::get_vfoB ()
 	wait_char(';',12, FL991_WAIT_TIME, "get vfo B", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqB;
+	if (p == std::string::npos) return freqB;
 	p += 2;
 	int f = 0;
 	for (int n = 0; n < ndigits; n++)
@@ -324,6 +324,7 @@ void RIG_FT991::selectA()
 	cmd = "FT2;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select A", cmd, replystr);
+	inuse = onA;
 }
 
 void RIG_FT991::selectB()
@@ -331,6 +332,7 @@ void RIG_FT991::selectB()
 	cmd = "FT3;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select B", cmd, replystr);
+	inuse = onB;
 }
 
 void RIG_FT991::A2B()
@@ -362,7 +364,7 @@ bool RIG_FT991::can_split()
 void RIG_FT991::set_split(bool val)
 {
 	split = val;
-	if (useB) {
+	if (inuse == onB) {
 		if (val) {
 			cmd = "FT2;";
 			sendCommand(cmd);
@@ -396,7 +398,7 @@ int RIG_FT991::get_split()
 	cmd.append(";");
 	wait_char(';', 4, FL991_WAIT_TIME, "get split tx vfo", ASC);
 	p = replystr.rfind(rsp);
-	if (p == string::npos) return false;
+	if (p == std::string::npos) return false;
 	tx = replystr[p+2] - '0';
 
 // rx vfo
@@ -405,7 +407,7 @@ int RIG_FT991::get_split()
 	wait_char(';', 4, FL991_WAIT_TIME, "get split rx vfo", ASC);
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos) return false;
+	if (p == std::string::npos) return false;
 	rx = replystr[p+2] - '0';
 
 	split = (tx == 1 ? 2 : 0) + (rx >= 4 ? 1 : 0);
@@ -421,7 +423,7 @@ int RIG_FT991::get_smeter()
 	wait_char(';',7, FL991_WAIT_TIME, "get smeter", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	mtr = mtr * 100.0 / 256.0;
@@ -435,7 +437,7 @@ int RIG_FT991::get_swr()
 	wait_char(';',7, FL991_WAIT_TIME, "get swr", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	return (int)ceil(mtr / 2.56);
@@ -448,7 +450,7 @@ int RIG_FT991::get_alc()
 	wait_char(';',7, FL991_WAIT_TIME, "get alc", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	return (int)ceil(mtr / 2.56);
@@ -457,7 +459,7 @@ int RIG_FT991::get_alc()
 double RIG_FT991::get_voltmeter()
 {
 	cmd = "RM8;";
-	string resp = "RM";
+	std::string resp = "RM";
 
 	int mtr = 0;
 	double val = 0;
@@ -467,7 +469,7 @@ double RIG_FT991::get_voltmeter()
 	gett("get vdd");
 
 	size_t p = replystr.rfind(resp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		mtr = atoi(&replystr[p+3]);
 		val = (7.0 * mtr / 98.0) + 0.14;
 		return val;
@@ -483,7 +485,7 @@ int RIG_FT991::get_power_out()
 	wait_char(';',7, FL991_WAIT_TIME, "get pout", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	double mtr = (double)(atoi(&replystr[p+3]));
 
@@ -501,7 +503,7 @@ double RIG_FT991::get_power_control()
 	wait_char(';',6, FL991_WAIT_TIME, "get power", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.power_level;
+	if (p == std::string::npos) return progStatus.power_level;
 	if (p + 5 >= replystr.length()) return progStatus.power_level;
 
 	int mtr = atoi(&replystr[p+2]);
@@ -528,7 +530,7 @@ int RIG_FT991::get_volume_control()
 	wait_char(';',7, FL991_WAIT_TIME, "get vol", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.volume;
+	if (p == std::string::npos) return progStatus.volume;
 	if (p + 6 >= replystr.length()) return progStatus.volume;
 	int val = round(atoi(&replystr[p+3]) / 2.55);
 	if (val > 100) val = 100;
@@ -563,7 +565,7 @@ int RIG_FT991::get_PTT()
 	waitN(4, 100, "get PTT", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ptt_;
+	if (p == std::string::npos) return ptt_;
 	ptt_ =  (replystr[p+2] != '0' ? 1 : 0);
 	return ptt_;
 }
@@ -584,7 +586,7 @@ int  RIG_FT991::get_tune()
 	// Why override FL991_WAIT_TIME to be the same as FL991A_...?
 	wait_char(';',6, 100, "Tuner Enabled?", ASC);
 	size_t p = replystr.rfind("AC");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if ((p + 5) >= replystr.length()) return 0;
 	if (replystr[p+4] == '0') {
 		return 0;
@@ -622,7 +624,7 @@ int RIG_FT991::get_attenuator()
 	wait_char(';',5, FL991_WAIT_TIME, "get att", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.attenuator;
+	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
 	atten_level = replystr[p+3] - '0';
 	if (atten_level == 1) {
@@ -667,7 +669,7 @@ int RIG_FT991::get_preamp()
 	wait_char(';',5, FL991_WAIT_TIME, "get pre", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos)
+	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
 	if (preamp_level == 1) {
 		preamp_label("Amp 1", true);
@@ -767,7 +769,7 @@ int RIG_FT991::get_modeA()
 	wait_char(';',5, FL991_WAIT_TIME, "get mode A", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			if (md <= '9') md = md - '1';
@@ -806,7 +808,7 @@ int RIG_FT991::get_modeB()
 	wait_char(';',5, FL991_WAIT_TIME, "get mode B", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			if (md <= '9') md = md - '1';
@@ -857,7 +859,7 @@ int RIG_FT991::get_bwA()
 		cmd += ';';
 		wait_char(';',5, FL991_WAIT_TIME, "get bw A narrow", ASC);
 		p = replystr.rfind(rsp);
-		if (p == string::npos) { bwA = 0; return bwA; }
+		if (p == std::string::npos) { bwA = 0; return bwA; }
 		if (p + 4 >= replystr.length()) { bwA = 0; return bwA; }
 		if (replystr[p+3] == '1') bwA = 1;	// narrow on
 		else bwA = 0;
@@ -868,7 +870,7 @@ int RIG_FT991::get_bwA()
 	wait_char(';',6, FL991_WAIT_TIME, "get bw A", ASC);
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos) return bwA;
+	if (p == std::string::npos) return bwA;
 	if (p + 5 >= replystr.length()) return bwA;
 
 	replystr[p+5] = 0;
@@ -924,7 +926,7 @@ int RIG_FT991::get_bwB()
 		cmd += ';';
 		wait_char(';',5, FL991_WAIT_TIME, "get bw B narrow", ASC);
 		p = replystr.rfind(rsp);
-		if (p == string::npos) { bwB = 0; return bwB; }
+		if (p == std::string::npos) { bwB = 0; return bwB; }
 		if (p + 4 >= replystr.length()) { bwB = 0; return bwB; }
 		if (replystr[p+3] == '1') bwB = 1;	// narrow on
 		else bwB = 0;
@@ -935,7 +937,7 @@ int RIG_FT991::get_bwB()
 	wait_char(';',6, FL991_WAIT_TIME, "get bw B", ASC);
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos) return bwB;
+	if (p == std::string::npos) return bwB;
 	if (p + 5 >= replystr.length()) return bwB;
 
 	replystr[p+5] = 0;
@@ -978,7 +980,7 @@ bool RIG_FT991::get_if_shift(int &val)
 
 	size_t p = replystr.rfind(rsp);
 	val = progStatus.shift_val;
-	if (p == string::npos) return progStatus.shift;
+	if (p == std::string::npos) return progStatus.shift;
 	val = atoi(&replystr[p+4]);
 	if (replystr[p+3] == '-') val = -val;
 	return (val != 0);
@@ -1025,7 +1027,7 @@ bool  RIG_FT991::get_notch(int &val)
 	wait_char(';',8, FL991_WAIT_TIME, "get notch on/off", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ison;
+	if (p == std::string::npos) return ison;
 
 	if (replystr[p+6] == '1') { // manual notch enabled
 		ison = true;
@@ -1034,7 +1036,7 @@ bool  RIG_FT991::get_notch(int &val)
 		cmd += ';';
 		wait_char(';',8, FL991_WAIT_TIME, "get notch val", ASC);
 		p = replystr.rfind(rsp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			val = 10;
 		else
 			val = fm_decimal(replystr.substr(p+4), 3) * 10;
@@ -1061,7 +1063,7 @@ int  RIG_FT991::get_auto_notch()
 	cmd = "BC0;";
 	wait_char(';',5, FL991_WAIT_TIME, "get auto notch", ASC);
 	size_t p = replystr.rfind("BC0");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (replystr[p+3] == '1') return 1;
 	return 0;
 }
@@ -1080,7 +1082,7 @@ int RIG_FT991::get_noise()
 	wait_char(';',5, FL991_WAIT_TIME, "get NB", ASC);
 
 	size_t p = replystr.rfind("NB0");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	return replystr[p+3] - '0';
 }
 
@@ -1104,7 +1106,7 @@ int RIG_FT991::get_mic_gain()
 	wait_char(';',6, FL991_WAIT_TIME, "get mic", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.mic_gain;
+	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
 	val = (int)(val / 2.50);
 	if (val > 100) val = 100;
@@ -1138,7 +1140,7 @@ int  RIG_FT991::get_rf_gain()
 	wait_char(';',7, FL991_WAIT_TIME, "get rfgain", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.rfgain;
+	if (p == std::string::npos) return progStatus.rfgain;
 	for (int i = 3; i < 6; i++) {
 		rfval *= 10;
 		rfval += replystr[p+i] - '0';
@@ -1263,7 +1265,7 @@ void RIG_FT991::get_band_selection(int v)
 	cmd = "IF;";
 	wait_char(';',28, FL991_WAIT_TIME, "get vfo mode in get_band_selection", ASC);
 	size_t p = replystr.rfind("IF");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	if ((p + 27) >= replystr.length()) return;
 	if (replystr[p+21] != '0') {	// vfo 60M memory mode
 		chan_mem_on = true;
@@ -1306,7 +1308,7 @@ int  RIG_FT991::get_noise_reduction_val()
 	cmd.append(";");
 	wait_char(';',6, FL991_WAIT_TIME, "GET noise reduction val", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return val;
+	if (p == std::string::npos) return val;
 	val = atoi(&replystr[p+3]);
 	return val;
 }
@@ -1326,7 +1328,7 @@ int  RIG_FT991::get_noise_reduction()
 	cmd.append(";");
 	wait_char(';',5, FL991_WAIT_TIME, "GET noise reduction", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	val = replystr[p+3] - '0';
 	return val;
 }
@@ -1339,7 +1341,7 @@ void RIG_FT991::set_xcvr_auto_on()
 	cmd.append(";");
 	wait_char(';', 4, FL991_WAIT_TIME, "Test: Is Rig ON", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) {	// rig is off, power on
+	if (p == std::string::npos) {	// rig is off, power on
 		cmd = "PS1;";
 		sendCommand(cmd);
 		MilliSleep(1100); // 1.0 < T < 2.0 seconds
@@ -1398,7 +1400,7 @@ double RIG_FT991::getVfoAdj()
 	wait_char(';',9, FL991_WAIT_TIME, "get Vfo Adjust", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	return (double)(atoi(&replystr[p+5]));
 }
 
