@@ -154,6 +154,8 @@ void RIG_FTdx10::initialize()
 	sendCommand(cmd);
 	showresp(WARN, ASC, "Auto Info OFF", cmd, replystr);
 	sett("Auto Info OFF");
+
+	get_vfoAorB();
 }
 
 RIG_FTdx10::RIG_FTdx10() {
@@ -230,6 +232,8 @@ RIG_FTdx10::RIG_FTdx10() {
 	notch_on = false;
 	m_60m_indx = 0;
 
+	inuse = onA;
+
 	precision = 1;
 	ndigits = 8;
 
@@ -269,7 +273,7 @@ void RIG_FTdx10::get_band_selection(int v)
 	sett("get band");
 
 	size_t p = replystr.rfind("IF");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	if (replystr[p+22 ] != '0') {	// vfo 60M memory mode
 		inc_60m = true;
 	}
@@ -295,8 +299,8 @@ void RIG_FTdx10::get_band_selection(int v)
 	showresp(WARN, ASC, "Select Band Stacks", cmd, replystr);
 }
 
-//static string Avfo = "FA014070000;";
-//static string Bvfo = "FB007070000;";
+//static std::string Avfo = "FA014070000;";
+//static std::string Bvfo = "FB007070000;";
 
 bool RIG_FTdx10::check ()
 {
@@ -321,7 +325,7 @@ unsigned long int RIG_FTdx10::get_vfoA ()
 	gett("get_vfoA()");
 //replystr = Avfo;
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqA;
+	if (p == std::string::npos) return freqA;
 	int f = 0;
 	for (size_t n = 2; n < 11; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -351,7 +355,7 @@ unsigned long int RIG_FTdx10::get_vfoB ()
 	gett("get_vfoB()");
 //replystr = Bvfo;
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqB;
+	if (p == std::string::npos) return freqB;
 	int f = 0;
 	for (size_t n = 2; n < 11; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -379,20 +383,36 @@ bool RIG_FTdx10::twovfos()
 	return true;
 }
 
+int RIG_FTdx10::get_vfoAorB()
+{
+	cmd = "VS;";
+	rsp = "VS";
+	wait_char(';', 4, 100, "get vfoAorB()", ASC);
+	gett("get vfoAorB()");
+	size_t p = replystr.rfind(rsp);
+	inuse = onA;
+	if (p != std::string::npos)
+		inuse = (replystr[p + 2] == '1') ? onB : onA;
+	return inuse;
+}
+
+
 void RIG_FTdx10::selectA()
 {
-	cmd = "FT2;FR01;";
+	cmd = "VS0;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select A", cmd, replystr);
 	sett("selectA()");
+	inuse = onA;
 }
 
 void RIG_FTdx10::selectB()
 {
-	cmd = "FT3;FR10;";
+	cmd = "VS1;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select B", cmd, replystr);
 	sett("selectB()");
+	inuse = onB;
 }
 
 void RIG_FTdx10::A2B()
@@ -424,12 +444,12 @@ void RIG_FTdx10::set_split(bool val)
 
 int RIG_FTdx10::get_split()
 {
-	cmd = rsp = "ST";
+	cmd = rsp = "FT";
 	cmd += ";";
 	wait_char(';', 4, 100, "Get split", ASC);
 	gett("get split()");
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	int split = replystr[p+2] - '0';
 
 	return (split > 0);
@@ -452,7 +472,7 @@ int RIG_FTdx10::get_smeter()
 	gett("get_smeter()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	mtr = mtr * 100.0 / 256.0;
@@ -468,7 +488,7 @@ int RIG_FTdx10::get_swr()
 	gett("get_swr()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	replystr[p+6] = 0;
 	int mtr = atoi(&replystr[p+3]);
@@ -493,7 +513,7 @@ int RIG_FTdx10::get_power_out()
 	gett("get_power_out()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
  	replystr.erase(p, p + rsp.length());
 	replystr.erase(3);
 	int mtr = atoi(replystr.c_str());
@@ -519,7 +539,7 @@ int RIG_FTdx10::get_alc()
 	gett("get_alc");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 9 >= replystr.length()) return 0;
 	replystr[6] = '\x00';
 	int mtr = atoi(&replystr[p+3]);
@@ -536,7 +556,7 @@ double RIG_FTdx10::get_power_control()
 	gett("get_power_control()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.power_level;
+	if (p == std::string::npos) return progStatus.power_level;
 	if (p + 5 >= replystr.length()) return progStatus.power_level;
 
 	int mtr = atoi(&replystr[p+2]);
@@ -565,7 +585,7 @@ int RIG_FTdx10::get_volume_control()
 	gett("get_volume_control()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.volume;
+	if (p == std::string::npos) return progStatus.volume;
 	if (p + 6 >= replystr.length()) return progStatus.volume;
 	int val = atoi(&replystr[p+3]) * 100 / 250;
 	if (val > 100) val = 100;
@@ -602,7 +622,7 @@ int RIG_FTdx10::get_PTT()
 	gett("get_PTT()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ptt_;
+	if (p == std::string::npos) return ptt_;
 	ptt_ =  (replystr[p+2] != '0' ? 1 : 0);
 	return ptt_;
 }
@@ -636,7 +656,7 @@ int RIG_FTdx10::get_tune()
 	rig_trace(2, "get_tuner status()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (replystr[p+4] == '0') return 0;
 	return 1;
 }
@@ -680,7 +700,7 @@ int RIG_FTdx10::get_attenuator()
 	gett("get_attenuator()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.attenuator;
+	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
 	atten_level = replystr[p+3] - '0';
 	if (atten_level == 1) {
@@ -732,7 +752,7 @@ int RIG_FTdx10::get_preamp()
 	gett("get_preamp()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos)
+	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
 	if (preamp_level == 1) {
 		preamp_label("Amp 1", true);
@@ -783,7 +803,7 @@ int RIG_FTdx10::adjust_bandwidth(int val)
 int RIG_FTdx10::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -837,7 +857,7 @@ int RIG_FTdx10::get_modeA()
 	gett("get_modeA()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			int n = 0;
@@ -871,7 +891,7 @@ int RIG_FTdx10::get_modeB()
 	gett("get_modeB()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			int n = 0;
@@ -918,7 +938,7 @@ int RIG_FTdx10::get_bwA()
 	gett("get_bwA()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return bwA;
+	if (p == std::string::npos) return bwA;
 
 	replystr[p+6] = 0;
 	int bw_idx = fm_decimal(replystr.substr(p+4), 2);
@@ -971,7 +991,7 @@ int RIG_FTdx10::get_bwB()
 
 	size_t p = replystr.rfind(rsp);
 	p = replystr.find(rsp);
-	if (p == string::npos) return bwB;
+	if (p == std::string::npos) return bwB;
 
 	replystr[p+6] = 0;
 	int bw_idx = fm_decimal(replystr.substr(p+4),2);
@@ -991,7 +1011,7 @@ int RIG_FTdx10::get_bwB()
 
 std::string RIG_FTdx10::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -1001,7 +1021,7 @@ std::string RIG_FTdx10::get_BANDWIDTHS()
 
 void RIG_FTdx10::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -1016,7 +1036,7 @@ int RIG_FTdx10::get_modetype(int n)
 
 void RIG_FTdx10::set_if_shift(int val)
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = "IS10+0000;";
 	else
 		cmd = "IS00+0000;";
@@ -1034,7 +1054,7 @@ void RIG_FTdx10::set_if_shift(int val)
 
 bool RIG_FTdx10::get_if_shift(int &val)
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = rsp = "IS1";
 	else
 		cmd = rsp = "IS0";
@@ -1045,7 +1065,7 @@ bool RIG_FTdx10::get_if_shift(int &val)
 
 	size_t p = replystr.rfind(rsp);
 	val = progStatus.shift_val;
-	if (p == string::npos) return progStatus.shift;
+	if (p == std::string::npos) return progStatus.shift;
 	val = atoi(&replystr[p+5]);
 	if (replystr[p+4] == '-') val = -val;
 	return (val != 0);
@@ -1063,7 +1083,7 @@ void RIG_FTdx10::set_notch(bool on, int val)
      {
 	if (on && !notch_on) {
 		notch_on = true;
-		if (useB)
+		if (inuse == onB)
 			cmd = "BP10001;";
 		else
 			cmd = "BP00001;";
@@ -1071,7 +1091,7 @@ void RIG_FTdx10::set_notch(bool on, int val)
 		showresp(WARN, ASC, "SET notch on", cmd, replystr);
 
 
-		if (useB)
+		if (inuse == onB)
 			cmd = "BP11000;";
 		else
 			cmd = "BP01000;";
@@ -1084,7 +1104,7 @@ void RIG_FTdx10::set_notch(bool on, int val)
 		showresp(WARN, ASC, "SET notch freq", cmd, replystr);
 	} else if (!on && notch_on) {
 		notch_on = false;
-		if (useB)
+		if (inuse == onB)
 			cmd = "BP10000;";
 		else
 			cmd = "BP00000;";
@@ -1098,14 +1118,14 @@ void RIG_FTdx10::set_notch(bool on, int val)
 bool  RIG_FTdx10::get_notch(int &val)
 {
 	bool ison = false;
-	if (useB) 
+	if (inuse == onB) 
 		cmd = rsp = "BP10";
 	else
 		cmd = rsp = "BP00";
 	cmd += ';';
 	wait_char(';', 8, 100, "get notch on/off", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ison;
+	if (p == std::string::npos) return ison;
 
 	gett("get_notch()");
 
@@ -1120,7 +1140,7 @@ bool  RIG_FTdx10::get_notch(int &val)
 	gett("get_notch_val()");
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos)
+	if (p == std::string::npos)
 		val = 10;
 	else
 		val = fm_decimal(replystr.substr(p+4), 3) * 10;
@@ -1137,7 +1157,7 @@ void RIG_FTdx10::get_notch_min_max_step(int &min, int &max, int &step)
 
 void RIG_FTdx10::set_auto_notch(int v)
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = "BC10;";
 	else
 		cmd = "BC00;";
@@ -1148,7 +1168,7 @@ void RIG_FTdx10::set_auto_notch(int v)
 
 int  RIG_FTdx10::get_auto_notch()
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = "BC1;";
 	else
 		cmd = "BC0;";
@@ -1157,7 +1177,7 @@ int  RIG_FTdx10::get_auto_notch()
 	gett("get_auto_notch()");
 
 	size_t p = replystr.rfind("BC");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (replystr[p+3] == '1') return 1;
 	return 0;
 }
@@ -1166,7 +1186,7 @@ int FTdx10_blanker_level = 0;
 
 void RIG_FTdx10::set_noise(bool b)
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = "NB10;";
 	else
 		cmd = "NB00;";
@@ -1183,7 +1203,7 @@ void RIG_FTdx10::set_noise(bool b)
 
 int RIG_FTdx10::get_noise()
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = rsp = "NB1";
 	else
 		cmd = rsp = "NB0";
@@ -1193,7 +1213,7 @@ int RIG_FTdx10::get_noise()
 	gett("get_noise()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return FTdx10_blanker_level;
+	if (p == std::string::npos) return FTdx10_blanker_level;
 
 	FTdx10_blanker_level = replystr[p+3] - '0';
 
@@ -1227,7 +1247,7 @@ int RIG_FTdx10::get_mic_gain()
 	gett("get_mic_gain()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.mic_gain;
+	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
 	return val * 100 / 255;
 }
@@ -1261,7 +1281,7 @@ int  RIG_FTdx10::get_rf_gain()
 	gett("get_rf_gain()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.rfgain;
+	if (p == std::string::npos) return progStatus.rfgain;
 	for (int i = 3; i < 6; i++) {
 		rfval *= 10;
 		rfval += replystr[p+i] - '0';
@@ -1406,7 +1426,7 @@ int  RIG_FTdx10::get_noise_reduction_val()
 	cmd.append(";");
 	wait_char(';',6, 100, "GET noise reduction val", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return val;
+	if (p == std::string::npos) return val;
 	val = atoi(&replystr[p+3]);
 	return val;
 }
@@ -1427,7 +1447,7 @@ int  RIG_FTdx10::get_noise_reduction()
 	cmd.append(";");
 	wait_char(';',5, 100, "GET noise reduction", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	val = replystr[p+3] - '0';
 	return val;
 }
