@@ -264,7 +264,7 @@ void RIG_FTdx101D::get_band_selection(int v)
 	sett("get band");
 
 	size_t p = replystr.rfind("IF");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	if (replystr[p+22 ] != '0') {	// vfo 60M memory mode
 		inc_60m = true;
 	}
@@ -290,8 +290,8 @@ void RIG_FTdx101D::get_band_selection(int v)
 	showresp(WARN, ASC, "Select Band Stacks", cmd, replystr);
 }
 
-//static string Avfo = "FA014070000;";
-//static string Bvfo = "FB007070000;";
+//static std::string Avfo = "FA014070000;";
+//static std::string Bvfo = "FB007070000;";
 
 bool RIG_FTdx101D::check ()
 {
@@ -300,7 +300,7 @@ bool RIG_FTdx101D::check ()
 	int ret = wait_char(';', 12 , 100, "check", ASC);
 
 	gett("check()");
-return true;
+
 	if (ret >= 12) return true;
 	return false;
 }
@@ -314,7 +314,7 @@ unsigned long int RIG_FTdx101D::get_vfoA ()
 	gett("get_vfoA()");
 //replystr = Avfo;
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqA;
+	if (p == std::string::npos) return freqA;
 	int f = 0;
 	for (size_t n = 2; n < 11; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -344,7 +344,7 @@ unsigned long int RIG_FTdx101D::get_vfoB ()
 	gett("get_vfoB()");
 //replystr = Bvfo;
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqB;
+	if (p == std::string::npos) return freqB;
 	int f = 0;
 	for (size_t n = 2; n < 11; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -378,6 +378,7 @@ void RIG_FTdx101D::selectA()
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select A", cmd, replystr);
 	sett("selectA()");
+	inuse = onA;
 }
 
 void RIG_FTdx101D::selectB()
@@ -386,6 +387,7 @@ void RIG_FTdx101D::selectB()
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select B", cmd, replystr);
 	sett("selectB()");
+	inuse = onB;
 }
 
 void RIG_FTdx101D::A2B()
@@ -422,7 +424,7 @@ int RIG_FTdx101D::get_split()
 	wait_char(';', 4, 100, "Get split", ASC);
 	gett("get split()");
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	int split = replystr[p+2] - '0';
 
 	return (split > 0);
@@ -445,7 +447,7 @@ int RIG_FTdx101D::get_smeter()
 	gett("get_smeter()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	mtr = mtr * 100.0 / 256.0;
@@ -461,7 +463,7 @@ int RIG_FTdx101D::get_swr()
 	gett("get_swr()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	replystr[p+6] = 0;
 	int mtr = atoi(&replystr[p+3]);
@@ -486,7 +488,7 @@ int RIG_FTdx101D::get_power_out()
 	gett("get_power_out()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
  	replystr.erase(p, p + rsp.length());
 	replystr.erase(3);
 	int mtr = atoi(replystr.c_str());
@@ -512,7 +514,7 @@ int RIG_FTdx101D::get_alc()
 	gett("get_alc");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 9 >= replystr.length()) return 0;
 	replystr[6] = '\x00';
 	int mtr = atoi(&replystr[p+3]);
@@ -529,7 +531,7 @@ double RIG_FTdx101D::get_power_control()
 	gett("get_power_control()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.power_level;
+	if (p == std::string::npos) return progStatus.power_level;
 	if (p + 5 >= replystr.length()) return progStatus.power_level;
 
 	int mtr = atoi(&replystr[p+2]);
@@ -558,7 +560,7 @@ int RIG_FTdx101D::get_volume_control()
 	gett("get_volume_control()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.volume;
+	if (p == std::string::npos) return progStatus.volume;
 	if (p + 6 >= replystr.length()) return progStatus.volume;
 	int val = atoi(&replystr[p+3]) * 100 / 250;
 	if (val > 100) val = 100;
@@ -595,7 +597,7 @@ int RIG_FTdx101D::get_PTT()
 	gett("get_PTT()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ptt_;
+	if (p == std::string::npos) return ptt_;
 	ptt_ =  (replystr[p+2] != '0' ? 1 : 0);
 	return ptt_;
 }
@@ -629,7 +631,7 @@ int RIG_FTdx101D::get_tune()
 	rig_trace(2, "get_tuner status()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (replystr[p+4] == '0') return 0;
 	return 1;
 }
@@ -673,7 +675,7 @@ int RIG_FTdx101D::get_attenuator()
 	gett("get_attenuator()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.attenuator;
+	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
 	atten_level = replystr[p+3] - '0';
 	if (atten_level == 1) {
@@ -725,7 +727,7 @@ int RIG_FTdx101D::get_preamp()
 	gett("get_preamp()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos)
+	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
 	if (preamp_level == 1) {
 		preamp_label("Amp 1", true);
@@ -776,7 +778,7 @@ int RIG_FTdx101D::adjust_bandwidth(int val)
 int RIG_FTdx101D::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -830,7 +832,7 @@ int RIG_FTdx101D::get_modeA()
 	gett("get_modeA()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			int n = 0;
@@ -864,7 +866,7 @@ int RIG_FTdx101D::get_modeB()
 	gett("get_modeB()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			int n = 0;
@@ -915,7 +917,7 @@ int RIG_FTdx101D::get_bwA()
 	gett("get_bwA()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return bwA;
+	if (p == std::string::npos) return bwA;
 
 	replystr[p+6] = 0;
 	int bw_idx = fm_decimal(replystr.substr(p+4), 2);
@@ -983,7 +985,7 @@ int RIG_FTdx101D::get_bwB()
 	gett("get_bwB()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return bwB;
+	if (p == std::string::npos) return bwB;
 
 	replystr[p+6] = 0;
 	int bw_idx = fm_decimal(replystr.substr(p+4),2);
@@ -1017,7 +1019,7 @@ int RIG_FTdx101D::get_bwB()
 
 std::string RIG_FTdx101D::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -1027,7 +1029,7 @@ std::string RIG_FTdx101D::get_BANDWIDTHS()
 
 void RIG_FTdx101D::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -1042,7 +1044,7 @@ int RIG_FTdx101D::get_modetype(int n)
 
 void RIG_FTdx101D::set_if_shift(int val)
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = "IS10+0000;";
 	else
 		cmd = "IS00+0000;";
@@ -1060,7 +1062,7 @@ void RIG_FTdx101D::set_if_shift(int val)
 
 bool RIG_FTdx101D::get_if_shift(int &val)
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = rsp = "IS1";
 	else
 		cmd = rsp = "IS0";
@@ -1071,7 +1073,7 @@ bool RIG_FTdx101D::get_if_shift(int &val)
 
 	size_t p = replystr.rfind(rsp);
 	val = progStatus.shift_val;
-	if (p == string::npos) return progStatus.shift;
+	if (p == std::string::npos) return progStatus.shift;
 	val = atoi(&replystr[p+5]);
 	if (replystr[p+4] == '-') val = -val;
 	return (val != 0);
@@ -1089,7 +1091,7 @@ void RIG_FTdx101D::set_notch(bool on, int val)
      {
 	if (on && !notch_on) {
 		notch_on = true;
-		if (useB)
+		if (inuse == onB)
 			cmd = "BP10001;";
 		else
 			cmd = "BP00001;";
@@ -1097,7 +1099,7 @@ void RIG_FTdx101D::set_notch(bool on, int val)
 		showresp(WARN, ASC, "SET notch on", cmd, replystr);
 
 
-		if (useB)
+		if (inuse == onB)
 			cmd = "BP11000;";
 		else
 			cmd = "BP01000;";
@@ -1110,7 +1112,7 @@ void RIG_FTdx101D::set_notch(bool on, int val)
 		showresp(WARN, ASC, "SET notch freq", cmd, replystr);
 	} else if (!on && notch_on) {
 		notch_on = false;
-		if (useB)
+		if (inuse == onB)
 			cmd = "BP10000;";
 		else
 			cmd = "BP00000;";
@@ -1124,14 +1126,14 @@ void RIG_FTdx101D::set_notch(bool on, int val)
 bool  RIG_FTdx101D::get_notch(int &val)
 {
 	bool ison = false;
-	if (useB) 
+	if (inuse == onB) 
 		cmd = rsp = "BP10";
 	else
 		cmd = rsp = "BP00";
 	cmd += ';';
 	wait_char(';', 8, 100, "get notch on/off", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ison;
+	if (p == std::string::npos) return ison;
 
 	gett("get_notch()");
 
@@ -1146,7 +1148,7 @@ bool  RIG_FTdx101D::get_notch(int &val)
 	gett("get_notch_val()");
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos)
+	if (p == std::string::npos)
 		val = 10;
 	else
 		val = fm_decimal(replystr.substr(p+4), 3) * 10;
@@ -1163,7 +1165,7 @@ void RIG_FTdx101D::get_notch_min_max_step(int &min, int &max, int &step)
 
 void RIG_FTdx101D::set_auto_notch(int v)
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = "BC10;";
 	else
 		cmd = "BC00;";
@@ -1174,7 +1176,7 @@ void RIG_FTdx101D::set_auto_notch(int v)
 
 int  RIG_FTdx101D::get_auto_notch()
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = "BC1;";
 	else
 		cmd = "BC0;";
@@ -1183,7 +1185,7 @@ int  RIG_FTdx101D::get_auto_notch()
 	gett("get_auto_notch()");
 
 	size_t p = replystr.rfind("BC");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (replystr[p+3] == '1') return 1;
 	return 0;
 }
@@ -1192,7 +1194,7 @@ int FTdx101D_blanker_level = 0;
 
 void RIG_FTdx101D::set_noise(bool b)
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = "NB10;";
 	else
 		cmd = "NB00;";
@@ -1209,7 +1211,7 @@ void RIG_FTdx101D::set_noise(bool b)
 
 int RIG_FTdx101D::get_noise()
 {
-	if (useB)
+	if (inuse == onB)
 		cmd = rsp = "NB1";
 	else
 		cmd = rsp = "NB0";
@@ -1219,7 +1221,7 @@ int RIG_FTdx101D::get_noise()
 	gett("get_noise()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return FTdx101D_blanker_level;
+	if (p == std::string::npos) return FTdx101D_blanker_level;
 
 	FTdx101D_blanker_level = replystr[p+3] - '0';
 
@@ -1253,7 +1255,7 @@ int RIG_FTdx101D::get_mic_gain()
 	gett("get_mic_gain()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.mic_gain;
+	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
 	return val * 100 / 255;
 }
@@ -1287,7 +1289,7 @@ int  RIG_FTdx101D::get_rf_gain()
 	gett("get_rf_gain()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.rfgain;
+	if (p == std::string::npos) return progStatus.rfgain;
 	for (int i = 3; i < 6; i++) {
 		rfval *= 10;
 		rfval += replystr[p+i] - '0';
@@ -1480,7 +1482,7 @@ int RIG_FTdx101MP::get_power_out()
 	gett("get_power_out()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
  	replystr.erase(p, p + rsp.length());
 	replystr.erase(3);
 	int mtr = atoi(replystr.c_str());
@@ -1507,7 +1509,7 @@ double RIG_FTdx101MP::get_power_control()
 	gett("get_power_control()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.power_level;
+	if (p == std::string::npos) return progStatus.power_level;
 	if (p + 5 >= replystr.length()) return progStatus.power_level;
 
 	int mtr = atoi(&replystr[p+2]);
@@ -1530,7 +1532,7 @@ double RIG_FTdx101D::get_voltmeter()
 {
 // RM8155000;
 	cmd = "RM8;";
-	string resp = "RM";
+	std::string resp = "RM";
 
 	int mtr = 0;
 	double val = 0;
@@ -1540,7 +1542,7 @@ double RIG_FTdx101D::get_voltmeter()
 	gett("get_voltmeter");
 
 	size_t p = replystr.rfind(resp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		replystr[6] = 0;
 		mtr = atoi(&replystr[p+3]);
 		val = 0.066 * mtr + 0.78;
