@@ -228,7 +228,7 @@ void RIG_FTdx1200::initialize()
 	cmd = "MR118;";
 	wait_char(';', 27, 100, "Read UK 60m Channel Mem", ASC);
 	size_t p = replystr.rfind("MR");
-	if (p == string::npos) {
+	if (p == std::string::npos) {
 		Channels_60m = US_60m_chan;
 		label_60m    = US_60m_label;
 		op_yaesu_select60->clear();
@@ -281,7 +281,7 @@ unsigned long int RIG_FTdx1200::get_vfoA ()
 	get_trace(3, "get_vfoA()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqA;
+	if (p == std::string::npos) return freqA;
 	int f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -311,7 +311,7 @@ unsigned long int RIG_FTdx1200::get_vfoB ()
 	get_trace(3, "get_vfoB()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return freqB;
+	if (p == std::string::npos) return freqB;
 	int f = 0;
 	for (size_t n = 2; n < 10; n++)
 		f = f*10 + replystr[p+n] - '0';
@@ -349,7 +349,7 @@ double RIG_FTdx1200::getVfoAdj()
 	wait_char(';', 9, 100, "get Vfo Adjust", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	return (double)(atoi(&replystr[p+5]));
 }
 
@@ -371,6 +371,7 @@ void RIG_FTdx1200::selectA()
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select A", cmd, replystr);
 	set_trace(3,"selectA", cmd.c_str(), replystr.c_str());
+	inuse = onA;
 }
 
 void RIG_FTdx1200::selectB()
@@ -379,6 +380,7 @@ void RIG_FTdx1200::selectB()
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select B", cmd, replystr);
 	set_trace(3,"selectB", cmd.c_str(), replystr.c_str());
+	inuse = onB;
 }
 
 void RIG_FTdx1200::A2B()
@@ -397,7 +399,7 @@ bool RIG_FTdx1200::can_split()
 void RIG_FTdx1200::set_split(bool val)
 {
 	split = val;
-	if (useB) {
+	if (inuse == onB) {
 		if (val) {
 			cmd = "FR4;FT2;";
 			sendCommand(cmd);
@@ -435,7 +437,7 @@ int RIG_FTdx1200::get_split()
 	cmd.append(";");
 	wait_char(';', 4, 100, "get split tx vfo", ASC);
 	p = replystr.rfind(rsp);
-	if (p == string::npos) return false;
+	if (p == std::string::npos) return false;
 	tx = replystr[p+2] - '0';
 
 // rx vfo
@@ -444,7 +446,7 @@ int RIG_FTdx1200::get_split()
 	wait_char(';', 4, 100, "get split rx vfo", ASC);
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos) return false;
+	if (p == std::string::npos) return false;
 	rx = replystr[p+2] - '0';
 
 	split = (tx == 1 ? 2 : 0) + (rx >= 4 ? 1 : 0);
@@ -462,7 +464,7 @@ int RIG_FTdx1200::get_smeter()
 	get_trace(3, "get_smeter()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	mtr = mtr * 100.0 / 256.0;
@@ -478,7 +480,7 @@ int RIG_FTdx1200::get_swr()
 	get_trace(3, "get_swr()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	return (int)ceil(mtr / 2.56);
@@ -491,7 +493,7 @@ int RIG_FTdx1200::get_alc()
 	wait_char(';', 7, 100, "get alc", ASC);
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	return (int)ceil(mtr / 2.56);
@@ -506,7 +508,7 @@ int RIG_FTdx1200::get_power_out()
 	get_trace(3, "get_power_out()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
 	double mtr = (double)(atoi(&replystr[p+3]));
 
@@ -526,7 +528,7 @@ double RIG_FTdx1200::get_power_control()
 	get_trace(3, "get_power_control()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.power_level;
+	if (p == std::string::npos) return progStatus.power_level;
 	if (p + 5 >= replystr.length()) return progStatus.power_level;
 
 	int mtr = atoi(&replystr[p+2]);
@@ -556,7 +558,7 @@ int RIG_FTdx1200::get_volume_control()
 	get_trace(3, "get_volume_control()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.volume;
+	if (p == std::string::npos) return progStatus.volume;
 	if (p + 6 >= replystr.length()) return progStatus.volume;
 	int val = round(atoi(&replystr[p+3]) / 2.55);
 	if (val > 100) val = 100;
@@ -595,7 +597,7 @@ int RIG_FTdx1200::get_PTT()
 	get_trace(3, "get_PTT()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ptt_;
+	if (p == std::string::npos) return ptt_;
 	ptt_ =  (replystr[p+2] != '0' ? 1 : 0);
 	return ptt_;
 }
@@ -629,7 +631,7 @@ int RIG_FTdx1200::get_tune()
 	rig_trace(2, "get_tuner status()", replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	int val = replystr[p+4] - '0';
 	return !(val < 2);
 }
@@ -651,7 +653,7 @@ void RIG_FTdx1200::tune_rig(int)
 	cmd.append(";");
 	wait_char(';', 6, 100, "is Int. Tuner Enabled", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	if ((p + 5) >= replystr.length()) return;
 	if (replystr[p+4] == '0') {
 		use_int_tuner = false;
@@ -665,11 +667,11 @@ void RIG_FTdx1200::tune_rig(int)
 		if (extun_on == false) {
 			if (btnPTT->value() == true) return;
 			if (get_split() == 1 || get_split() == 2) return;	// no split extune
-			useB ? rmd = modeB : rmd = modeA;
-			useB ? rbw = bwB : rbw = bwA;
-			useB ? rfreq = freqB : rfreq = freqA;
-			useB ? set_modeB(mAM) : set_modeA(mAM);
-			useB ? set_vfoB(rfreq) : set_vfoA(rfreq);
+			inuse == onB ?rmd = modeB : rmd = modeA;
+			inuse == onB ?rbw = bwB : rbw = bwA;
+			inuse == onB ?rfreq = freqB : rfreq = freqA;
+			inuse == onB ?set_modeB(mAM) : set_modeA(mAM);
+			inuse == onB ?set_vfoB(rfreq) : set_vfoA(rfreq);
 			rpwr = get_power_control();
 			set_power_control(10);
 			sendCommand("EX0360000;");	// AM mic off
@@ -684,9 +686,9 @@ void RIG_FTdx1200::tune_rig(int)
 			sendCommand("EX0361000;");	// AM mic default
 //			sendCommand("EX0560050;");	// FM mic default
 			set_power_control(rpwr);
-			useB ? set_modeB(rmd) : set_modeA(rmd);
-			useB ? set_bwB(rbw) : set_bwA(rbw);
-			useB ? set_vfoB(rfreq) : set_vfoA(rfreq);
+			inuse == onB ?set_modeB(rmd) : set_modeA(rmd);
+			inuse == onB ?set_bwB(rbw) : set_bwA(rbw);
+			inuse == onB ?set_vfoB(rfreq) : set_vfoA(rfreq);
 		}
 	}
 }
@@ -732,7 +734,7 @@ int RIG_FTdx1200::get_attenuator()
 	get_trace(3, "get_attenuator()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.attenuator;
+	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
 	atten_level = replystr[p+3] - '0';
 	if (atten_level == 1) {
@@ -785,7 +787,7 @@ int RIG_FTdx1200::get_preamp()
 	get_trace(3, "get_preamp()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos)
+	if (p != std::string::npos)
 		preamp_level = replystr[p+3] - '0';
 	if (preamp_level == 1) {
 		preamp_label("Amp 1", true);
@@ -832,7 +834,7 @@ int RIG_FTdx1200::adjust_bandwidth(int val)
 int RIG_FTdx1200::def_bandwidth(int m)
 {
 	int bw = adjust_bandwidth(m);
-	if (useB) {
+	if (inuse == onB) {
 		if (mode_bwB[m] == -1)
 			mode_bwB[m] = bw;
 		return mode_bwB[m];
@@ -888,7 +890,7 @@ int RIG_FTdx1200::get_modeA()
 	get_trace(3, "get_modeA()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			if (md <= '9') md -= '1';
@@ -930,7 +932,7 @@ int RIG_FTdx1200::get_modeB()
 	get_trace(3, "get_modeB()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p != string::npos) {
+	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
 			int md = replystr[p+3];
 			if (md <= '9') md -= '1';
@@ -988,7 +990,7 @@ int RIG_FTdx1200::get_bwA()
 	get_trace(3, "get_bwA()", cmd.c_str(), replystr.c_str());
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos) return bwA;
+	if (p == std::string::npos) return bwA;
 	if (p + 5 >= replystr.length()) return bwA;
 
 	replystr[p+5] = 0;
@@ -1052,7 +1054,7 @@ int RIG_FTdx1200::get_bwB()
 	get_trace(3, "get_bwB()", cmd.c_str(), replystr.c_str());
 
 	p = replystr.rfind(rsp);
-	if (p == string::npos) return bwB;
+	if (p == std::string::npos) return bwB;
 	if (p + 5 >= replystr.length()) return bwB;
 
 	replystr[p+5] = 0;
@@ -1072,7 +1074,7 @@ int RIG_FTdx1200::get_bwB()
 
 std::string RIG_FTdx1200::get_BANDWIDTHS()
 {
-	stringstream s;
+	std::stringstream s;
 	for (int i = 0; i < NUM_MODES; i++)
 		s << mode_bwA[i] << " ";
 	for (int i = 0; i < NUM_MODES; i++)
@@ -1082,7 +1084,7 @@ std::string RIG_FTdx1200::get_BANDWIDTHS()
 
 void RIG_FTdx1200::set_BANDWIDTHS(std::string s)
 {
-	stringstream strm;
+	std::stringstream strm;
 	strm << s;
 	for (int i = 0; i < NUM_MODES; i++)
 		strm >> mode_bwA[i];
@@ -1120,7 +1122,7 @@ bool RIG_FTdx1200::get_if_shift(int &val)
 
 	size_t p = replystr.rfind(rsp);
 	val = progStatus.shift_val;
-	if (p == string::npos) return progStatus.shift;
+	if (p == std::string::npos) return progStatus.shift;
 	val = atoi(&replystr[p+4]);
 	if (replystr[p+3] == '-') val = -val;
 	return (val != 0);
@@ -1176,7 +1178,7 @@ bool  RIG_FTdx1200::get_notch(int &val)
 	get_trace(3, "get_notch()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return ison;
+	if (p == std::string::npos) return ison;
 
 	if (replystr[p+6] == '1') { // manual notch enabled
 		ison = true;
@@ -1187,7 +1189,7 @@ bool  RIG_FTdx1200::get_notch(int &val)
 
 		get_trace(3, "get_notch_val()", cmd.c_str(), replystr.c_str());
 		p = replystr.rfind(rsp);
-		if (p == string::npos)
+		if (p == std::string::npos)
 			val = 10;
 		else
 			val = fm_decimal(replystr.substr(p+4), 3) * 10;
@@ -1218,7 +1220,7 @@ int  RIG_FTdx1200::get_auto_notch()
 	get_trace(3, "get_auto_notch()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind("BC0");
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	if (replystr[p+3] == '1') return 1;
 	return 0;
 }
@@ -1253,7 +1255,7 @@ int RIG_FTdx1200::get_noise()
 	get_trace(3, "get_noise()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return FTdx1200_blanker_level;
+	if (p == std::string::npos) return FTdx1200_blanker_level;
 
 	FTdx1200_blanker_level = replystr[p+3] - '0';
 	if (FTdx1200_blanker_level == 1) {
@@ -1290,7 +1292,7 @@ int RIG_FTdx1200::get_mic_gain()
 	get_trace(3, "get_mic_gain()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.mic_gain;
+	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
 	val = (int)(val / 2.50);
 	if (val > 100) val = 100;
@@ -1327,7 +1329,7 @@ int  RIG_FTdx1200::get_rf_gain()
 	get_trace(3, "get_rf_gain()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return progStatus.rfgain;
+	if (p == std::string::npos) return progStatus.rfgain;
 	for (int i = 3; i < 6; i++) {
 		rfval *= 10;
 		rfval += replystr[p+i] - '0';
@@ -1465,7 +1467,7 @@ void RIG_FTdx1200::get_band_selection(int v)
 	get_trace(3, "get set_band vfo_mode()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind("IF");
-	if (p == string::npos) return;
+	if (p == std::string::npos) return;
 	if ((p + 26) >= replystr.length()) return;
 	if (replystr[p+21] != '0') {	// vfo 60M memory mode
 		chan_mem_on = true;
@@ -1509,7 +1511,7 @@ int  RIG_FTdx1200::get_noise_reduction_val()
 	cmd.append(";");
 	wait_char(';', 6, 100, "GET noise reduction val", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return val;
+	if (p == std::string::npos) return val;
 	val = atoi(&replystr[p+3]);
 	return val;
 }
@@ -1530,7 +1532,7 @@ int  RIG_FTdx1200::get_noise_reduction()
 	cmd.append(";");
 	wait_char(';', 5, 100, "GET noise reduction", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) return 0;
+	if (p == std::string::npos) return 0;
 	val = replystr[p+3] - '0';
 	return val;
 }
@@ -1543,7 +1545,7 @@ void RIG_FTdx1200::set_xcvr_auto_on()
 	cmd.append(";");
 	wait_char(';', 4, 100, "Test: Is Rig ON", ASC);
 	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) {	// rig is off, power on
+	if (p == std::string::npos) {	// rig is off, power on
 		cmd = "PS1;";
 		sendCommand(cmd);
 		for (int i = 0; i < 1500; i += 100) {
