@@ -50,9 +50,9 @@
 #include "cwioUI.h"
 #include "ptt.h"
 
+// The server
 using namespace XmlRpc;
 
-// The server
 XmlRpcServer rig_server;
 
 //------------------------------------------------------------------------------
@@ -66,7 +66,7 @@ public:
 		result = FLRIG_VERSION;
 	}
 
-	std::string help() { return std::string("returns program version string"); }
+	std::string help() { return std::string("returns program version std::string"); }
 
 } main_get_version(&rig_server);
 
@@ -91,47 +91,47 @@ public:
 //------------------------------------------------------------------------------
 // Request for info
 //------------------------------------------------------------------------------
-string uname;
-string ufreq;
-string umode;
-string unotch;
-string ubw;
-string utx;
-string urfg;
-string uvol;
-string umic;
+std::string uname;
+std::string ufreq;
+std::string umode;
+std::string unotch;
+std::string ubw;
+std::string utx;
+std::string urfg;
+std::string uvol;
+std::string umic;
 
-static string sname()
+static std::string sname()
 {
-	string temp;
+	std::string temp;
 	temp.assign("R:").append(selrig->name_).append("\n");
 	return temp;
 }
 
-static string stx()
+static std::string stx()
 {
-	string temp;
+	std::string temp;
 	temp.assign("T:").append(btnPTT->value() ? "X" : "R").append("\n");
 	return temp;
 }
 
-static string tempfreq;
-static string tempmode;
-static string tempbw;
+static std::string tempfreq;
+static std::string tempmode;
+static std::string tempbw;
 
 static void freq_mode_bw()
 {
-	string temp;
+	std::string temp;
 	int freq = 0;
 	int mode = 0;
 	int BW = 0;
 	static char szval[20];
 
 	snprintf(szval, sizeof(szval), "%d", freq);
-	tempfreq.assign("F").append(useB ? "B:" : "A:").append(szval).append("\n");
+	tempfreq.assign("F").append((selrig->inuse == onB) ? "B:" : "A:").append(szval).append("\n");
 
-	BW = useB ? vfoB.iBW : vfoA.iBW;
-	mode = useB ? vfoB.imode : vfoA.imode;
+	BW = (selrig->inuse == onB) ? vfoB.iBW : vfoA.iBW;
+	mode = (selrig->inuse == onB) ? vfoB.imode : vfoA.imode;
 	const char **bwt = selrig->bwtable(mode);
 	const char **dsplo = selrig->lotable(mode);
 	const char **dsphi = selrig->hitable(mode);
@@ -140,24 +140,24 @@ static void freq_mode_bw()
 
 	tempbw.assign("L:").append((BW > 256 && selrig->has_dsp_controls) ?
 						(dsplo ? dsplo[BW & 0x7F] : "") :
-						(bwt ? bwt[BW] : "")).append("\n");
+						(bwt && bwt[BW]) ? bwt[BW] : "" ).append("\n");
 	tempbw.append("U:").append((BW > 256 && selrig->has_dsp_controls) ?
 						(dsphi ? dsphi[(BW >> 8) & 0x7F] : "") :
 						"").append("\n");
 }
 
-static string snotch()
+static std::string snotch()
 {
-	string temp;
+	std::string temp;
 	static char szval[20];
 	snprintf(szval, sizeof(szval), "%d", (int)(progStatus.notch_val));
 	temp.assign("N:").append(szval).append("\n");
 	return temp;
 }
 
-static string svol()
+static std::string svol()
 {
-	string temp;
+	std::string temp;
 	static char szval[20];
 	int volval = 0;
 	if (spnrVOLUME) volval = spnrVOLUME->value();
@@ -167,9 +167,9 @@ static string svol()
 	return temp;
 }
 
-static string srfg()
+static std::string srfg()
 {
-	string temp;
+	std::string temp;
 	static char szval[20];
 	int rfgval = 0;
 	if (spnrRFGAIN) rfgval = spnrRFGAIN->value();
@@ -179,9 +179,9 @@ static string srfg()
 	return temp;
 }
 
-static string smic()
+static std::string smic()
 {
-	string temp;
+	std::string temp;
 	static char szval[20];
 	int micval = 0;
 	if (sldrMICGAIN) micval = sldrMICGAIN->value();
@@ -196,7 +196,7 @@ public:
 	rig_get_info(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_info", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		string info = "";
+		std::string info = "";
 
 		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = info;
@@ -218,7 +218,7 @@ public:
 
 	}
 
-	std::string help() { return std::string("returns all info in single string"); }
+	std::string help() { return std::string("returns all info in single std::string"); }
 
 } rig_get_info(&rig_server);
 
@@ -227,8 +227,8 @@ public:
 	rig_get_update(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_update", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		string info;  info.clear();
-		string temp;  temp.clear();
+		std::string info;  info.clear();
+		std::string temp;  temp.clear();
 
 		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = info;
@@ -264,7 +264,7 @@ public:
 
 	}
 
-	std::string help() { return std::string("returns all updates in single string"); }
+	std::string help() { return std::string("returns all updates in single std::string"); }
 
 } rig_get_update(&rig_server);
 
@@ -347,7 +347,7 @@ public:
 			if (progStatus.split && PTT) freq = vfoB.freq;
 			else freq = vfoA.freq;
 		} else {
-			if (useB)
+			if (selrig->inuse == onB)
 				freq = vfoB.freq;
 			else
 				freq = vfoA.freq;
@@ -380,7 +380,7 @@ public:
 		guard_lock serial(&mutex_serial);
 
 		vfoA.freq = selrig->get_vfoA();
-		Fl::awake(setFreqDispA, (void *)vfoA.freq);
+		Fl::awake(setFreqDispA);
 
 		static char szfreq[20];
 		snprintf(szfreq, sizeof(szfreq), "%d", (int)vfoA.freq);
@@ -409,7 +409,7 @@ public:
 		guard_lock serial(&mutex_serial);
 
 		vfoB.freq = selrig->get_vfoB();
-		Fl::awake(setFreqDispB, (void *)vfoB.freq);
+		Fl::awake(setFreqDispB);
 
 		static char szfreq[20];
 		snprintf(szfreq, sizeof(szfreq), "%d", (int)vfoB.freq);
@@ -439,8 +439,8 @@ public:
 
 		wait();
 		guard_lock service_lock(&mutex_srvc_reqs, "xml rig_get_AB");
-		xml_trace(2, "rig_get_AB: " , (useB ? "B" : "A"));
-		result = useB ? "B" : "A";
+		xml_trace(2, "rig_get_AB: " , ((selrig->inuse == onB) ? "B" : "A"));
+		result = (selrig->inuse == onB) ? "B" : "A";
 	}
 
 	std::string help() { return std::string("returns vfo in use A or B"); }
@@ -815,7 +815,8 @@ public:
 		int min, max, step;
 		selrig->get_vol_min_max_step(min, max, step);
 
-		static int change = (int)(params[0]);
+		int change = (int)(params[0]);
+std::cout << "vol change: " << change << " --> " << (progStatus.volume + change) << std::endl;
 		progStatus.volume += change;
 		if (progStatus.volume > max) progStatus.volume = max;
 		if (progStatus.volume < min) progStatus.volume = min;
@@ -918,7 +919,7 @@ public:
 
 		std::string result_string = "none";
 		if (selrig->modes_) result_string = selrig->modes_[mode];
-		xml_trace(2, "mode on ", (useB ? "B " : "A "), result_string.c_str());
+		xml_trace(2, "mode on ", ((selrig->inuse == onB) ? "B " : "A "), result_string.c_str());
 		result = result_string;
 
 	}
@@ -1011,7 +1012,7 @@ public :
 		wait();
 		guard_lock service_lock(&mutex_srvc_reqs, "xml rig_get_bws");
 
-		int mode = useB ? vfoB.imode : vfoA.imode;
+		int mode = (selrig->inuse == onB) ? vfoB.imode : vfoA.imode;
 		const char **bwt = selrig->bwtable(mode);
 		const char **dsplo = selrig->lotable(mode);
 		const char **dsphi = selrig->hitable(mode);
@@ -1073,8 +1074,8 @@ public:
 		wait();
 		guard_lock service_lock(&mutex_srvc_reqs, "xml rig_get_bw");
 
-		int BW = useB ? vfoB.iBW : vfoA.iBW;
-		int mode = useB ? vfoB.imode : vfoA.imode;
+		int BW = (selrig->inuse == onB) ? vfoB.iBW : vfoA.iBW;
+		int mode = (selrig->inuse == onB) ? vfoB.imode : vfoA.imode;
 
 		const char **bwt = selrig->bwtable(mode);
 		const char **dsplo = selrig->lotable(mode);
@@ -1107,7 +1108,7 @@ public:
 			if (dsphi) result[1] = dsphi[SH];
 		}
 		std::string s1 = result[0], s2 = result[1];
-		xml_trace( 5, "bandwidth on ", (useB ? "B " : "A "), s1.c_str(), " | ", s2.c_str());
+		xml_trace( 5, "bandwidth on ", ((selrig->inuse == onB) ? "B " : "A "), s1.c_str(), " | ", s2.c_str());
 	}
 
 	std::string help() { return std::string("returns current bw L/U value"); }
@@ -1383,8 +1384,8 @@ public:
 #include <queue>
 #include "rigbase.h"
 
-extern queue<VFOQUEUE> srvc_reqs;
-extern queue<bool> quePTT;
+extern std::queue<VFOQUEUE> srvc_reqs;
+extern std::queue<bool> quePTT;
 
 extern XCVR_STATE vfoA;
 extern XCVR_STATE vfoB;
@@ -1392,7 +1393,7 @@ extern XCVR_STATE vfoB;
 std::string print(int f, int m, int b)
 {
 	static std::ostringstream p;
-	p.seekp(ios::beg);
+	p.seekp(std::ios::beg);
 	if (b > 65536) b /= 65536;
 	p << "freq: " << f << ", imode: " << m << ", bw " << b;
 	return p.str();
@@ -1528,14 +1529,14 @@ public:
 		xml_trace(1, (PTT ? "rig_set_verify_ptt ON" : "rig_set_verify_ptt OFF"));
 		rigPTT(PTT);
 		{
-			bool get = rigPTT();
+			bool get = ptt_state();
 			int cnt = 0;
 			while ((get != PTT) && (cnt++ < 100)) {
 				MilliSleep(10);
-				get = rigPTT();
+				get = ptt_state();
 			}
 			PTT = get;
-			stringstream s;
+			std::stringstream s;
 			s << "ptt returned " << get << " in " << cnt * 10 << " msec";
 			xml_trace(1, s.str().c_str());
 			Fl::awake(update_UI_PTT);
@@ -1822,7 +1823,7 @@ public:
 
 		guard_lock serial(&mutex_serial);
 
-		if (!selrig->can_change_alt_vfo  && useB) {
+		if (!selrig->can_change_alt_vfo  && (selrig->inuse == onB)) {
 			selrig->selectA();
 			vfoA.freq = freq;
 			selrig->set_vfoA(vfoA.freq);
@@ -1832,7 +1833,7 @@ public:
 			selrig->set_vfoA(vfoA.freq);
 		}
 
-		Fl::awake(setFreqDispA, (void *)vfoA.freq);
+		Fl::awake(setFreqDispA);
 
 	}
 	std::string help() { return std::string("rig.set_vfo NNNNNNNN (Hz)"); }
@@ -1852,7 +1853,7 @@ public:
 
 		guard_lock serial(&mutex_serial);
 
-		if (!selrig->can_change_alt_vfo  && useB) {
+		if (!selrig->can_change_alt_vfo  && (selrig->inuse == onB)) {
 			selrig->selectA();
 			selrig->set_vfoA(freq);
 			vfoA.freq = selrig->get_vfoA();
@@ -1862,7 +1863,7 @@ public:
 			vfoA.freq = selrig->get_vfoA();
 		}
 
-		Fl::awake(setFreqDispA, (void *)vfoA.freq);
+		Fl::awake(setFreqDispA);
 	}
 	std::string help() { return std::string("rig.set_verify_vfo NNNNNNNN (Hz)"); }
 
@@ -1881,7 +1882,7 @@ public:
 
 		guard_lock serial(&mutex_serial);
 
-		if (!selrig->can_change_alt_vfo  && useB) {
+		if (!selrig->can_change_alt_vfo  && (selrig->inuse == onB)) {
 			selrig->selectA();
 			vfoA.freq = freq;
 			selrig->set_vfoA(vfoA.freq);
@@ -1891,7 +1892,7 @@ public:
 			selrig->set_vfoA(vfoA.freq);
 		}
 
-		Fl::awake(setFreqDispA, (void *)vfoA.freq);
+		Fl::awake(setFreqDispA);
 	}
 	std::string help() { return std::string("deprecated; use rig.set_vfoA"); }
 
@@ -1910,7 +1911,7 @@ public:
 
 		guard_lock serial(&mutex_serial);
 
-		if (!selrig->can_change_alt_vfo  && useB) {
+		if (!selrig->can_change_alt_vfo  && (selrig->inuse == onB)) {
 			selrig->selectA();
 			vfoA.freq += freq;
 			selrig->set_vfoA(vfoA.freq);
@@ -1920,7 +1921,7 @@ public:
 			selrig->set_vfoA(vfoA.freq);
 		}
 
-		Fl::awake(setFreqDispA, (void *)vfoA.freq);
+		Fl::awake(setFreqDispA);
 
 	}
 	std::string help() { return std::string("rig.mod_vfo +/- NNN (Hz)"); }
@@ -1944,7 +1945,7 @@ public:
 
 		guard_lock serial(&mutex_serial);
 
-		if (!selrig->can_change_alt_vfo  && !useB) {
+		if (!selrig->can_change_alt_vfo  && (selrig->inuse == onA)) {
 			selrig->selectB();
 			selrig->set_vfoB(freq);
 			vfoB.freq = freq;
@@ -1954,7 +1955,7 @@ public:
 			vfoB.freq = freq;
 		}
 
-		Fl::awake(setFreqDispB, (void *)vfoB.freq);
+		Fl::awake(setFreqDispB);
 	}
 	std::string help() { return std::string("rig.set_vfo NNNNNNNN (Hz)"); }
 
@@ -1973,7 +1974,7 @@ public:
 
 		guard_lock serial(&mutex_serial);
 
-		if (!selrig->can_change_alt_vfo  && !useB) {
+		if (!selrig->can_change_alt_vfo  && (selrig->inuse == onA)) {
 			selrig->selectB();
 			selrig->set_vfoB(freq);
 			vfoB.freq = selrig->get_vfoB();
@@ -1983,7 +1984,7 @@ public:
 			vfoB.freq = selrig->get_vfoB();
 		}
 
-		Fl::awake(setFreqDispB, (void *)vfoB.freq);
+		Fl::awake(setFreqDispB);
 	}
 	std::string help() { return std::string("rig.set_verify_vfo NNNNNNNN (Hz)"); }
 
@@ -2002,7 +2003,7 @@ public:
 
 		guard_lock serial(&mutex_serial);
 
-		if (!selrig->can_change_alt_vfo  && !useB) {
+		if (!selrig->can_change_alt_vfo  && (selrig->inuse == onA)) {
 			selrig->selectB();
 			selrig->set_vfoB(freq);
 			vfoB.freq = freq;
@@ -2012,7 +2013,7 @@ public:
 			vfoB.freq = freq;
 		}
 
-		Fl::awake(setFreqDispB, (void *)vfoB.freq);
+		Fl::awake(setFreqDispB);
 	}
 	std::string help() { return std::string("deprecated; use rig.set_vfoB"); }
 
@@ -2031,7 +2032,7 @@ public:
 
 		guard_lock serial(&mutex_serial);
 
-		if (!selrig->can_change_alt_vfo  && !useB) {
+		if (!selrig->can_change_alt_vfo  && (selrig->inuse == onA)) {
 			selrig->selectB();
 			selrig->set_vfoB(vfoB.freq);
 			vfoB.freq += freq;
@@ -2041,7 +2042,7 @@ public:
 			vfoB.freq += freq;
 		}
 
-		Fl::awake(setFreqDispB, (void *)vfoB.freq);
+		Fl::awake(setFreqDispB);
 
 	}
 	std::string help() { return std::string("rig.mod_vfoB +/- NNN (Hz)"); }
@@ -2070,7 +2071,7 @@ public:
 		selrig->set_vfoB(vfoB.freq);
 		selrig->set_modeB(vfoB.imode);
 
-		Fl::awake(setFreqDispB, (void *)vfoB.freq);
+		Fl::awake(setFreqDispB);
 
 	}
 	std::string help() { return std::string("sets vfoB to vfoA freq/mode"); }
@@ -2097,7 +2098,7 @@ public:
 
 		selrig->set_vfoB(vfoB.freq);
 
-		Fl::awake(setFreqDispB, (void *)vfoB.freq);
+		Fl::awake(setFreqDispB);
 
 	}
 	std::string help() { return std::string("sets freqB to freqA"); }
@@ -2145,14 +2146,14 @@ public:
 		unsigned long int freq = static_cast<unsigned long int>(double(params[0]));
 
 		guard_lock serial(&mutex_serial);
-		if (useB) {
+		if (selrig->inuse == onB) {
 			selrig->set_vfoB(freq);
 			vfoB.freq = freq;
-			Fl::awake(setFreqDispB, (void *)vfoB.freq);
+			Fl::awake(setFreqDispB);
 		}else {
 			selrig->set_vfoA(freq);
 			vfoA.freq = freq;
-			Fl::awake(setFreqDispA, (void *)vfoA.freq);
+			Fl::awake(setFreqDispA);
 		}
 
 	}
@@ -2172,14 +2173,14 @@ public:
 		unsigned long int freq = static_cast<unsigned long int>(double(params[0]));
 
 		guard_lock serial(&mutex_serial);
-		if (useB) {
+		if (selrig->inuse == onB) {
 			selrig->set_vfoB(freq);
 			vfoB.freq = selrig->get_vfoB();
-			Fl::awake(setFreqDispB, (void *)vfoB.freq);
+			Fl::awake(setFreqDispB);
 		}else {
 			selrig->set_vfoA(freq);
 			vfoA.freq = selrig->get_vfoA();
-			Fl::awake(setFreqDispA, (void *)vfoA.freq);
+			Fl::awake(setFreqDispA);
 		}
 
 	}
@@ -2200,14 +2201,14 @@ public:
 		unsigned long int freq = static_cast<unsigned long int>(double(params[0]));
 
 		guard_lock serial(&mutex_serial);
-		if (useB) {
+		if (selrig->inuse == onB) {
 			selrig->set_vfoB(freq);
 			vfoB.freq = freq;
-			Fl::awake(setFreqDispB, (void *)vfoB.freq);
+			Fl::awake(setFreqDispB);
 		}else {
 			selrig->set_vfoA(freq);
 			vfoA.freq = freq;
-			Fl::awake(setFreqDispA, (void *)vfoA.freq);
+			Fl::awake(setFreqDispA);
 		}
 
 	}
@@ -2227,14 +2228,14 @@ public:
 		unsigned long int freq = static_cast<unsigned long int>(double(params[0]));
 
 		guard_lock serial(&mutex_serial);
-		if (useB) {
+		if (selrig->inuse == onB) {
 			selrig->set_vfoB(freq);
 			vfoB.freq = freq;
-			Fl::awake(setFreqDispB, (void *)vfoB.freq);
+			Fl::awake(setFreqDispB);
 		}else {
 			selrig->set_vfoA(freq);
 			vfoA.freq = freq;
-			Fl::awake(setFreqDispA, (void *)vfoA.freq);
+			Fl::awake(setFreqDispA);
 		}
 
 		result = 1;
@@ -2255,14 +2256,14 @@ public:
 		unsigned long int freq = static_cast<unsigned long int>(double(params[0]));
 
 		guard_lock serial(&mutex_serial);
-		if (useB) {
+		if (selrig->inuse == onB) {
 			selrig->set_vfoB(freq);
 			vfoB.freq = selrig->get_vfoB();
-			Fl::awake(setFreqDispB, (void *)vfoB.freq);
+			Fl::awake(setFreqDispB);
 		}else {
 			selrig->set_vfoA(freq);
 			vfoA.freq = selrig->get_vfoA();
-			Fl::awake(setFreqDispA, (void *)vfoA.freq);
+			Fl::awake(setFreqDispA);
 		}
 
 		result = 1;
@@ -2290,7 +2291,7 @@ public:
 		nuvals.imode = -1;
 		nuvals.iBW = 255;
 
-		std::string numode = (string)params[0];
+		std::string numode = (std::string)params[0];
 		int i = 0;
 
 		if (!selrig->modes_) {
@@ -2303,7 +2304,7 @@ public:
 				nuvals.imode = i;
 				nuvals.iBW = selrig->def_bandwidth(i);
 				guard_lock serial_lock(&mutex_serial);
-				if (useB) {
+				if (selrig->inuse == onB) {
 					serviceB(nuvals);
 				} else {
 					serviceA(nuvals);
@@ -2336,7 +2337,7 @@ public:
 		nuvals.imode = -1;
 		nuvals.iBW = 255;
 
-		std::string numode = (string)params[0];
+		std::string numode = (std::string)params[0];
 		int i = 0;
 
 		if (!selrig->modes_) {
@@ -2348,7 +2349,7 @@ public:
 				nuvals.imode = i;
 				nuvals.iBW = selrig->def_bandwidth(i);
 				guard_lock serial_lock(&mutex_serial);
-				if (useB) {
+				if (selrig->inuse == onB) {
 					serviceB(nuvals);
 					result = (i == selrig->get_modeB());
 				} else {
@@ -2388,7 +2389,7 @@ public:
 		nuvals.imode = -1;
 		nuvals.iBW = 255;
 
-		std::string numode = (string)params[0];
+		std::string numode = (std::string)params[0];
 		int i = 0;
 
 		if (!selrig->modes_) {
@@ -2430,7 +2431,7 @@ public:
 		nuvals.imode = -1;
 		nuvals.iBW = 255;
 
-		std::string numode = (string)params[0];
+		std::string numode = (std::string)params[0];
 		int i = 0;
 
 		if (!selrig->modes_) {
@@ -2475,7 +2476,7 @@ public:
 		nuvals.imode = -1;
 		nuvals.iBW = 255;
 
-		std::string numode = (string)params[0];
+		std::string numode = (std::string)params[0];
 		int i = 0;
 
 		if (!selrig->modes_) {
@@ -2516,7 +2517,7 @@ public:
 		nuvals.imode = -1;
 		nuvals.iBW = 255;
 
-		std::string numode = (string)params[0];
+		std::string numode = (std::string)params[0];
 		int i = 0;
 
 		if (!selrig->modes_) {
@@ -2566,13 +2567,13 @@ public:
 		if (!selrig->bandwidths_[i]) i--;
 		bw = atol(selrig->bandwidths_[i]);
 
-		ostringstream s;
+		std::ostringstream s;
 		s << "nearest bandwidth " << selrig->bandwidths_[i];
 		xml_trace(2,"Set to ", s.str().c_str());
 
 		XCVR_STATE nuvals;
 		nuvals.iBW = i;
-		if (useB) {
+		if (selrig->inuse == onB) {
 			nuvals.freq = vfoB.freq;
 			nuvals.imode = vfoB.imode;
 			serviceB(nuvals);
@@ -2608,14 +2609,14 @@ public:
 		if (!selrig->bandwidths_[i]) i--;
 		bw = atol(selrig->bandwidths_[i]);
 
-		ostringstream s;
+		std::ostringstream s;
 		s << "nearest bandwidth " << selrig->bandwidths_[i];
 		xml_trace(2,"Set to ", s.str().c_str());
 
 		XCVR_STATE nuvals;
 		int retbw;
 		nuvals.iBW = i;
-		if (useB) {
+		if (selrig->inuse == onB) {
 			nuvals.freq = vfoB.freq;
 			nuvals.imode = vfoB.imode;
 			serviceB(nuvals);
@@ -2648,7 +2649,7 @@ public:
 		guard_lock que_lock ( &mutex_srvc_reqs, "xml rig_set_bw" );
 		XCVR_STATE nuvals;
 		nuvals.iBW = bw;
-		if (useB) {
+		if (selrig->inuse == onB) {
 			nuvals.freq = vfoB.freq;
 			nuvals.imode = vfoB.imode;
 			serviceB(nuvals);
@@ -2672,7 +2673,7 @@ public:
 			result = 0;
 			return;
 		}
-		string bwstr = params;
+		std::string bwstr = params;
 
 		int bw = (int)params[0];
 		guard_lock que_lock ( &mutex_srvc_reqs, "xml rig_set_verify_bw" );
@@ -2680,7 +2681,7 @@ public:
 		XCVR_STATE nuvals;
 		int retbw;
 		nuvals.iBW = bw;
-		if (useB) {
+		if (selrig->inuse == onB) {
 			nuvals.freq = vfoB.freq;
 			nuvals.imode = vfoB.imode;
 			serviceB(nuvals);
@@ -2706,7 +2707,7 @@ public:
 			result = 0;
 			return;
 		}
-		string bwstr = params;
+		std::string bwstr = params;
 
 		int bw = (int)params[0];
 		guard_lock que_lock ( &mutex_srvc_reqs, "xml rig_set_BW" );
@@ -2719,7 +2720,7 @@ public:
 			return;
 		}
 		XCVR_STATE nuvals;
-		if (useB) {
+		if (selrig->inuse == onB) {
 			nuvals.freq = vfoB.freq;
 			nuvals.imode = vfoB.imode;
 			nuvals.iBW = bw;
@@ -2746,7 +2747,7 @@ public:
 			result = 0;
 			return;
 		}
-		string bwstr = params;
+		std::string bwstr = params;
 
 		int bw = (int)params[0];
 		guard_lock que_lock ( &mutex_srvc_reqs, "xml rig_set_BW" );
@@ -2762,7 +2763,7 @@ public:
 		XCVR_STATE nuvals;
 		int retbw;
 		nuvals.iBW = bw;
-		if (useB) {
+		if (selrig->inuse == onB) {
 			nuvals.freq = vfoB.freq;
 			nuvals.imode = vfoB.imode;
 			serviceB(nuvals);
@@ -2796,7 +2797,7 @@ public:
 
 		guard_lock lock(&mutex_srvc_reqs, "xml rig_mod_bandwidth");
 
-		if (useB) {
+		if (selrig->inuse == onB) {
 			nuvals.freq  = vfoB.freq;
 			nuvals.imode = vfoB.imode;
 			nuvals.iBW   = vfoB.iBW;
@@ -2823,12 +2824,12 @@ public:
 		if (!widths[i]) i--;
 		bw = atol(widths[i]);
 
-		ostringstream s;
+		std::ostringstream s;
 		s << "nearest bandwidth " << widths[i];
 		xml_trace(2,"Set to ", s.str().c_str());
 
 		nuvals.iBW = i;
-		if (useB) {
+		if (selrig->inuse == onB) {
 			serviceB(nuvals);
 		} else {
 			serviceA(nuvals);
@@ -2855,11 +2856,11 @@ public:
 		if (command.empty()) return;
 
 		std::string cmd = "";
-		if (command.find("x") != string::npos) { // hex strings
+		if (command.find("x") != std::string::npos) { // hex std::strings
 			size_t p = 0;
 			unsigned int val;
 			usehex = true;
-			while (( p = command.find("x", p)) != string::npos) {
+			while (( p = command.find("x", p)) != std::string::npos) {
 				sscanf(&command[p+1], "%x", &val);
 				cmd += (unsigned char) val;
 				p += 3;
@@ -2887,7 +2888,7 @@ public:
 		xml_trace(2, "xmlrpc command:", command.c_str());
 	}
 
-	std::string help() { return std::string("sends xmlrpc CAT string to xcvr"); }
+	std::string help() { return std::string("sends xmlrpc CAT std::string to xcvr"); }
 
 } rig_cat_string(&rig_server);
 
@@ -2904,10 +2905,10 @@ public:
 		if (command.empty()) return;
 
 		std::string cmd = "";
-		if (command.find("x") != string::npos) { // hex strings
+		if (command.find("x") != std::string::npos) { // hex std::strings
 			size_t p = 0;
 			unsigned int val;
-			while (( p = command.find("x", p)) != string::npos) {
+			while (( p = command.find("x", p)) != std::string::npos) {
 				sscanf(&command[p+1], "%x", &val);
 				cmd += (unsigned char) val;
 				p += 3;
@@ -2924,7 +2925,7 @@ public:
 		return;
 	}
 
-	std::string help() { return std::string("sends xmlrpc priority CAT string to xcvr"); }
+	std::string help() { return std::string("sends xmlrpc priority CAT std::string to xcvr"); }
 
 } rig_cat_priority(&rig_server);
 
@@ -2983,20 +2984,17 @@ public:
 
 
 //------------------------------------------------------------------------------
-// Set cwio transmit string
+// Set cwio transmit std::string
 //------------------------------------------------------------------------------
 
-extern void add_cwio(string);
-string cwio_text;
-
 class rig_cwio_text : public XmlRpcServerMethod {
 public:
 	rig_cwio_text(XmlRpcServer* s) : XmlRpcServerMethod("rig.cwio_text", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		std::string s = (string)params[0];
+		std::string s = (std::string)params[0];
 		guard_lock lck(&cwio_text_mutex);
-		cwio_text.append(s);
+		add_cwio(s);
 	}
 
 	std::string help() { return std::string("sends text using cwio DTR/RTS keying"); }
@@ -3004,18 +3002,18 @@ public:
 } rig_cwio_text(&rig_server);
 
 //------------------------------------------------------------------------------
-// Set fskio transmit string
+// Set fskio transmit std::string
 //------------------------------------------------------------------------------
 
-extern void FSK_add(string);
-static string fskio_text;
+extern void FSK_add(std::string);
+static std::string fskio_text;
 
 class rig_fskio_text : public XmlRpcServerMethod {
 public:
 	rig_fskio_text(XmlRpcServer* s) : XmlRpcServerMethod("rig.fskio_text", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		std::string s = (string)params[0];
+		std::string s = (std::string)params[0];
 		FSK_add(s);
 	}
 
@@ -3079,16 +3077,16 @@ public:
 
 
 struct MLIST {
-	string name; string signature; string help;
+	std::string name; std::string signature; std::string help;
 } mlist[] = {
 	{ "main.set_frequency", "d:d", "set current VFO in Hz" },
-	{ "main.get_version", "s:n", "returns version string" },
+	{ "main.get_version", "s:n", "returns version std::string" },
 	{ "rig.get_AB",       "s:n", "returns vfo in use A or B" },
 	{ "rig.get_bw",       "A:n", "return BW of current VFO" },
 	{ "rig.get_bws",      "A:n", "return table of BW values" },
 	{ "rig.get_bwA",      "A:n", "return BW of vfo A" },
 	{ "rig.get_bwB",      "A:n", "return BW of vfo B" },
-	{ "rig.get_info",     "s:n", "return an info string" },
+	{ "rig.get_info",     "s:n", "return an info std::string" },
 	{ "rig.get_mode",     "s:n", "return MODE of current VFO" },
 	{ "rig.get_modeA",    "s:n", "return MODE of current VFO A" },
 	{ "rig.get_modeB",    "s:n", "return MODE of current VFO B" },
@@ -3157,8 +3155,8 @@ struct MLIST {
 
 	{ "rig.swap",         "n:n", "execute vfo swap" },
 	{ "rig.tune",         "n:n", "enable transceiver tune function"},
-	{ "rig.cat_string",   "s:s", "execute CAT string" },
-	{ "rig.cat_priority", "s:s", "priority CAT string" },
+	{ "rig.cat_string",   "s:s", "execute CAT std::string" },
+	{ "rig.cat_priority", "s:s", "priority CAT std::string" },
 	{ "rig.shutdown",     "i:n", "shutdown xcvr & flrig" },
 	{ "rig.cwio_set_wpm", "n:i", "set cwio WPM" },
 	{ "rig.cwio_text",    "i:s", "send text via cwio interface" },
@@ -3184,7 +3182,7 @@ public:
 	rig_list_methods(XmlRpcServer *s) : XmlRpcServerMethod("rig.list_methods", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		vector<XmlRpcValue> methods;
+		std::vector<XmlRpcValue> methods;
 		for (size_t n = 0; n < sizeof(mlist) / sizeof(*mlist); ++n) {
 			XmlRpcValue::ValueStruct item;
 			item["name"]      = mlist[n].name;
@@ -3241,9 +3239,9 @@ void set_server_port(int port)
 
 std::string print_xmlhelp()
 {
-	static string pstr;
+	static std::string pstr;
 	pstr.clear();
-	string line;
+	std::string line;
 	size_t f1_len = 0;
 	for (size_t n = 0; n < sizeof(mlist) / sizeof(*mlist); ++n) {
 		if (mlist[n].name.length() > f1_len) f1_len = mlist[n].name.length();
