@@ -54,8 +54,6 @@
 #include "cwioUI.h"
 #include "fskioUI.h"
 
-using namespace std;
-
 Fl_Double_Window *dlgDisplayConfig = NULL;
 Fl_Double_Window *dlgXcvrConfig = NULL;
 Fl_Double_Window *dlgMemoryDialog = NULL;
@@ -1026,7 +1024,7 @@ void setColors()
 	progStatus.tab_green = tab_green;
 	progStatus.tab_blue = tab_blue;
 
-	if (useB) {
+	if (selrig->inuse == onB) {
 		FreqDispB->SetONOFFCOLOR( fl_rgb_color(fg_red, fg_green, fg_blue), bgclr);
 		FreqDispA->SetONOFFCOLOR(
 			fl_rgb_color(fg_red, fg_green, fg_blue),
@@ -1297,6 +1295,18 @@ void openMemoryDialog()
 
 void show_controls()
 {
+	Fl_Widget * vtab = (Fl_Widget *)0;
+	if (tabsGeneric && !progStatus.visible_tab.empty()) {
+		Fl_Widget * const *vtabs = tabsGeneric->array();
+		int ntabs = tabsGeneric->children();
+		for (int n = 0; n < ntabs; n++) {
+			if (progStatus.visible_tab == vtabs[n]->label()) {
+				vtab = vtabs[n];
+			}
+			vtabs[n]->redraw();
+		}
+	}
+
 	switch (progStatus.UIsize) {
 		case touch_ui : {
 			if (selrig->name_ == rig_TT550.name_) {
@@ -1321,16 +1331,6 @@ void show_controls()
 				tabsGeneric->show();
 				tabsGeneric->redraw();
 			}
-			Fl_Widget * vtab = (Fl_Widget *)0;
-			if (tabsGeneric) {
-				Fl_Widget * const *vtabs = tabsGeneric->array();
-				int ntabs = tabsGeneric->children();
-				for (int n = 0; n < ntabs; n++)
-					if (progStatus.visible_tab == vtabs[n]->label()) {
-						vtab = vtabs[n];
-						break;
-					}
-			}
 			if (progStatus.embed_tabs) { // embedded
 				int X = mainwindow->x(),
 					Y = mainwindow->y(),
@@ -1360,14 +1360,17 @@ void show_controls()
 					tabs->show();
 					progStatus.show_tabs = true;
 
-					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
 					mainwindow->redraw();
 				}
 			} else {
 				if ((progStatus.show_tabs && !progStatus.first_use) || (!progStatus.show_tabs && progStatus.first_use)) {
+
 					tabs_dialog->hide();
+
 					progStatus.show_tabs = false;
+
 				} else if ((!progStatus.show_tabs && !progStatus.first_use) || (progStatus.show_tabs && progStatus.first_use)) {
+
 					static int X, Y, W, H, dH;
 					X = mainwindow->x();
 					Y = mainwindow->y();
@@ -1377,7 +1380,7 @@ void show_controls()
 					dH = mainwindow->decorated_h();
 					tabs_dialog->resize( X, Y + dH, W, tabs_dialog->h() );
 					grpTABS->resize(0, 0, W, tabs_dialog->h());
-					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
+
 					tabs_dialog->add(grpTABS);
 					tabs_dialog->show();
 					tabs_dialog->redraw();
@@ -1396,21 +1399,12 @@ void show_controls()
 				tabsGeneric->hide();
 				tabs550->show();
 				tabs550->redraw();
+				break;
 			} else {
 				tabs550->hide();
 				tabsGeneric->show();
 				tabsGeneric->redraw();
 			}
-			Fl_Widget * vtab = (Fl_Widget *)0;
-			if (tabsGeneric) {
-				Fl_Widget * const *vtabs = tabsGeneric->array();
-				int ntabs = tabsGeneric->children();
-				for (int n = 0; n < ntabs; n++)
-					if (progStatus.visible_tab == vtabs[n]->label()) {
-						vtab = vtabs[n];
-						break;
-					}
-			}
 			if (progStatus.embed_tabs) { // embedded
 				static int X = mainwindow->x(),
 						   Y = mainwindow->y(),
@@ -1418,6 +1412,7 @@ void show_controls()
 						   H = mainwindow->h();
 				if ((progStatus.show_tabs && !progStatus.first_use) || (!progStatus.show_tabs && progStatus.first_use)) {
 					tabs_dialog->add(grpTABS);
+
 					grpTABS->resize(tabs_dialog->x(), tabs_dialog->y(), tabs_dialog->w(), tabs_dialog->h());
 					mainwindow->resize(mainwindow->x(), mainwindow->y(), W, H);
 					progStatus.show_tabs = false;
@@ -1429,35 +1424,37 @@ void show_controls()
 					mainwindow->resize(X, Y, W, H + grpTABS->h());
 					grpTABS->resize(0, H, W, grpTABS->h());
 					mainwindow->add(grpTABS);
-					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
+
 					grpTABS->show();
 					progStatus.show_tabs = true;
-
 				} else if (progStatus.show_tabs && progStatus.first_use) {
+
 					X = mainwindow->x();
 					Y = mainwindow->y();
 					W = mainwindow->w();
 					H = mainwindow->h();
+
 					mainwindow->resize(X, Y, W, H + grpTABS->h());
 					grpTABS->resize(0, H, W, grpTABS->h());
 					mainwindow->add(grpTABS);
-					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
 
 					grpTABS->show();
-
+					grpTABS->redraw();
+					mainwindow->redraw();
 					progStatus.show_tabs = true;
-
 				}
 			} else {
 				if ((progStatus.show_tabs && !progStatus.first_use) || (!progStatus.show_tabs && progStatus.first_use)) {
 					tabs_dialog->hide();
+
 					progStatus.show_tabs = false;
 				} else if ((!progStatus.show_tabs && !progStatus.first_use) || (progStatus.show_tabs && progStatus.first_use)) {
 					static int X, Y, W, dH;
-					X = progStatus.mainX;
-					Y = progStatus.mainY;
-					W = progStatus.mainW;
+					X = mainwindow->x(); //progStatus.mainX;
+					Y = mainwindow->y(); //progStatus.mainY;
+					W = mainwindow->w(); //progStatus.mainW;
 					dH = mainwindow->decorated_h();
+
 					tabs_dialog->resize( X, Y + dH, W, tabs_dialog->h() );
 					grpTABS->resize(0, 0, W, tabs_dialog->h());
 					if (vtab != (Fl_Widget *)0) tabsGeneric->value(vtab);
@@ -1472,6 +1469,14 @@ void show_controls()
 		default :
 			break;
 	}
+
+	if (tabsGeneric) {
+		if (vtab != (Fl_Widget *)0)
+			tabsGeneric->value(vtab);
+		else
+			progStatus.visible_tab = (tabsGeneric->value())->label();
+	}
+
 	progStatus.first_use = false;
 }
 
@@ -1744,17 +1749,17 @@ Fl_Color flrig_def_color(int n)
 }
 
 
-void cb_send_command(string command, Fl_Output *resp)
+void cb_send_command(std::string command, Fl_Output *resp)
 {
 	if (command.empty()) return;
 	bool usehex = false;
 	if (command.empty()) return;
-	string cmd = "";
-	if (command.find("x") != string::npos) { // hex strings
+	std::string cmd = "";
+	if (command.find("x") != std::string::npos) { // hex std::strings
 		size_t p = 0;
 		usehex = true;
 		unsigned int val;
-		while (( p = command.find("x", p)) != string::npos) {
+		while (( p = command.find("x", p)) != std::string::npos) {
 			sscanf(&command[p+1], "%x", &val);
 			cmd += (unsigned char) val;
 			p += 3;
