@@ -23,10 +23,11 @@
 #include <iostream>
 #include <errno.h>
 
-#include "serial.h"
 #include "debug.h"
-
 #include "rig.h"
+#include "serial.h"
+#include "status.h"
+#include "trace.h"
 
 LOG_FILE_SOURCE(debug::LOG_RIGCONTROL);
 
@@ -43,8 +44,6 @@ char traceinfo[500];
 
 #include <memory>
 
-using namespace std;
-
 Cserial::Cserial() {
 	device = "/dev/ttyS0";
 	baud = 1200;
@@ -70,9 +69,9 @@ Cserial::~Cserial() {
 // Function name	: Cserial::OpenPort
 // Description	  : Opens the port specified by strPortName
 // Return type	  : bool
-// Argument		 : c_string strPortName
+// Argument		 : c_std::string strPortName
 ///////////////////////////////////////////////////////
-bool Cserial::CheckPort(string dev)  {
+bool Cserial::CheckPort(std::string dev)  {
 	int testfd = open( dev.c_str(), O_RDWR | O_NOCTTY | O_NDELAY);
 	if (testfd < 0)
 		return false;
@@ -84,7 +83,7 @@ bool Cserial::CheckPort(string dev)  {
 // Function name	: Cserial::OpenPort
 // Description	  : Opens the port specified by strPortName
 // Return type	  : bool
-// Argument		 : c_string strPortName
+// Argument		 : c_std::string strPortName
 ///////////////////////////////////////////////////////
 bool Cserial::OpenPort()  {
 
@@ -99,6 +98,8 @@ bool Cserial::OpenPort()  {
 		ser_trace(1, traceinfo);
 	}
 
+	MilliSleep(5); // K0OG
+
 // save current port settings
 	tcflush (fd, TCIFLUSH);
 
@@ -351,7 +352,7 @@ bool  Cserial::IOselect ()
 // Function name	: Cserial::ReadBuffer
 // Description	  : Reads upto nchars from the selected port
 // Return type	  : # characters received
-// Argument		 : pointer to buffer; # chars to read; string terminator
+// Argument		 : pointer to buffer; # chars to read; std::string terminator
 ///////////////////////////////////////////////////////
 int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::string find2)
 {
@@ -363,8 +364,7 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 	int retnum = 0, nread = 0;
 	static char tempbuf[201];
 	int tries = 10;
-	bool hex = false;
-	std::string s1, s2;
+
 	size_t p1, p2;
 
 	fd_set rfds;
@@ -376,29 +376,33 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 	tv.tv_sec = timeout/1000;
 	tv.tv_usec = (timeout % 1000) * 1000;
 
-	if (find1.length()) {
-		if (find1.find('\xFE') != std::string::npos) {
-			hex = true;
-			s1 = str2hex(find1.c_str(), find1.length());
-		} else
-			s1 = find1;
-	}
-	if (find2.length()) {
-		if (find2.find('\xFD') != std::string::npos) {
-			hex = true;
-			s2 = str2hex(find2.c_str(), find2.length());
-		} else
-			s2 = find2;
-	}
-
-	while (--tries) {
-
+	while ((tries > 0 ) && (nread < nchars)) {
+		{
+			char tc[50];
+			snprintf(tc, sizeof(tc), "ReadBuffer try # %d", 11 - tries);
+			ser_trace(1, tc);
+		}
 		if (select (FD_SETSIZE, &rfds, (fd_set *)0, (fd_set *)0, &tv) > 0) {
 			if (FD_ISSET( fd, &rfds) ) {
+
 				memset(tempbuf, 0, 201);
-				if ((retnum = read (fd, tempbuf, 200)) > 0) {
+				retnum = read (fd, tempbuf, 200);
+
+				if (retnum > 0) {
 					buf.append(tempbuf, retnum);
 					nread = buf.length();
+				} else if (progStatus.serialtrace)  {
+					char traceinfo[100];
+					snprintf(traceinfo, sizeof(traceinfo), "read(fd %d, tempbuf, 200) error: %s", fd,
+						(errno == EAGAIN ? "EAGAIN" :
+						errno == EWOULDBLOCK ? "EWOULDBLOCK" :
+						errno == EBADF ? "EBADF" :
+						errno == EFAULT? "EFAULT" :
+						errno == EINTR ? "EINTR" :
+						errno == EINVAL ? "EINVAL" :
+						errno == EIO ? "EIO" :
+						errno == EISDIR ? "EISDRI" : "OTHER"));
+						set_trace(1, traceinfo);
 				}
 			}
 		}
@@ -409,35 +413,46 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 			if (p1 != std::string::npos &&
 				p2 != std::string::npos &&
 				p2 > p1) {
-				snprintf(traceinfo, sizeof(traceinfo), "s1/s2: %s",
-					(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()) );
-				if (progStatus.serialtrace) ser_trace(1, traceinfo);
-				return nread;
+				if (progStatus.serialtrace) {
+					char traceinfo[100];
+					snprintf(traceinfo, sizeof(traceinfo), "Buffer: %s",
+						str2hex(buf.c_str(), buf.length()) );
+					ser_trace(1, traceinfo);
+				}
 			}
-		} else if (find1.length()) {
-			p1 = buf.rfind(find1);
-			if (p1 != std::string::npos) {
-				snprintf(traceinfo, sizeof(traceinfo), "s1   : %s",
-					(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()) );
-				if (progStatus.serialtrace) ser_trace(1, traceinfo);
-				return nread;
-			}
-		} else if (nread >= nchars) {
-			snprintf(traceinfo, sizeof(traceinfo), "%d / %d: %s", nread, nchars, 
-				(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()) );
-			if (progStatus.serialtrace) ser_trace(1, traceinfo);;
 			return nread;
 		}
+
+		else if (find1.length()) {
+			p1 = buf.rfind(find1);
+			if (p1 != std::string::npos) {
+				if (progStatus.serialtrace) {
+					char traceinfo[100];
+					std::string srx = buf;
+					if (srx[srx.length() - 1] == '\r') srx.replace(srx.length() -1, 1, "<cr>");
+					snprintf(traceinfo, sizeof(traceinfo), "Buffer: %s",
+						str2hex(buf.c_str(), buf.length()) );
+					ser_trace(1, traceinfo);
+				}
+				return nread;
+			}
+		}
+		tries--;
+	}
+
+	if (progStatus.serialtrace) {
+		char traceinfo[100];
+		snprintf(traceinfo, sizeof(traceinfo), "Buffer: %s",
+			str2hex(buf.c_str(), buf.length()) );
+		ser_trace(1, traceinfo);
 	}
-	if (progStatus.serialtrace)
-		ser_trace(2, "FAILED: ", (hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()) );
 
 	return nread;
 }
 
 ///////////////////////////////////////////////////////
 // Function name	: Cserial::WriteBuffer
-// Description	  : Writes a string to the selected port
+// Description	  : Writes a std::string to the selected port
 // Return type	  : bool
 // Argument		 : BYTE by
 ///////////////////////////////////////////////////////
@@ -483,17 +498,15 @@ void Cserial::FlushBuffer()
 
 #else // __WIN32__
 
-using namespace std;
-
 ///////////////////////////////////////////////////////
 // Function name	: Cserial::CheckPort
 // Description	  : Checks the port specified by strPortName
 // Return type	  : bool
-// Argument		 : c_string strPortName
+// Argument		 : c_std::string strPortName
 ///////////////////////////////////////////////////////
-bool Cserial::CheckPort(string dev)  {
+bool Cserial::CheckPort(std::string dev)  {
 	static HANDLE hTest;
-	string COMportname = "//./";
+	std::string COMportname = "//./";
 
 	COMportname.append(dev);
 
@@ -515,7 +528,7 @@ bool Cserial::CheckPort(string dev)  {
 // Function name	: Cserial::OpenPort
 // Description	  : Opens the port specified by strPortName
 // Return type	  : bool
-// Argument		 : CString strPortName
+// Argument		 : Cstd::string strPortName
 ///////////////////////////////////////////////////////
 bool Cserial::OpenPort()
 {
@@ -523,7 +536,7 @@ bool Cserial::OpenPort()
 
 	if (IsOpen()) ClosePort();
 
-	string COMportname = "//./";
+	std::string COMportname = "//./";
 	COMportname.append(device);
 
 	hComm = CreateFile(COMportname.c_str(),
@@ -535,12 +548,12 @@ bool Cserial::OpenPort()
 			  0);
 
 	if (hComm == INVALID_HANDLE_VALUE) {
-		LOG_ERROR("Open Comm port %s ; hComm = %d", COMportname.c_str(), (int)hComm);
+		LOG_ERROR("Open Comm port %s ; hComm = %llu", COMportname.c_str(), (size_t)hComm);
 
 		if (progStatus.serialtrace) {
 			snprintf(traceinfo, sizeof(traceinfo), 
-				"INVALID_HANDLE_VALUE: Open Comm port %s ; hComm = %d\n", 
-				COMportname.c_str(), (int)hComm);
+				"INVALID_HANDLE_VALUE: Open Comm port %s ; hComm = %llu\n", 
+				COMportname.c_str(), (size_t)hComm);
 			ser_trace(1, traceinfo);
 		}
 
@@ -549,12 +562,15 @@ bool Cserial::OpenPort()
 
 	if (progStatus.serialtrace) {
 		snprintf(traceinfo, sizeof(traceinfo), 
-			"Open Comm port %s ; hComm = %d\n", 
-			COMportname.c_str(), (int)hComm);
+			"Open Comm port %s ; hComm = %llu\n", 
+			COMportname.c_str(), (size_t)hComm);
 		ser_trace(1, traceinfo);
 		}
 
 	ConfigurePort( baud, 8, false, NOPARITY, stopbits);
+
+	MilliSleep(5); // K0OG
+
 	FlushBuffer();
 	failed_ = false;
 
@@ -713,6 +729,7 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 	}
 
 	if (progStatus.serialtrace) {
+		hex = true;
 		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer: (%d): %s\n", nchars, 
 			(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()) );
 		ser_trace(1, traceinfo);
@@ -748,7 +765,7 @@ bool Cserial::WriteByte(char by)
 
 ///////////////////////////////////////////////////////
 // Function name	: Cserial::WriteBuffer
-// Description	  : Writes a string to the selected port
+// Description	  : Writes a std::string to the selected port
 // Return type	  : bool
 // Argument		 : BYTE by
 ///////////////////////////////////////////////////////
@@ -1031,7 +1048,7 @@ DCB.fOutxDsrFlow    %d\n",
 
 	if (progStatus.serialtrace) {
 		long err = GetLastError();
-		snprintf(traceinfo, sizeof(traceinfo), "SetCommState handle %d, returned %d, error = %d\n", (int)hComm, bPortReady, (int)err);
+		snprintf(traceinfo, sizeof(traceinfo), "SetCommState handle %llu, returned %d, error = %d\n", (size_t)hComm, bPortReady, (int)err);
 		ser_trace(1, traceinfo);
 	}
 
