@@ -30,6 +30,7 @@
 #include <fcntl.h>
 
 #include <FL/Fl_Button.H>
+#include <FL/Fl_Light_Button.H>
 
 #include "icons.h"
 #include "support.h"
@@ -53,20 +54,28 @@
 
 #include "tod_clock.h"
 
-using namespace std;
-
 Fl_Double_Window*	tracewindow = (Fl_Double_Window *)0;
 Fl_Text_Display*	tracedisplay = (Fl_Text_Display *)0;
 Fl_Text_Buffer*		tracebuffer = (Fl_Text_Buffer*)0;
 Fl_Button*			btn_cleartrace = (Fl_Button*)0;
+Fl_Light_Button*	btn_pausetrace = (Fl_Light_Button*)0;
 
-vector<string> tracestrings;
+std::string tracestring;
 
 bool stdout_trace = false;
 
+bool pausetrace = false;
+
+static void cb_pausetrace(Fl_Light_Button *o, void *)
+{
+	pausetrace = o->value();
+}
+
 static void cb_cleartrace(Fl_Button *, void *)
 {
+	guard_lock tt(&mutex_trace);
 	tracedisplay->buffer()->text("");
+	tracestring.clear();
 }
 
 void make_trace_window() {
@@ -76,6 +85,8 @@ void make_trace_window() {
 	tracedisplay->buffer(tracebuffer);
 	tracedisplay->textfont(FL_SCREEN);
 	tracedisplay->wrap_mode(Fl_Text_Display::WRAP_NONE, 100);
+	btn_pausetrace = new Fl_Light_Button(430, 275, 80, 20, _("Pause"));
+	btn_pausetrace->callback((Fl_Callback *)cb_pausetrace);
 	btn_cleartrace = new Fl_Button(515, 275, 80, 20, _("Clear"));
 	btn_cleartrace->callback((Fl_Callback *)cb_cleartrace);
 	tracewindow->resizable(tracedisplay);
@@ -83,9 +94,9 @@ void make_trace_window() {
 
 static void write_trace_file(std::string s)
 {
-	string trace_fname = RigHomeDir;
+	std::string trace_fname = RigHomeDir;
 	trace_fname.append("trace.txt");
-	fstream tfile(trace_fname.c_str(), ios::app);
+	std::fstream tfile(trace_fname.c_str(), std::ios::app);
 	if (tfile)
 		tfile << s;
 	tfile.close();
@@ -96,12 +107,13 @@ static void update_tracetext(void *)
 	guard_lock tt(&mutex_trace);
 
 	if (tracewindow->visible()) {
-		if (tracedisplay->buffer()->length() > 100000)
-			tracedisplay->buffer()->text("");
-		for (size_t n = 0; n < tracestrings.size(); n++)
-			tracedisplay->insert(tracestrings[n].c_str());
+		if (!pausetrace) {
+			if (tracedisplay->buffer()->length() > 100000)
+				tracedisplay->buffer()->text("");
+			tracedisplay->insert(tracestring.c_str());
+		}
 	}
-    tracestrings.clear();
+    tracestring.clear();
 }
 
 void trace(int n, ...) // all args of type const char *
@@ -112,7 +124,7 @@ void trace(int n, ...) // all args of type const char *
 
 	if (!n) return;
 
-	stringstream s;
+	std::stringstream s;
 	va_list vl;
 	va_start(vl, n);
 	s << ztime() << " : " << va_arg(vl, const char *);
@@ -129,8 +141,7 @@ void trace(int n, ...) // all args of type const char *
 	write_trace_file(s.str());
 
 	guard_lock tt(&mutex_trace);
-
-	tracestrings.push_back(s.str());
+	tracestring.append(s.str());
 	Fl::awake(update_tracetext);
 }
 
@@ -144,7 +155,7 @@ void xml_trace(int n, ...) // all args of type const char *
 
 	if (!n) return;
 
-	stringstream s;
+	std::stringstream s;
 	va_list vl;
 	va_start(vl, n);
 	s << ztime();
@@ -165,14 +176,13 @@ void xml_trace(int n, ...) // all args of type const char *
 	write_trace_file(s.str());
 
 	guard_lock tt(&mutex_trace);
-
-	tracestrings.push_back(s.str());
+	tracestring.append(s.str());
 	Fl::awake(update_tracetext);
 }
 
 void rig_trace(int n, ...) // all args of type const char *
 {
-	stringstream s;
+	std::stringstream s;
 	va_list vl;
 	va_start(vl, n);
 	s << ztime() << " : " << va_arg(vl, const char *);
@@ -193,14 +203,13 @@ void rig_trace(int n, ...) // all args of type const char *
 	write_trace_file(s.str());
 
 	guard_lock tt(&mutex_trace);
-
-	tracestrings.push_back(s.str());
+	tracestring.append(s.str());
 	Fl::awake(update_tracetext);
 }
 
 void set_trace(int n, ...) // all args of type const char *
 {
-	stringstream s;
+	std::stringstream s;
 	va_list vl;
 	va_start(vl, n);
 	s << ztime() << " : " << va_arg(vl, const char *);
@@ -221,14 +230,13 @@ void set_trace(int n, ...) // all args of type const char *
 	write_trace_file(s.str());
 
 	guard_lock tt(&mutex_trace);
-
-	tracestrings.push_back(s.str());
+	tracestring.append(s.str());
 	Fl::awake(update_tracetext);
 }
 
 void get_trace(int n, ...) // all args of type const char *
 {
-	stringstream s;
+	std::stringstream s;
 	va_list vl;
 	va_start(vl, n);
 	s << ztime() << " : " << va_arg(vl, const char *);
@@ -249,15 +257,13 @@ void get_trace(int n, ...) // all args of type const char *
 	write_trace_file(s.str());
 
 	guard_lock tt(&mutex_trace);
-
-	tracestrings.push_back(s.str());
-
+	tracestring.append(s.str());
 	Fl::awake(update_tracetext);
 }
 
 void rpc_trace(int n, ...) // all args of type const char *
 {
-	stringstream s;
+	std::stringstream s;
 	va_list vl;
 	va_start(vl, n);
 	s << ztime() << " : " << va_arg(vl, const char *);
@@ -318,14 +324,13 @@ void rpc_trace(int n, ...) // all args of type const char *
 	write_trace_file(s.str());
 
 	guard_lock tt(&mutex_trace);
-
-	tracestrings.push_back(str);
+	tracestring.append(s.str());
 	Fl::awake(update_tracetext);
 }
 
 void ser_trace(int n, ...) // all args of type const char *
 {
-	stringstream s;
+	std::stringstream s;
 	va_list vl;
 	va_start(vl, n);
 	s << ztime() << " : " << va_arg(vl, const char *);
@@ -346,7 +351,6 @@ void ser_trace(int n, ...) // all args of type const char *
 	write_trace_file(s.str());
 
 	guard_lock tt(&mutex_trace);
-
-	tracestrings.push_back(s.str());
+	tracestring.append(s.str());
 	Fl::awake(update_tracetext);
 }
